total_dane <- fromJSON(api_endpoint("/crawler_mail_dane")) %>%
  filter(port == "25") %>%
  group_by(ts) %>%
  summarise(dane_domains = sum(domains)) %>%
  mutate(ts = as.Date(ts))

total_dom_dane <- fromJSON(api_endpoint("/fred_domains")) %>%
  filter(zone == "cz") %>%
  group_by(ts) %>%
  summarise(domains = sum(domains)) %>%
  mutate(ts = as.Date(ts)) %>%
  inner_join(total_dane, by = c("ts")) %>%
  mutate(ratio_dane = (dane_domains / domains) * 100) %>%
  filter(ts != "2021-04-08")


plot_total_dom_dane <- plot_ly(total_dom_dane,
  x = ~ts,
  y = ~ratio_dane,
  type = "scatter",
  name = gettext("DANE Records"),
  mode = "lines",
  line = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    "<b>", gettext("Date"), "</b>: %{x}<br><b>",
    gettext("DANE Records"), "</b>: ",
    formatC(total_dom_dane$dane_domains, big.mark = " "), "<br><b>",
    gettext("Total Domains"), "</b>: ",
    formatC(total_dom_dane$domains,
      big.mark = " "
    ), "<br><b>",
    gettext("Ratio (%)"), "</b>: %{y}<br><b>"
  )
) %>%
  layout(
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 yr"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 2,
            label = gettext("2 yr"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Ratio of DANE Domains"),
      ticksuffix = "%"
    )
  )




dane_reg <- fromJSONwithToken(
  api_endpoint("/crawler_mail_dane_by_registrar_latest")
) %>%
  mutate(ts = as.Date(ts)) %>%
  filter(port == 25)
max_dane_ts <- max(dane_reg$ts)


domains_registrar <- fromJSONwithToken(
  api_endpoint("/fred_domains_by_registrar_latest")
) %>%
  mutate(ts = as.Date(ts)) %>%
  filter(zone == "cz")


df_dane <- left_join(dane_reg, domains_registrar,
  by = c("registrar_id")
) %>%
  rename(dane_domains = domains.x, domains = domains.y) %>%
  mutate(
    percent = dane_domains / domains,
    registrar_id = str_remove_all(registrar_id, "REG-"),
    registrar_id = fct_lump_n(registrar_id,
      n = 20, w = dane_domains,
      other_level = gettext("Other")
    ),
    type_registrar = ifelse(domains >= 15000,
      "Big Registrar", "Small Registrar"
    )
  )

plot_dane <- ggplot(
  df_dane,
  aes(reorder(registrar_id, dane_domains), dane_domains,
    text = paste0(
      registrar_id,
      "<b>\n", gettext("Total domains"), "</b>: ", formatC(domains,
        format = "d",
        big.mark = " "
      ),
      "<b>\n", gettext("DANE Domains"), "</b>: ", formatC(dane_domains,
        format = "d",
        big.mark = " "
      ),
      "<b>\n", gettext("share [%]"), "</b>: ", round(percent * 100, 2)
    )
  )
) +
  geom_segment(aes(xend = registrar_id, yend = 0), color = "grey") +
  geom_point(aes(x = registrar_id, y = dane_domains),
    color = dashboard_colors[1], size = 3
  ) +
  coord_flip() +
  theme_bw() +
  labs(x = gettext("Registrars"), y = gettext("DANE domains"))

plot_dane <- ggplotly(plot_dane,
  tooltip = "text"
) %>%
  layout(
    margin = list(t = 50),
    xaxis = list(fixedrange = TRUE)
  ) %>%
  layout(yaxis = list(fixedrange = TRUE))


subplot(plot_total_dom_dane, plot_dane,
  margin = 0.06, titleX = TRUE, titleY = TRUE, nrows = 1
) %>%
  layout(
    autosize = TRUE,
    xaxis = list(showgrid = TRUE, zeroline = FALSE),
    yaxis = list(showgrid = TRUE, zeroline = FALSE)
  ) %>%
  config(displayModeBar = FALSE)
