endpoint <- api_endpoint("/fred_dnssec_domains", zone = "eq.cz")
total_dnssec <- fromJSON(endpoint) %>%
  mutate(
    ts = as.Date(ts),
    year = year(ts)
  ) %>%
  group_by(year) %>%
  filter(ts == max(ts)) %>%
  rename(dnssec_domains = domains) %>%
  select(-zone)

total_dom <- fromJSON(api_endpoint("/fred_domains", zone = "eq.cz")) %>%
  select(-zone) %>%
  mutate(
    ts = as.Date(ts),
    year = year(ts)
  ) %>%
  group_by(year) %>%
  filter(ts == max(ts)) %>%
  inner_join(total_dnssec, by = c("year", "ts")) %>%
  mutate(ratio_dnssec = dnssec_domains / domains) %>%
  ungroup() %>%
  arrange(desc(ts))

details(
  gettext("Share of DNSSEC-protected domains relative to the total number of domains"), # nolint long string
  gettext("The domains (total and DNSSEC) correspond to the end of each year, and the present day for the current year.") # nolint long string
)


plot_ly(total_dom,
  x = ~year,
  y = ~ 100 * round(ratio_dnssec, 3),
  type = "bar",
  name = gettext("Ratio of DNSSEC Domains"),
  marker = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    "<b>", gettext("Year"), "</b>: %{x}<br><b>",
    gettext("Ratio (%)"), "</b>: %{y}<br><b>",
    gettext("Total Domains"), "</b>: ",
    formatC(total_dom$domains,
      big.mark = " "
    ), "<br><b>",
    gettext("DNSSEC Domains"), "</b>: ",
    formatC(total_dom$dnssec_domains,
      big.mark = " "
    ), "<br><b>"
  )
) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  onRender(add_csv_button_local()) %>%
  layout(
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 1,
            label = gettext("1 yr"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 3,
            label = gettext("3 yr"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 yr"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Ratio of DNSSEC domains"),
      ticksuffix = "%"
    )
  )
