dnssec_registrars <- fromJSONwithToken(
  api_endpoint("/fred_dnssec_domains_by_registrar_latest")
) %>%
  filter(zone == "cz")
domains_registrar <- fromJSONwithToken(
  api_endpoint("/fred_domains_by_registrar_latest")
) %>%
  filter(zone == "cz")

dnssec_domains_registrars <- inner_join(dnssec_registrars,
  domains_registrar,
  by = c("registrar_id", "zone", "ts")
) %>%
  rename(dnssec_domains = domains.x, domains = domains.y) %>%
  mutate(
    percent = round(dnssec_domains / domains, 2),
    registrar_id = str_remove_all(registrar_id, "REG-"),
    registrar_id = fct_lump_n(registrar_id,
      n = DISPLAYED_REGISTRARS_COUNT, w = percent,
      other_level = gettext("Other")
    ),
    type_registrar = ifelse(domains >= 15000,
      "Big Registrar", "Small Registrar"
    )
  ) %>%
  group_by(registrar_id, type_registrar) %>%
  summarise(
    dnssec_domains = sum(dnssec_domains), domains = sum(domains),
    percent = mean(percent)
  )

dnssec_big_registrars <- dnssec_domains_registrars %>%
  filter(type_registrar == "Big Registrar") %>%
  ggplot(aes(reorder(registrar_id, percent), percent,
    text = paste0(
      registrar_id,
      "<b>\n", gettext("Total domains"), "</b>: ", formatC(domains,
        format = "d",
        big.mark = " "
      ),
      "<b>\n", gettext("DNSSEC Domains"), "</b>: ", formatC(dnssec_domains,
        format = "d",
        big.mark = " "
      ), " (", round(percent * 100, 1), "%)"
    )
  )) +
  geom_segment(aes(xend = registrar_id, yend = 0), color = "grey") +
  geom_point(aes(x = registrar_id, y = percent),
    color = dashboard_colors[1], size = 3
  ) +
  coord_flip() +
  theme_bw() +
  scale_y_continuous(labels = scales::percent) +
  labs(x = gettext("Large Registrars"), y = "")

dnssec_small_registrars <- dnssec_domains_registrars %>%
  filter(type_registrar == "Small Registrar") %>%
  ggplot(aes(reorder(registrar_id, percent), percent,
    text = paste0(
      registrar_id,
      "<b>\n", gettext("Total Domains"), "</b>: ", formatC(domains,
        format = "d",
        big.mark = " "
      ),
      "<b>\n", gettext("DNSSEC Domains"), "</b>: ", formatC(dnssec_domains,
        format = "d",
        big.mark = " "
      ), " (", round(percent * 100, 1), "%)"
    )
  )) +
  geom_segment(aes(xend = registrar_id, yend = 0), color = "grey") +
  geom_point(aes(x = registrar_id, y = percent),
    color = dashboard_colors[1], size = 3
  ) +
  coord_flip() +
  theme_bw() +
  scale_y_continuous(labels = scales::percent) +
  labs(x = gettext("Small Registrars"), y = "")

big_registrars <- ggplotly(dnssec_big_registrars,
  tooltip = "text"
) %>%
  layout(
    margin = list(t = 50),
    xaxis = list(fixedrange = TRUE)
  ) %>%
  layout(yaxis = list(fixedrange = TRUE))

small_registrars <- ggplotly(dnssec_small_registrars,
  tooltip = "text"
) %>%
  layout(
    margin = list(t = 50),
    xaxis = list(fixedrange = TRUE)
  ) %>%
  layout(yaxis = list(fixedrange = TRUE))

subplot(big_registrars, small_registrars,
  margin = 0.06, titleX = TRUE, titleY = TRUE, nrows = 2
) %>%
  layout(
    autosize = TRUE,
    xaxis = list(showgrid = TRUE, zeroline = FALSE),
    yaxis = list(showgrid = TRUE, zeroline = FALSE)
  ) %>%
  config(displayModeBar = FALSE)
