dane_reg <- fromJSONwithToken(
  api_endpoint("/crawler_mail_dane_by_registrar")
) %>%
  mutate(ts = as.Date(ts))

total <- fromJSON(
  api_endpoint("/fred_domains")
) %>%
  mutate(ts = as.Date(ts)) %>%
  filter(zone == "cz") %>%
  rename(total_domains = domains)


df <- dane_reg %>%
  left_join(total, by = c("ts")) %>%
  filter(port == 25) %>%
  mutate(
    registrar_id = str_remove_all(registrar_id, "REG-"),
    registrar_id = fct_lump_n(registrar_id,
      n = 8, w = domains,
      other_level = gettext("Other")
    )
  ) %>%
  group_by(ts, registrar_id) %>%
  summarise(
    dane_records = sum(domains), total_domains = max(total_domains),
    ratio = round((100 * dane_records / total_domains), 2)
  ) %>%
  ungroup()


fig <- df %>%
  ggplot(aes(ts, dane_records,
    group = 1,
    text = paste0(
      "<b>", ts,
      "<br>", registrar_id,
      "<br>", gettext("DANE records"), "<b>: ", formatC(dane_records,
        format = "d", big.mark = " "
      )
    )
  )) +
  geom_line(color = dashboard_pal(1)) +
  facet_wrap(. ~ reorder(registrar_id, -dane_records), scale = "free_y") +
  theme_bw() +
  labs(y = gettext("DANE records"), x = gettext("Date")) +
  # scale_color_manual(values = rev(dashboard_pal(6))) +
  scale_x_date(date_labels = "%d.%b.%y") +
  scale_y_continuous(labels = scales::format_format(
    big.mark = " ",
    decimal.mark = ",",
    scientific = FALSE
  )) +
  theme(
    panel.spacing.x = unit(-0.8, "lines"),
    panel.spacing.y = unit(0.5, "lines")
  )


ggplotly(fig, tooltip = "text") %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    margin = list(t = 50),
    xaxis = list(fixedrange = TRUE)
  ) %>%
  layout(yaxis = list(fixedrange = TRUE))
