num_registrars <- 15
dnssec_registrars <- fromJSONwithToken(
  api_endpoint("/fred_dnssec_domains_by_registrar")
) %>%
  filter(zone == "cz")
domains_registrar <- fromJSONwithToken(
  api_endpoint("/fred_domains_by_registrar")
) %>%
  filter(zone == "cz")


dnssec_domains_registrars <- inner_join(
  dnssec_registrars,
  domains_registrar,
  by = c("registrar_id", "zone", "ts")
) %>%
  rename(dnssec_domains = domains.x, domains = domains.y) %>%
  mutate(
    ts = as.Date(ts),
    registrar_id = str_remove_all(registrar_id, "REG-"),
    registrar_id = fct_lump_n(registrar_id,
                              n = num_registrars, w = dnssec_domains,
                              other_level = gettext("Other")),
    registar_id = as.factor(registrar_id)
  ) |>
  group_by(ts, registrar_id) |>
  summarise(dnssec_domains = sum(dnssec_domains),
            domains = sum(domains),
            ratio = 100 * round(dnssec_domains / domains, 4),
            .groups = "drop")

n <- length(unique(dnssec_domains_registrars$registrar_id))  # Number of registrars
colors <- dashboard_pal(n)

plot_ly(
  dnssec_domains_registrars,
  x = ~ts,
  y = ~ratio,
  type = "scatter",
  color = ~registrar_id,
  colors = colors,
  mode = "lines",
  hovertemplate =
    paste0(
      "</b> %{x}<br><b>",
      gettext("Registrar"), "</b>:", dnssec_domains_registrars$registrar_id,
      "<br><b>",
      gettext("DNSSEC"), "</b>: ",
      formatC(dnssec_domains_registrars$dnssec_domains, big.mark = " "),
      "<br><b>",
      gettext("Total Domains"), "</b>: ",
      formatC(
        dnssec_domains_registrars$domains,
        big.mark = " "
      ),
      "<br><b>",
      gettext("Ratio (%)"),
      "</b>: %{y}<br><b>"
    )
) %>%
  layout(
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 yr"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 2,
            label = gettext("2 yr"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Ratio of DNSSEC Domains"),
      ticksuffix = "%"
    ),
    showlegend = TRUE
  )
