dns_rtt_cc_qps <- fromJSONwithToken(api_endpoint("/datart_qps_cc_server_ipv_1d",
  ts = get_ts(days, 30)
))
dns_rtt_cc <- fromJSONwithToken(api_endpoint("/datart_rtt_cc_server_ipv_1d",
  ts = get_ts(days, 30)
))

df_wm_rtt <- left_join(dns_rtt_cc_qps, dns_rtt_cc) %>%
  group_by(country_code) %>%
  summarise(
    rtt_median_wm = weighted.mean(mean_median_rtt, qps,
      na.rm = TRUE
    )
  ) %>%
  rename(ISO2 = country_code)

vv <- c("#006d2c", "#addd8e", "#fed976", "#fd8d3c", "#e31a1c", "#800026")

pal <- colorBin(vv,
  bins = c(0, 50, 100, 200, 300, 1000, Inf)
)

data(wrld_simpl)
map_domain_rtt_by_country <- sp::merge(wrld_simpl,
  df_wm_rtt,
  by = c("ISO2"),
  all.x = TRUE
)


map_domain_rtt_by_country@data$country <- countrycode(
  map_domain_rtt_by_country@data$ISO2,
  "iso2c",
  "country.name"
)


m <- leaflet(map_domain_rtt_by_country,
  width = "100%",
  options = tileOptions(minZoom = 1, maxZoom = 5)
) %>%
  setView(lng = 15, lat = 35, zoom = 1.2) %>%
  addPolygons(
    label = ~ lapply(sprintf(
      "<center>%s<BR><B>%s</B></center>",
      country,
      formatC(rtt_median_wm, format = "d", big.mark = " ")
    ), HTML),
    weight = 1,
    color = "gray",
    fillColor = ~ pal(rtt_median_wm),
    fillOpacity = 0.7,
    labelOptions = labelOptions(direction = "auto"),
    smoothFactor = 0.5
  ) %>%
  addPolylines(
    data = map_domain_rtt_by_country,
    weight = 0.2,
    color = "gray",
    fillOpacity = 0.1,
    opacity = 1
  ) %>%
  setMapWidgetStyle(
    list(background = "white")
  ) %>%
  addLegend(
    pal = pal, values = ~rtt_median_wm, opacity = 0.7,
    title = gettext("Round-Trip Time (ms)"),
    position = "bottomright",
    labFormat = labelFormat(big.mark = " ")
  ) %>%
  suspendScroll(sleepOpacity = 1, sleepNote = FALSE)

m$x$options <- append(m$x$options, list(
  "zoomControl" = FALSE,
  "dragging" = TRUE, "attributionControl" = FALSE
))

m
