source("../R/common.R")
source("../R/fromJSONwithToken.R")


fake_active_domains <-
  fromJSONwithToken(api_endpoint("/crawler_fake_eshop_2w_export",
    first_seen = get_ts(days, 14)
  )) %>%
  mutate(
    first_seen = as.Date(first_seen),
    last_seen = as.Date(last_seen),
    class = ifelse(min_prob > 0.65, gettext("very likely"),
      gettext("likely")
    )
  ) %>%
  filter(last_seen == max(last_seen)) %>%
  select(-min_prob, -max_prob) %>%
  mutate(class = cell_spec(class,
    bold = TRUE,
    color = ifelse(class == gettext("very likely"),
      dashboard_colors[3], dashboard_colors[1]
    )
  ))


ranking_active_dom <- fromJSONwithToken(
  api_endpoint("/domain_ranking",
    ts = get_ts(days, 14),
    domain = paste0(
      "in.(",
      paste(as.vector(fake_active_domains$domain), collapse = ","),
      ")"
    )
  )
) %>%
  select(ts, domain, registrar_id, queries) %>%
  mutate(ts = as.Date(ts)) %>%
  group_by(ts, domain, registrar_id) %>%
  summarise(queries_24h = sum(queries)) %>%
  group_by(domain, registrar_id) %>%
  summarise(mean_queries = round(mean(queries_24h), 0)) %>%
  ungroup() %>%
  mutate(queries_tile = adam_color_tile(
    mean_queries,
    "white", dashboard_colors[1]
  ))

inner_join(fake_active_domains, ranking_active_dom, by = c("domain")) %>%
  arrange(desc(mean_queries)) %>%
  select(domain, registrar_id, first_seen, last_seen, class, queries_tile) %>%
  kable(
    "html",
    table.attr = "data-search-cols='1'",
    escape = FALSE,
    format.args = list(big.mark = " "),
    align = c("l", "l", "c", "c", "c", "c"),
    col.names = c(
      gettext("Domain"),
      gettext("Registrar"),
      gettext("Registration date"),
      gettext("Classification date"),
      gettext("Classification"),
      gettext("Avg queries per day")
    )
  ) %>%
  kable_styling(
    full_width = TRUE,
    htmltable_class = paste(
      "adam-table-search",
      "adam-table-scroll",
      "adam-table-nowrap",
      "dtable",
      "table-condensed"
    )
  )
