scan_yesterday_all <-
  fromJSONwithToken(api_endpoint("/crawler_fake_eshop_2w_export_all",
    last_seen = get_ts(days, 4)
  )) %>%
  mutate(last_seen = as.Date(last_seen)) %>%
  filter(last_seen == max(last_seen)) %>%
  group_by(predicted) %>%
  summarise(n = n()) %>%
  mutate(
    total = sum(n),
    percent = 100 * round(n / total, 3)
  )


scan <- scan_yesterday_all %>%
  mutate(
    n = as.numeric(n),
    predicted = ifelse(predicted == "not-an-eshop", gettext("not an e-shop"),
      ifelse(predicted == "no_content", gettext("no content"),
        ifelse(predicted == "http_error", gettext("http error"),
          ifelse(predicted == "likely-not-fake", gettext("likely not fake"),
            gettext("likely fake")
          )
        )
      )
    ),
    topic = ifelse(predicted %in% c("likely fake", "likely not fake"),
      "e-shops", predicted
    ),
    domain_tile = adam_color_tile(
      n,
      "white", dashboard_colors[1]
    ),
    percent_bar = color_bar(dashboard_colors[3])(percent)
  ) %>%
  rename(subtopic = predicted)


scan %>%
  arrange(desc(n)) %>%
  select(subtopic, domain_tile, percent, percent_bar) %>%
  kable(
    "html",
    escape = FALSE,
    format.args = list(big.mark = " "),
    align = c("l", "l", "r", "l", "l"),
    col.names = c(
      gettext("Categories"),
      gettext("Domains"),
      paste0(gettext("Frequency"), " (%)"),
      ""
    )
  ) %>%
  column_spec(4, color = "transparent", width = "12cm") %>%
  kable_styling(
    bootstrap_options = c("striped", "hover", "condensed", "responsive"),
    full_width = TRUE
  )
