fake_domains <-
  fromJSONwithToken(api_endpoint("/crawler_fake_eshop_2w_export",
    first_seen = get_ts(months, 6)
  ))

holder_info <- get_crawler_registry_data(fake_domains$domain) %>%
  filter(first_registration_date > as.Date(Sys.Date()) %m-% months(6)) %>%
  select(domain, holder_id, holder_country, registrar_id) %>%
  mutate(registrar_id = str_remove_all(registrar_id, "REG-")) %>%
  group_by(domain, holder_id, holder_country, registrar_id) %>%
  summarise(n = n_distinct(domain)) %>%
  ungroup() %>%
  rename(country_code = holder_country)

country_codes <- load_country_codes()


df_holder <- right_join(country_codes, holder_info, by = c("country_code")) %>%
  filter(!is.na(holder_id)) %>%
  group_by(holder_id, Country, registrar_id) %>%
  summarise(n = n_distinct(domain)) %>%
  ungroup() %>%
  mutate(
    n_tile = adam_color_tile(
      n,
      "white", dashboard_colors[1]
    ),
    dt_url = paste0("https://www.nic.cz/whois/contact/", holder_id),
    link = cell_spec(holder_id, "html", link = dt_url, new_tab = TRUE)
  )


df_holder %>%
  arrange(desc(n)) %>%
  select(link, Country, registrar_id, n_tile) %>%
  kable(
    format = "html",
    table.attr = "data-search-cols='1'",
    escape = FALSE,
    format.args = list(big.mark = " "),
    align = c("l", "l", "c", "c", "c"),
    col.names = c(
      gettext("Holder ID"),
      gettext("Country"),
      gettext("Registrar"),
      gettext("Domains")
    )
  ) %>%
  kable_styling(
    bootstrap_options = c("hover", "condensed"),
    full_width = TRUE,
    htmltable_class = paste(
      "adam-table-search",
      "adam-table-scroll",
      "adam-table-nowrap",
      "dtable",
      "table-condensed"
    )
  )
