fake_domains <-
  fromJSONwithToken(api_endpoint("/crawler_fake_eshop_2w_export",
                                 first_seen = get_ts(months, 6)))


country_codes <- load_country_codes()

holder_cc_df <- get_crawler_registry_data(fake_domains$domain) %>%
  filter(first_registration_date > as.Date(Sys.Date()) %m-% months(6))  %>%
  group_by(holder_country) %>%
  summarise(n = n_distinct(domain)) %>%
  mutate(total = sum(n)) %>%
  ungroup() %>%
  rename(country_code = holder_country) %>%
  inner_join(country_codes, by = c("country_code"))


holder_cc <- holder_cc_df %>%
  ggplot(aes(reorder(Country, n), n,
    text = paste0(
      "<b>", Country,
      "<br>", gettext("count"), "<b>: ", n,
      "<br>", gettext("frequency [%]"), "<b>: ", round(n * 100 / total, 2)
    )
  )) +
  geom_bar(stat = "identity", fill = dashboard_colors[1]) +
  coord_flip() +
  theme_light() +
  theme_classic() +
  labs(
    x = gettext("Country"),
    y = gettext("Number of fake e-shops")
  )



ggplotly(holder_cc, tooltip = "text") %>%
  config(displayModeBar = FALSE) %>%
  layout(
    margin = list(t = 50),
    xaxis = list(fixedrange = TRUE)
  ) %>%
  layout(yaxis = list(fixedrange = TRUE))
