fake_domains <-
  fromJSONwithToken(api_endpoint("/crawler_fake_eshop_2w_export",
    first_seen = get_ts(months, 6)
  ))

ranking_active_dom <- fromJSONwithToken(
  api_endpoint("/domain_ranking",
    ts = get_ts(months, 6),
    domain = paste0(
      "in.(",
      paste(as.vector(fake_domains$domain), collapse = ","),
      ")"
    )
  )
)

fig_reg <- left_join(fake_domains, ranking_active_dom, by = c("domain")) %>%
  group_by(registrar_id) %>%
  summarise(n = n_distinct(domain)) %>%
  mutate(
    total = sum(n),
    registrar_id = str_remove_all(registrar_id, "REG-")
  ) %>%
  ungroup() %>%
  filter(!is.na(registrar_id)) %>%
  ggplot(aes(reorder(registrar_id, n), n,
    text = paste0(
      "<b>", registrar_id,
      "<br>", gettext("count"), "<b>: ", n,
      "<br>", gettext("frequency [%]"), "<b>: ", round(n * 100 / total, 2)
    )
  )) +
  geom_bar(stat = "identity", fill = dashboard_colors[1]) +
  coord_flip() +
  theme_classic() +
  labs(
    x = gettext("Registrars"),
    y = gettext("Number of fake e-shops")
  )

ggplotly(fig_reg, tooltip = "text") %>%
  config(displayModeBar = FALSE) %>%
  layout(
    margin = list(t = 50),
    xaxis = list(fixedrange = TRUE)
  ) %>%
  layout(yaxis = list(fixedrange = TRUE))
