domains <- fromJSONwithToken(
  api_endpoint("/crawler_fake_eshop_2w_export",
    last_seen = get_ts(months, 1)
  )
) %>%
  mutate(
    first_seen = as.Date(first_seen),
    last_seen = as.Date(last_seen),
    diff_days = last_seen - first_seen
  ) %>%
  group_by(domain) %>%
  summarise(n = n())


boty <- domains %>%
  filter(grepl("boty|croc|hoka|rieker|shoe|boot|aigle|foot|
               pascal|balance|sorel|etnies|ecco|adidas|cater|pascal|
               puma|inov|reebok|craft|asics|soucony|moose|sportiva|
               tamaris|salomon|skecher|saucony|marten|bearpaw|vans|
               pikol|seibel|salewa|inov|merrell|vibram|
               vagabond|asics|kors", domain)) %>%
  mutate(topic = gettext("shoes"))

jeans <- domains %>%
  filter(grepl("jeans|outdoor|northface|hugo|timberland|obleceni|
               canadagoose|mizuno|hilfiger|clothe", domain)) %>%
  mutate(topic = gettext("clothing"))


crypto <- domains %>%
  filter(grepl("cardano|crypto|coin", domain)) %>%
  mutate(topic = gettext("cryptocurrencies"))

food <- domains %>%
  filter(grepl("bistro|chut|pivo", domain)) %>%
  mutate(topic = gettext("food"))

technology <- domains %>%
  filter(grepl("web|internet|max|project|elektro|group|tech|team", domain)) %>%
  mutate(topic = gettext("technology"))

hobbie <- domains %>%
  filter(grepl("nabytek|zahr|knih|darek|moto|rekreace|dovolena|
               kola|doprava|game|letenky|darka|nintendo|
               play|gym|sport", domain)) %>%
  mutate(topic = gettext("hobbies"))


health <- domains %>%
  filter(grepl("zivot|rezidence|zdrav|nemoc|psycholog|
               nutrition|covid", domain)) %>%
  mutate(topic = gettext("health"))

topics <- rbind(
  boty, jeans, crypto,
  food, health,
  technology, hobbie
) %>%
  select(domain, topic)


plot_topics <- right_join(topics, domains, by = c("domain")) %>%
  mutate(topic = ifelse(is.na(topic), gettext("other"), topic)) %>%
  group_by(topic) %>%
  summarise(n = n()) %>%
  mutate(total = sum(n), percent = round(n / total, 3)) %>%
  ggplot(aes(reorder(topic, percent), percent,
    text = paste0(
      "<b>", gettext("category"), "</b>: ", topic,
      "<br><b>", gettext("count"), "</b>: ", n,
      "<br><b>", gettext("frequency"), " [%]</b>: ", percent * 100
    )
  )) +
  geom_bar(stat = "identity", fill = dashboard_colors[1]) +
  theme_bw() +
  labs(
    x = gettext("Goods category"), y = gettext("Frequency"),
    title = gettext("Fake e-shops goods categories")
  ) +
  scale_y_continuous(labels = scales::percent) +
  coord_flip()


ggplotly(plot_topics, tooltip = "text") %>%
  config(displayModeBar = FALSE) %>%
  layout(
    margin = list(t = 50),
    xaxis = list(fixedrange = TRUE)
  ) %>%
  layout(yaxis = list(fixedrange = TRUE))
