endpoint <- api_endpoint("/mojeid_accounts_nia_loa")

df_2fa_accounts <- fromJSON(endpoint) %>%
  filter(type %in% c("fido", "key")) %>%
  mutate(ts = as.Date(ts))


df_account <- df_2fa_accounts %>%
  mutate(type = paste0(type, "-", loa)) %>%
  group_by(ts, type) %>%
  summarise(count = sum(count)) %>%
  ungroup() %>%
  spread(type, count) %>%
  mutate(
    total = `fido-HIGH` + `fido-SUBSTANTIAL` +
      `key-HIGH` + `key-SUBSTANTIAL`,
    total2FA = `fido-HIGH` + `fido-SUBSTANTIAL` + `key-SUBSTANTIAL`,
    totalFIDO = `fido-HIGH` + `fido-SUBSTANTIAL`
  )


plot_ly(df_account,
  x = ~ts,
  y = ~`key-SUBSTANTIAL`,
  name = gettext("MojeID klíč"),
  type = "scatter",
  mode = "none",
  stackgroup = "one",
  hovertemplate = paste0(
    "<b>", gettext("MojeID klíč"), "</b>: %{y}",
    "<extra></extra>"
  ),
  fillcolor = dashboard_colors[3]
) %>%
  add_trace(
    y = ~totalFIDO,
    name = gettext("FIDO2 token"),
    hovertemplate = paste0(
      "<b>", gettext("FIDO2 token (high + substantial)"), "</b>: %{y}",
      "<extra></extra>"
    ),
    fillcolor = dashboard_colors[1]
  ) %>%
  add_trace(
    y = 0,
    hovertemplate = paste0(
      "<b>", gettext("Total 2FA means"), "</b>: ",
      format(df_account$total2FA,
        big.mark = "\u202F"
      ), "<extra></extra>"
    ),
    fillcolor = "rgba(255, 0, 0, 0)",
    hoverinfo = "text",
    visible = TRUE,
    showlegend = FALSE
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    hovermode = "x unified",
    margin = list(t = 60),
    title = gettext("Number of 2FA means registered for use with NIA"),
    legend = list(
      orientation = "h",
      xanchor = "center",
      yanchor = "bottom",
      x = 0.55,
      y = 1
    ),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 15,
            label = gettext("15 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Registered 2FA means"),
      tickformat = ",d",
      dtick = 3800
    )
  )
