endpoint <- api_endpoint("/mojeid_accounts_nia", type = "eq.person")

df_nia_accounts <- fromJSON(endpoint) %>%
  mutate(ts = as.Date(ts))

plot_ly(df_nia_accounts,
  x = ~ts,
  y = ~count,
  hovertemplate = paste0(
    "<b>", gettext("Count"), "</b>: %{y}<extra></extra>"
  )
) %>%
  add_lines() %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    hovermode = "x unified",
    margin = list(t = 60),
    title = gettext("Number of unique personal identities connected with NIA"),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Date"),
      titlefont = list(size = 14),
      rangeselector = list(
        buttons = list(
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 3,
            label = gettext("3 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("NIA identities"),
      titlefont = list(size = 14),
      tickformat = ",d",
      dtick = 3000
    )
  )
