df_nia_aggregated <-
  fromJSONwithToken(
    api_endpoint("/mojeid_day_users_nia_to_registration_aggregated")
  )

df_nia_aggregated <- df_nia_aggregated |>
  mutate(
    ts = as.Date(ts),
    weekday = weekdays(ts),
    category_name = as.factor(category_name),
    group_percentage = sub("%", "", group_percentage)
  ) |>
  mutate(group_percentage = sub(",", ".", group_percentage)) |>
  mutate(group_percentage = as.numeric(group_percentage)) |>
  mutate(weekday = recode(weekday,
    "Pondělí" = "Monday",
    "Úterý"   = "Tuesday",
    "Středa"  = "Wednesday",
    "Čtvrtek" = "Thursday",
    "Pátek"   = "Friday",
    "Sobota"  = "Saturday",
    "Neděle"  = "Sunday"
  ))

df_nia_methods <- df_nia_aggregated |>
  group_by(ts) |>
  summarise(
    total = sum(group_total),
    czech_point = sum(czech_point),
    cp_isds = sum(cp_isds),
    isds = sum(isds),
    nia = sum(nia),
    weekday = first(weekday)
  ) |>
  ungroup() |>
  mutate(
    cp_perc = round(czech_point / total * 100, 2),
    cp_isds_perc = round(cp_isds / total * 100, 2),
    isds_perc = round(isds / total * 100, 2),
    nia_perc = round(nia / total * 100, 2)
  )

fig_nia <- plot_ly(
  df_nia_methods,
  x = ~ts,
  y = ~czech_point,
  type = "bar",
  name = "Czech POINT",
  marker = list(color = dashboard_colors[1]),
  text = ~ paste0(
    "<b>Czech POINT</b>: ",
    czech_point, " (", cp_perc, "%)"
  ),
  hoverinfo = "text",
  textposition = "none"
)
fig_nia <- fig_nia |>
  add_trace(
    y = ~cp_isds,
    name = "ISDS",
    marker = list(color = dashboard_colors[2]),
    text = ~ paste0(
      "<b>ISDS</b>: ",
      cp_isds, " (", cp_isds_perc, "%)"
    ),
    hoverinfo = "text",
    textposition = "none"
  )
fig_nia <- fig_nia |>
  add_trace(
    y = ~nia,
    name = "NIA",
    marker = list(color = dashboard_colors[3]),
    text = ~ paste0(
      "<b>NIA</b>: ",
      nia, " (", nia_perc, "%)"
    ),
    hoverinfo = "text",
    textposition = "none"
  )
fig_nia <- fig_nia |>
  add_trace(
    x = ~ts,
    y = 0,
    name = gettext("Date"),
    marker = list(color = "white"),
    text = ~ paste0(
      "<b>", gettext("Date"), "</b>: ", ts
    ),
    showlegend = FALSE
  )
fig_nia <- fig_nia |>
  layout(
    hovermode = "x unified",
    barmode = "stack",
    legend = list(
      orientation = "h",
      xanchor     = "center",
      yanchor     = "bottom",
      x           = 0.5,
      y           = 0.99
    ),
    yaxis = list(title = gettext("Count of validations")),
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 7,
            label = gettext("7 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 2,
            label = gettext("2 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    )
  )
fig_nia <- fig_nia |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local())
fig_nia
