df_attribute <-
  fromJSONwithToken(
    api_endpoint("/mojeid_attribute")
  )

df_attribute_top15 <-
  df_attribute |>
  mutate(
    ts = as.Date(ts),
    attribute =
    fct_lump_n(attribute,
      n = 15,
      w = count,
      other_level = gettext("Other")
    )
  ) |>
  filter(attribute != gettext("Other")) |>
  arrange(ts)

df_attribute_other <-
  df_attribute |>
  filter(!attribute %in% df_attribute_top15$attribute) |>
  mutate(
    attribute = fct_lump_n(attribute,
      n = 35,
      w = count,
      other_level = gettext("Other")
    )
  ) |>
  arrange(ts)

plot_ly(
  data = df_attribute_top15,
  x = ~ts,
  y = ~count,
  color = ~attribute,
  type = "scatter",
  mode = "line",
  text = ~ paste0(
    ts, " <b>", attribute, "</b>: ", count
  ),
  hoverinfo = "text"
) |>
  add_trace(
    data = df_attribute_other,
    x = ~ts,
    y = ~count,
    color = ~attribute,
    type = "scatter",
    mode = "line",
    text = ~ paste0(
      ts, " <b>", attribute, "</b>: ", count
    ),
    hoverinfo = "text",
    visible = "legendonly"
  ) |>
  layout(
    yaxis =
      list(
        title = gettext("Count")
      ),
    xaxis =
      list(
        title = gettext("Date"),
        rangeselector = list(
          buttons =
            list(
              list(
                count    = 7,
                label    = gettext("7 d"),
                step     = "day",
                stepmode = "backward"
              ),
              list(
                count    = 1,
                label    = gettext("1 m"),
                step     = "month",
                stepmode = "backward"
              ),
              list(
                count    = 6,
                label    = gettext("6 m"),
                step     = "month",
                stepmode = "backward"
              ),
              list(
                count    = 1,
                label    = gettext("1 y"),
                step     = "year",
                stepmode = "backward"
              ),
              list(
                count    = 2,
                label    = gettext("2 y"),
                step     = "year",
                stepmode = "backward"
              ),
              list(
                count    = 4,
                label    = gettext("4 y"),
                step     = "year",
                stepmode = "backward"
              ),
              list(
                step = "all",
                label = gettext("all")
              )
            ),
          rangeslider = list(type = "date")
        )
      )
  ) |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button(api_endpoint("/mojeid_attribute")))
