df_consumer_login <-
  fromJSONwithToken(
    api_endpoint("/mojeid_consumer_login")
  )

df_consumer_login <-
  df_consumer_login |>
  mutate(
    ts = as.Date(ts)
  )

df_consumer_login_top10 <-
  df_consumer_login |>
  mutate(
    consumer = fct_lump_n(consumer,
      n = 10,
      w = count,
      other_level = gettext("Other")
    )
  ) |>
  filter(consumer != gettext("Other"))

df_consumer_login_other <-
  df_consumer_login |>
  filter(!consumer %in% df_consumer_login_top10$consumer) |>
  mutate(
    consumer = fct_lump_n(consumer,
      n = 40,
      w = count,
      other_level = gettext("Other")
    )
  )

plot_ly(
  data = df_consumer_login_top10,
  x = ~ts,
  y = ~count,
  color = ~consumer,
  type = "scatter",
  mode = "line",
  text = ~ paste0(
    ts, " <b>", consumer, "</b>: ", count
  ),
  hoverinfo = "text"
) |>
  add_trace(
    data = df_consumer_login_other,
    x = ~ts,
    y = ~count,
    color = ~consumer,
    type = "scatter",
    mode = "line",
    text = ~ paste0(
      ts, " <b>", consumer, "</b>: ", count
    ),
    hoverinfo = "text",
    visible = "legendonly"
  ) |>
  layout(
    yaxis =
      list(
        title = gettext("Login count")
      ),
    xaxis =
      list(
        title = gettext("Date"),
        rangeselector = list(
          buttons =
            list(
              list(
                count    = 7,
                label    = gettext("7 d"),
                step     = "day",
                stepmode = "backward"
              ),
              list(
                count    = 1,
                label    = gettext("1 m"),
                step     = "month",
                stepmode = "backward"
              ),
              list(
                count    = 6,
                label    = gettext("6 m"),
                step     = "month",
                stepmode = "backward"
              ),
              list(
                count    = 1,
                label    = gettext("1 y"),
                step     = "year",
                stepmode = "backward"
              ),
              list(
                count    = 2,
                label    = gettext("2 y"),
                step     = "year",
                stepmode = "backward"
              ),
              list(
                count    = 4,
                label    = gettext("4 y"),
                step     = "year",
                stepmode = "backward"
              ),
              list(
                step = "all",
                label = gettext("all")
              )
            ),
          rangeslider = list(type = "date")
        )
      )
  ) |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button(api_endpoint("/mojeid_consumer_login")))
