df_plot <- fromJSONwithToken(
  api_endpoint("/mojeid_login_method", order = "ts.asc")
) %>% mutate(ts = as.Date(ts))

n_colors <- df_plot %>%
  distinct(method) %>%
  nrow()
colors <- colorRampPalette(dashboard_colors)(n_colors)

plot1 <- plot_ly(
  df_plot,
  x = ~ts,
  y = ~count,
  color = ~method,
  name = ~method,
  type = "bar",
  colors = colors,
  text = ~ paste0(
    ts, " <b>", method, "</b>: ", count
  ),
  hoverinfo = "text",
  textposition = "none"
) %>%
  layout(
    hovermode = "x unified",
    barmode = "stack",
    legend = list(
      orientation = "v",
      xanchor     = "left",
      yanchor     = "center",
      x           = 1,
      y           = 1
    ),
    yaxis =
      list(title = gettext("Count of logins")),
    xaxis =
      list(
        title = gettext("Date"),
        rangeselector = list(
          buttons = list(
            list(
              count = 7,
              label = gettext("7 d"),
              step = "day",
              stepmode = "backward"
            ),
            list(
              count = 1,
              label = gettext("1 m"),
              step = "month",
              stepmode = "backward"
            ),
            list(
              count = 1,
              label = gettext("1 y"),
              step = "year",
              stepmode = "backward"
            ),
            list(
              step = "all",
              label = gettext("all")
            )
          ),
          rangeslider = list(type = "date")
        )
      )
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  htmlwidgets::onRender(add_csv_button(api_endpoint("/mojeid_login_method")))
plot1
