mojeid_nia_bar <- fromJSON(api_endpoint("/mojeid_nia_logins_1d",
  order = "ts.asc"
)) %>%
  mutate(ts = as.Date(ts), year = year(ts)) %>%
  group_by(year) %>%
  summarise(logins = sum(logins)) %>%
  rename(nia_logins = logins)

endpoint <- api_endpoint("/mojeid_combined_logins_1d",
  order = "ts.asc"
)

df_mojeid_logins <- fromJSON(api_endpoint("/mojeid_logins",
  order = "ts.asc"
)) %>%
  mutate(
    ts = as.Date(ts), year = year(ts)
  ) %>%
  group_by(year) %>%
  summarise(logins = sum(logins)) %>%
  left_join(mojeid_nia_bar, by = c("year")) %>%
  mutate(
    nia_logins = ifelse(is.na(nia_logins), 0, nia_logins),
    other_logins = logins - nia_logins
  )



fig <- plot_ly(df_mojeid_logins,
  x = ~year,
  y = ~nia_logins,
  type = "bar",
  marker = list(color = dashboard_colors[3]),
  name = gettext("NIA logins"),
  hovertemplate = paste0(
    "<b>", gettext("NIA logins"), "</b>: ",
    formatC(df_mojeid_logins$nia_logins,
      format = "d",
      big.mark = "\u202F"
    ),
    " (",
    round(df_mojeid_logins$nia_logins * 100 / df_mojeid_logins$logins, 2),
    "%)",
    "<extra></extra>"
  )
)
fig <- fig %>%
  add_trace(
    y = ~other_logins,
    name = gettext("Other logins"),
    marker = list(color = dashboard_colors[1]),
    hovertemplate = paste0(
      "<b>", gettext("Other logins"), "</b>: ",
      formatC(df_mojeid_logins$other_logins,
        format = "d",
        big.mark = "\u202F"
      ),
      " (",
      round(df_mojeid_logins$other_logins * 100 / df_mojeid_logins$logins, 2),
      "%)",
      "<extra></extra>"
    )
  )
fig <- fig %>%
  add_trace(
    y = 0,
    name = gettext("Total logins"),
    marker = list(color = "white"),
    showlegend = FALSE,
    hovertemplate = paste0(
      "<b>", gettext("Total logins"), "</b>: ",
      formatC(df_mojeid_logins$logins,
        format = "d",
        big.mark = "\u202F"
      ),
      "<extra></extra>"
    )
  )

fig <- fig %>%
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    barmode = "stack",
    hovermode = "x unified",
    title = gettext("Number of MojeID accounts"),
    legend = list(
      orientation = "h",
      xanchor = "center",
      yanchor = "bottom",
      x = 0.5,
      y = 0.99
    ),
    separators = ".\u202F",
    margin = list(t = 50),
    xaxis = list(
      fixedrange = TRUE,
      dtick = 1,
      title = gettext("Year")
    )
  ) %>%
  layout(yaxis = list(
    fixedrange = TRUE,
    title = gettext("Logins"),
    tickformat = ",d",
    dtick = 100000
  ))


fig
