mojeid_nia_1d <- fromJSON(api_endpoint("/mojeid_nia_logins_1d",
  order = "ts.asc"
)) %>%
  mutate(ts = as.Date(ts)) %>%
  rename(nia_logins = logins)

df_mojeid_logins_1d <- fromJSON(api_endpoint("/mojeid_logins",
  order = "ts.asc"
)) %>%
  mutate(
    ts = as.Date(ts),
    weekday = weekdays(ts)
  ) %>%
  left_join(mojeid_nia_1d, by = c("ts")) %>%
  mutate(ratio = nia_logins / logins) %>%
  rowwise() %>%
  mutate(other_logins = sum(logins, -nia_logins, na.rm = TRUE)) %>%
  ungroup()

plot1 <- plot_ly(
  df_mojeid_logins_1d,
  x = ~ts,
  y = ~logins,
  type = "scatter",
  mode = "lines",
  text = ~ paste0(
    "<b>", gettext("Total logins"),
    "</b>:", logins
  ),
  name = gettext("Total logins"),
  line = list(color = dashboard_colors[1]),
  hoverinfo = "text"
) %>%
  add_trace(
    y = ~nia_logins,
    name = gettext("NIA logins"),
    mode = "lines",
    text = ~ paste0(
      "<b>", gettext("NIA logins"),
      "</b>: ", nia_logins
    ),
    hoverinfo = "text",
    line = list(color = dashboard_colors[3])
  ) %>%
  add_trace(
    x = ~ts,
    y = 0,
    type = "scatter",
    mode = "lines",
    text = ~ paste0(
      "<b>", gettext("Date"), "</b>: ", ts,
      " (", weekday, ")"
    ),
    name = gettext("Date"),
    line = list(color = "rgba(255, 0, 0, 0)"),
    hoverinfo = "text",
    visible = TRUE,
    legendrank = 1,
    showlegend = FALSE
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    hovermode = "x unified",
    margin = list(t = 75),
    title = gettext("Number of daily logins"),
    legend = list(
      orientation = "h",
      xanchor = "center",
      x = 0.5,
      y = 1.08
    ),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 7,
            label = gettext("7 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 15,
            label = gettext("15 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 3,
            label = gettext("3 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Number of logins"),
      tickformat = ",d",
      dtick = 1200
    )
  )
plot1
