mojeid_nia <- fromJSON(api_endpoint("/mojeid_nia_logins_1d",
  order = "ts.asc"
))

mojeid_logins <- fromJSON(api_endpoint("/mojeid_logins",
  order = "ts.asc"
))

max_month <- mojeid_logins %>%
  mutate(
    ts = as.Date(ts),
    Day = days_in_month(ts),
    day_logins = day(ts)
  ) %>%
  filter(Day == day_logins) %>%
  filter(ts == max(ts))

df_mojeid_nia <- mojeid_nia %>%
  mutate(ts = as.Date(ts)) %>%
  filter(ts <= max_month$ts) %>%
  mutate(
    month = month(ts), year = year(ts),
    month = as.Date(paste(year, month, 1, sep = "-"))
  ) %>%
  group_by(month, year) %>%
  summarise(logins = sum(logins)) %>%
  ungroup() %>%
  rename(nia_logins = logins)

df_mojeid_logins <- mojeid_logins %>%
  mutate(ts = as.Date(ts)) %>%
  filter(ts <= max_month$ts) %>%
  mutate(
    month = month(ts), year = year(ts),
    month = as.Date(paste(year, month, 1, sep = "-"))
  ) %>%
  group_by(month, year) %>%
  summarise(logins = sum(logins)) %>%
  left_join(df_mojeid_nia, by = c("month", "year")) %>%
  rowwise() %>%
  mutate(other_logins = sum(logins, -nia_logins, na.rm = TRUE)) %>%
  ungroup()


plot2 <- plot_ly(df_mojeid_logins,
  x = ~month,
  y = ~logins,
  name = gettext("Total logins"),
  line = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    "<b>", gettext("Total logins"),
    "</b>: %{y}<extra></extra>"
  )
) %>%
  add_lines() %>%
  add_trace(
    y = ~nia_logins, name = gettext("NIA logins"),
    mode = "lines",
    hovertemplate = paste0(
      "<b>", gettext("NIA logins"), "</b>: %{y}<extra></extra>"
    ),
    line = list(color = dashboard_colors[3])
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    hovermode = "x unified",
    margin = list(t = 75),
    title = gettext("Number of monthly logins"),
    legend = list(
      orientation = "h",
      xanchor = "center",
      x = 0.5,
      y = 1.08
    ),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Month"),
      rangeselector = list(
        buttons = list(
          list(
            count = 3,
            label = gettext("3 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 3,
            label = gettext("3 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Number of logins"),
      tickformat = ",d",
      dtick = 25000
    )
  )

plot2
