endpoint <- api_endpoint("/mojeid_combined_logins_1d",
  order = "ts.asc"
)

mojeid_logins <- fromJSON(endpoint) %>%
  mutate(
    ts = as.Date(ts)
  ) %>%
  rowwise() %>%
  mutate(other_logins = sum(logins, -nia_logins, na.rm = TRUE)) %>%
  ungroup()

latest_ts <- max(mojeid_logins$ts)
last_sunday <- floor_date(latest_ts, "week")

mojeid_logins <- mojeid_logins %>%
  filter(ts <= last_sunday) %>%
  aggregate(cbind(logins, other_logins, nia_logins) ~ cut(ts,
      breaks = "1 week",
      right = FALSE
    ), ., sum,
    na.action = na.pass
  ) %>%
  mutate(
    week_start = as.Date(.[[1]]),
    week_end = as.Date(.[[1]]) + 6
  ) %>%
  select(
    week_start,
    week_end,
    logins,
    other_logins,
    nia_logins
  )

week_plot <- plot_ly(
  mojeid_logins,
  x = ~week_end,
  type = "scatter",
  mode = "lines",
  y = ~logins,
  name = gettext("Total logins"),
  line = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    "<b>", gettext("Total logins"), "</b>: %{y}<extra></extra>"
  )
) %>%
  add_trace(
    y = ~nia_logins,
    name = gettext("NIA logins"),
    mode = "lines",
    line = list(color = dashboard_colors[3]),
    hovertemplate = paste0(
      "<b>", gettext("NIA logins"), "</b>: %{y}<extra></extra>"
    )
  ) %>%
  add_trace(
    y = 0,
    name = gettext("Date"),
    line = list(color = "rgba(255, 0, 0, 0)"),
    customdata = paste0(
      gettext("from"),
      " <b>",
      format(mojeid_logins$week_start, locale_date_format()),
      "</b> ",
      gettext("to"),
      " <b>",
      format(mojeid_logins$week_end, locale_date_format()),
      "</b>"
    ),
    hovertemplate = paste0(
      gettext("Week"), " %{customdata}", "<extra></extra>"
    ),
    visible = TRUE,
    legendrank = 1,
    showlegend = FALSE
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    hovermode = "x unified",
    margin = list(t = 75),
    title = gettext("Number of weekly logins"),
    legend = list(
      orientation = "h",
      xanchor = "center",
      x = 0.5,
      y = 1.08
    ),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Week"),
      rangeselector = list(
        buttons = list(
          list(
            count = 15,
            label = gettext("15 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 3,
            label = gettext("3 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Number of logins"),
      tickformat = ",d"
    )
  )

week_plot
