endpoint <- api_endpoint("/mojeid_registration_steps_latest")

df_mojeid <- fromJSONwithToken(endpoint)

df_matomo <- fromJSON(
  url(
    description =
      paste0(
        "https://matomo.nic.cz/index.php",
        "?module=API",
        "&format=JSON",
        "&idSite=79",
        "&period=day",
        "&date=2024-04-02,", Sys.Date() - 1,
        "&method=Actions.getPageUrls",
        "&label=%40%252Fregistration",
        "&filter_limit=-1",
        "&format_metrics=1",
        "&expanded=1",
        "&showColumns=nb_uniq_visitors",
        "&token_auth=", Sys.getenv("MATOMO_MOJEID_TOKEN")
      )
  )
)

dates <- names(df_matomo)

df_matomo <-
  do.call(rbind, df_matomo) |>
  mutate(
    datum = dates,
    nb_uniq_visitors = as.integer(nb_uniq_visitors)
  ) |>
  select(datum, nb_uniq_visitors) |>
  rename(registration = nb_uniq_visitors)

df_mojeid <- left_join(df_mojeid, df_matomo, by = "datum")

df_mjid <- df_mojeid %>%
  mutate(
    datum = as.Date(datum),
    prop_started = round(started * 100 / registration, 2),
    prop_email = round(email * 100 / started, 2),
    prop_phone = round(phone * 100 / email, 2),
    prop_pass = round(password * 100 / phone, 2),
    prop_tfa = round(tfa * 100 / password, 2),
    prop_nia = round(nia * 100 / tfa, 2)
  )


plot_ly(df_mjid,
  x = ~datum,
  y = ~prop_started,
  type = "scatter",
  name = gettext("1st Page"),
  mode = "lines",
  line = list(color = dashboard_colors[1]),
  hovertemplate =
    paste0(
      "<b>", gettext("1st Page"), "</b>: ",
      "%{y}% (", df_mjid$started, ")<extra></extra>"
    )
) %>%
  add_trace(
    y = ~prop_email,
    name = gettext("Email"),
    mode = "lines",
    hovertemplate =
      paste0(
        "<b>", gettext("Email"), "</b>: ",
        "%{y}% (", df_mjid$email, ")<extra></extra>"
      ),
    line = list(color = dashboard_colors[2])
  ) %>%
  add_trace(
    y = ~prop_phone,
    name = gettext("Phone"),
    mode = "lines",
    hovertemplate =
      paste0(
        "<b>", gettext("Phone"), "</b>: ",
        "%{y}% (", df_mjid$phone, ")<extra></extra>"
      ),
    line = list(color = dashboard_colors[3])
  ) %>%
  add_trace(
    y = ~prop_pass,
    name = gettext("Password"),
    mode = "lines",
    hovertemplate =
      paste0(
        "<b>", gettext("Password"), "</b>: ",
        "%{y}% (", df_mjid$password, ")<extra></extra>"
      ),
    line = list(color = dashboard_colors[4])
  ) %>%
  add_trace(
    y = ~prop_tfa,
    name = gettext("2FA"),
    mode = "lines",
    hovertemplate =
      paste0(
        "<b>", gettext("2FA"), "</b>: ",
        "%{y}% (", df_mjid$tfa, ")<extra></extra>"
      ),
    line = list(color = dashboard_colors[5])
  ) %>%
  add_trace(
    y = ~prop_nia,
    name = gettext("NIA"),
    mode = "lines",
    hovertemplate =
      paste0(
        "<b>", gettext("NIA"), "</b>: ",
        "%{y}% (", df_mjid$nia, ")<extra></extra>"
      ),
    line = list(color = dashboard_colors[6])
  ) %>%
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    hovermode = "x unified",
    margin = list(t = 75),
    legend = list(
      orientation = "h",
      xanchor     = "center",
      x           = 0.5,
      y           = 1.08
    ),
    yaxis = list(title = gettext("Ratio (%)")),
    xaxis =
      list(
        title = gettext("Date"),
        rangeselector = list(
          buttons =
            list(
              list(
                count    = 7,
                label    = gettext("7 d"),
                step     = "day",
                stepmode = "backward"
              ),
              list(
                count    = 1,
                label    = gettext("1 m"),
                step     = "month",
                stepmode = "backward"
              ),
              list(
                count    = 6,
                label    = gettext("6 m"),
                step     = "month",
                stepmode = "backward"
              ),
              list(
                step = "all",
                label = gettext("all")
              )
            ),
          rangeslider = list(type = "date")
        )
      )
  )
