library("readr")

df_mojeid <- fromJSONwithToken(
  api_endpoint("/mojeid_users_registration_to_nia_latest", order = "ts.asc")
)

caption <- paste0(
  gettext("Last update: "),
  df_mojeid %>%
    select(ts) %>%
    distinct() %>%
    pull() %>%
    as.Date()
)

df_mojeid %>%
  select(-ts) %>%
  mutate(
    num_connected_identities_to_nia = adam_color_tile(
      num_connected_identities_to_nia, "white", dashboard_colors[1]
    ),
    num_registered_users = adam_color_tile(
      num_registered_users, "white", dashboard_colors[1]
    ),
    num_connected_accounts_to_nia = adam_color_tile(
      num_connected_accounts_to_nia, "white", dashboard_colors[1]
    ),
    group_percentage = color_tile("white", dashboard_colors[3])
    (percent(
      parse_number(group_percentage, locale = locale(decimal_mark = ",")) / 100
    )
    )
  ) %>%
  kable(
    "html",
    table.attr = "data-search-cols='1'",
    escape = FALSE,
    format.args = list(big.mark = " "),
    align = c("r", "c", "c", "c", "c", "l", "l"),
    caption = caption,
    col.names = c(
      gettext("Time frame"),
      gettext("Registered users"),
      gettext("Accounts connected to NIA"),
      gettext("Identities connected to NIA"),
      gettext("Group percentage"),
      gettext("Average meantime"),
      gettext("Median meantime")
    )
  ) %>%
  kable_styling(
    bootstrap_options = c("hover", "condensed"),
    full_width = TRUE,
    htmltable_class = paste(
      "adam-table-search",
      "adam-table-scroll",
      "adam-table-nowrap",
      "dtable",
      "table-condensed"
    )
  )
