library("readr")

df_mojeid <- fromJSONwithToken(
  api_endpoint("/mojeid_users_registration_to_nia_latest", order = "ts.asc")
)


df_mojeid %>%
  mutate(
    analyzed_time_frame = parse_date_time(analyzed_time_frame, "%Y-%m"),
    group_percentage = parse_number(group_percentage,
      locale = locale(decimal_mark = ",")
    ) / 100
  ) %>%
  plot_ly(
    x = ~analyzed_time_frame,
    y = ~group_percentage,
    hovertemplate = paste0(
      "%{y}<extra></extra>"
    )
  ) %>%
  add_lines() %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    hovermode = "x unified",
    margin = list(t = 60),
    title = gettext("NIA success rate"),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Month"),
      titlefont = list(size = 14)
    ),
    yaxis = list(
      title = gettext("Group percentage"),
      titlefont = list(size = 14),
      tickformat = "%"
    )
  )
