odvr_ipv_1h <- fromJSON(api_endpoint("/odvr_qps_ipv_1h",
  ts = get_ts(months, 6)
))

odvr_ipv <- odvr_ipv_1h %>%
  mutate(ts = as.Date(ts), ts = as.Date(ts), ipv = as.factor(ipv)) %>%
  group_by(ts, ipv) %>%
  summarise(qps = mean(qps)) %>%
  spread(ipv, qps) %>%
  rename(IPv4 = `4`, IPv6 = `6`) %>%
  ungroup()

plot_ly(odvr_ipv,
  x = ~ts,
  y = ~IPv4,
  mode = "lines",
  line = list(color = dashboard_colors[1]),
  name = "IPv4",
  hovertemplate = paste0(
    "<b>IPv4</b>: %{y} qps<extra></extra>"
  )
) %>%
  add_trace(
    x = ~ts,
    y = ~IPv6,
    line = list(color = dashboard_colors[3]),
    name = "IPv6",
    hovertemplate = paste0(
      "<b>IPv6</b>: %{y} qps<extra></extra>"
    )
  ) %>%
  add_lines() %>%
  config(locale = locale_lang_code()) %>%
  onRender(add_csv_button(
    api_endpoint("/odvr_qps_ipv_1h"),
    series = "ipv",
    mapping = csv_mapping_ipv
  )) %>%
  layout(
    hovermode = "x unified",
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 2,
            label = gettext("2 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 4,
            label = gettext("4 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(title = gettext("Queries per second"))
  )
