odvr_protocol_1h <- fromJSON(api_endpoint("/odvr_qps_dstp_prot_1h",
  ts = get_ts(months, 6)
))

odvr_protocol <- odvr_protocol_1h %>%
  mutate(
    ts = as.Date(ts),
    dstp = as.factor(dstp),
    prot = as.factor(prot),
    Protocol = ifelse(prot == 6, "TCP", "UDP"),
    dstp = ifelse(dstp == 53, "", ifelse(dstp == 443, "DoH", "DoT"))
  ) %>%
  mutate(type = paste0(Protocol, " ", dstp)) %>%
  group_by(ts, type) %>%
  summarise(qps = mean(qps)) %>%
  ungroup() %>%
  spread(type, qps) %>%
  rename(TCP = `TCP `, UDP = `UDP `)

odvr_protocol_plot <- plot_ly(odvr_protocol,
  x = ~ts,
  y = ~UDP,
  mode = "lines",
  line = list(color = dashboard_colors[1]),
  name = "UDP",
  hovertemplate = paste0(
    "<b>UDP</b>: %{y} qps<extra></extra>"
  )
) %>%
  add_lines() %>%
  add_lines(
    x = ~ts,
    y = ~`TCP DoT`,
    line = list(color = dashboard_colors[2]),
    name = "TCP DoT",
    hovertemplate = paste0(
      "<b>TCP DoT</b>: %{y} qps<extra></extra>"
    )
  ) %>%
  add_lines(
    x = ~ts,
    y = ~`TCP DoH`,
    line = list(color = dashboard_colors[3]),
    name = "TCP DoH",
    hovertemplate = paste0(
      "<b>TCP DoH</b>: %{y} qps<extra></extra>"
    )
  ) %>%
  add_lines(
    x = ~ts,
    y = ~TCP,
    line = list(color = dashboard_colors[4]),
    name = "TCP/53",
    hovertemplate = paste0(
      "<b>TCP/53</b>: %{y} qps<extra></extra>"
    )
  ) %>%
  config(locale = locale_lang_code()) %>%
  onRender(add_csv_button(
    api_endpoint("/odvr_qps_dstp_prot_1h"),
    series = "prot"
  )) %>%
  layout(
    hovermode = "x unified",
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 2,
            label = gettext("2 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 4,
            label = gettext("4 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(title = gettext("Queries per second"))
  )

if (Sys.getenv("ADAM_DOCS") == "true") {
  odvr_protocol_plot %>%
    add_annotations(
      x = 1.09,
      y = 0.8,
      xref = "paper",
      yref = "paper",
      text = paste0("<b>", gettext("legend"), "</b>"),
      showarrow = TRUE,
      ax = 1,
      ay = 30,
      arrowcolor = "Darkgreen",
      font = list(
        color = "Darkgreen",
        size = 15
      )
    ) %>%
    add_annotations(
      x = 0.08,
      y = 1,
      xref = "paper",
      yref = "paper",
      text = paste0("<b>", gettext("extent"), "</b>"),
      showarrow = TRUE,
      ax = 1,
      ay = 25,
      arrowcolor = "Darkgreen",
      font = list(
        color = "Darkgreen",
        size = 15
      )
    ) %>%
    add_annotations(
      x = 0.96,
      y = 1.01,
      xref = "paper",
      yref = "paper",
      text = paste0("<b>", gettext("toolbar"), "</b>"),
      showarrow = TRUE,
      ax = 1,
      ay = 25,
      arrowcolor = "Darkgreen",
      font = list(
        color = "Darkgreen",
        size = 15
      )
    )
} else {
  odvr_protocol_plot
}
