odvr_rcode_1h <- fromJSON(api_endpoint("/odvr_qps_rcode_1h",
  ts = get_ts(days, 30)
)) %>%
  mutate(rcode = as.factor(rcode))

rcode <- read.csv("../../Dashboard/CSV/rcode.csv", sep = ",")

odvr_rcode <- odvr_rcode_1h %>% inner_join(rcode, by = c("rcode"))


df_odvr_rcode_traffic <- odvr_rcode %>%
  mutate(ts = as.Date(ts)) %>%
  group_by(ts, Name) %>%
  summarise(queries = sum(qps)) %>%
  mutate(queries = queries * 3600) %>%
  mutate(queries_24h = queries / 86400) %>%
  group_by(ts, Name) %>%
  summarise(queries_24h = sum(queries_24h))



df_odvr_rcode_traffic_table <- df_odvr_rcode_traffic %>%
  group_by(Name) %>%
  summarise(
    qps_max = round(max(queries_24h), 0),
    qps_min = round(min(queries_24h), 0)
  ) %>%
  ungroup() %>%
  mutate(
    qps_max_tile = adam_color_tile(qps_max, "white", dashboard_colors[1]),
    qps_min_tile = adam_color_tile(qps_min, "white", dashboard_colors[1])
  ) %>%
  inner_join(
    df_odvr_rcode_traffic %>%
      group_by(Name) %>%
      summarise(
        qps_current = mean(queries_24h)
      ) %>%
      ungroup() %>%
      mutate(
        qps_current_tile = adam_color_tile(
          qps_current,
          "white", dashboard_colors[3]
        )
      ),
    by = c("Name")
  )

df_odvr_rcode_traffic_spark <- df_odvr_rcode_traffic %>%
  group_by(Name) %>%
  arrange(ts) %>%
  summarise(
    queries_bar = spk_chr(
      queries_24h,
      type = "line",
      lineColor = sparkline_colors[1],
      fillColor = sparkline_colors[2],
      spotColor = TRUE,
      width = 80
    )
  )


htmltools::attachDependencies(
  htmltools::div(), html_dependency_sparkline()
)


df_odvr_rcode_traffic_table %>%
  left_join(df_odvr_rcode_traffic_spark, by = "Name") %>%
  arrange(desc(qps_current)) %>%
  select(
    Name,
    qps_max_tile,
    qps_min_tile,
    queries_bar,
    qps_current_tile
  ) %>%
  kable(
    "html",
    table.attr = "class='dtable'",
    escape = FALSE,
    align = c("r", "c", "c", "c", "c", "c"),
    format.args = list(big.mark = " "),
    col.names = c("RCODE", "Max QPS", "Min QPS", "Trend", gettext("Average"))
  ) %>%
  column_spec(1, bold = TRUE, width = "3cm") %>%
  column_spec(2, width = "3cm") %>%
  column_spec(3, width = "3cm") %>%
  column_spec(4, width = "3cm") %>%
  column_spec(5, width = "3cm") %>%
  kable_styling(
    bootstrap_options = c("striped", "hover", "condensed", "responsive"),
    full_width = TRUE,
    position = "left"
  )
