odvr_server_1h <- fromJSON(api_endpoint("/odvr_qps_server_1h",
  ts = get_ts(days, 30)
))

df_odvr_server_traffic <- odvr_server_1h %>%
  mutate(
    ts = as.Date(ts), server = str_remove_all(server, "odvr-odvr-"),
    server = str_remove_all(server, "odvr-"),
    server = str_remove_all(server, "-new")
  ) %>%
  group_by(ts, server) %>%
  summarise(queries = sum(qps)) %>%
  mutate(queries = queries * 3600) %>%
  mutate(
    queries_24h = queries / 86400,
    server = fct_lump_n(server, n = 9, w = queries_24h)
  ) %>%
  group_by(ts, server) %>%
  summarise(queries_24h = sum(queries_24h))


df_odvr_server_traffic_table <- df_odvr_server_traffic %>%
  group_by(server) %>%
  summarise(
    qps_max = round(max(queries_24h), 0),
    qps_min = round(min(queries_24h), 0)
  ) %>%
  ungroup() %>%
  mutate(
    qps_max_tile = adam_color_tile(qps_max, "white", dashboard_colors[1]),
    qps_min_tile = adam_color_tile(qps_min, "white", dashboard_colors[1])
  ) %>%
  inner_join(
    df_odvr_server_traffic %>%
      group_by(server) %>%
      summarise(
        qps_current = mean(queries_24h)
      ) %>%
      ungroup() %>%
      mutate(
        qps_current_tile = adam_color_tile(
          qps_current,
          "white", dashboard_colors[3]
        )
      ),
    by = c("server")
  )


df_odvr_num <- df_odvr_server_traffic %>%
  arrange(ts) %>%
  group_by(server) %>%
  summarise(n = n()) %>%
  filter(n == 1) %>%
  mutate(ts = as.Date(Sys.Date() - 7), queries_24h = 0) %>%
  select(ts, server, queries_24h)

df_odvr_server_traffic_spark <- df_odvr_server_traffic %>%
  rbind(df_odvr_num) %>%
  arrange(ts) %>%
  group_by(server) %>%
  summarise(
    queries_bar = spk_chr(
      queries_24h,
      type = "line",
      lineColor = sparkline_colors[1],
      fillColor = sparkline_colors[2],
      spotColor = TRUE,
      width = 80
    )
  )



htmltools::attachDependencies(
  htmltools::div(), html_dependency_sparkline()
)


df_odvr_server_traffic_table %>%
  left_join(df_odvr_server_traffic_spark, by = "server") %>%
  arrange(desc(qps_current)) %>%
  select(
    server,
    qps_max_tile,
    qps_min_tile,
    queries_bar,
    qps_current_tile
  ) %>%
  kable(
    "html",
    table.attr = "class='dtable'",
    escape = FALSE,
    align = c("r", "c", "c", "c", "c", "c"),
    format.args = list(big.mark = " "),
    col.names = c(
      "Server", "Max QPS", "Min QPS",
      "Trend", gettext("Average")
    )
  ) %>%
  column_spec(1, bold = TRUE, width = "3cm") %>%
  column_spec(2, width = "3cm") %>%
  column_spec(3, width = "3cm") %>%
  column_spec(4, width = "3cm") %>%
  column_spec(5, width = "3cm") %>%
  kable_styling(
    bootstrap_options = c("striped", "hover", "condensed", "responsive"),
    full_width = TRUE,
    position = "left"
  )
