df_cd_odvr <- fromJSON(api_endpoint("/odvr_qps_cd_1h",
  ts = get_ts(months, 6)
))

qps_cd_odvr <- df_cd_odvr %>%
  mutate(
    ts = as.Date(ts),
    cd = as.factor(cd),
    cd = ifelse(cd == 0, "CD_bit_0", "CD_bit_1")
  ) %>%
  group_by(ts, cd) %>%
  summarise(qps = mean(qps)) %>%
  spread(cd, qps) %>%
  mutate(total = CD_bit_0 + CD_bit_1, ratio_cd = CD_bit_1 / total) %>%
  ungroup()


qps_cd_odvr <- df_cd_odvr %>%
  mutate(
    ts = as.Date(ts),
    cd = as.factor(cd),
    cd = ifelse(cd == 0, "CD bit = 0", "CD bit = 1"),
    year = year(ts),
    month = month(ts)
  ) %>%
  group_by(month, year, cd) %>%
  summarise(qps = mean(qps)) %>%
  mutate(
    total = sum(qps),
    date = paste0(year, "-", month, "-01")
  ) %>%
  ungroup() %>%
  mutate(date = as.Date(date))



plot_qps_cd_odvr <- qps_cd_odvr %>%
  ggplot(aes(date,
    qps,
    fill = cd,
    text = sprintf(
      "%s<br>%s: <b>%s (%4.2f %%)</b>",
      date,
      cd,
      formatC(qps, format = "d", big.mark = " "),
      qps / total * 100
    )
  )) +
  geom_bar(
    stat = "identity",
    position = position_fill(reverse = TRUE),
    color = dashboard_colors[1], size = 0.1
  ) +
  theme_classic() +
  xlab(gettext("Months")) +
  ylab(gettext("Shares of CD bit answers")) +
  scale_y_continuous(labels = scales::percent) +
  scale_fill_manual(values = dashboard_pal(2)) +
  theme(legend.title = element_blank()) +
  scale_x_date(date_breaks = "months", date_labels = "%b-%y")


ggplotly(plot_qps_cd_odvr, tooltip = "text") %>%
  config(displayModeBar = FALSE) %>%
  layout(
    margin = list(t = 50),
    xaxis = list(fixedrange = TRUE)
  ) %>%
  layout(yaxis = list(fixedrange = TRUE))




# hide temporarly

qps_cd_odvr <- df_cd_odvr %>%
  mutate(
    ts = as.Date(ts),
    cd = as.factor(cd),
    cd = ifelse(cd == 0, "CD_bit_0", "CD_bit_1")
  ) %>%
  group_by(ts, cd) %>%
  summarise(qps = mean(qps)) %>%
  spread(cd, qps) %>%
  mutate(total = CD_bit_0 + CD_bit_1, ratio_cd = CD_bit_1 / total) %>%
  ungroup()

hideplot <- plot_ly(qps_cd_odvr,
  x = ~ts,
  y = ~ round(CD_bit_0, 0),
  type = "scatter",
  mode = "lines",
  line = list(color = dashboard_colors[1]),
  name = "CD bit = 0",
  hovertemplate = paste0(
    "<b>", gettext("Date"), "</b>: %{x}<br><b>",
    "CD bit = 0", "</b>: %{y}<br><b><extra></extra>"
  )
) %>%
  add_trace(
    x = ~ts,
    y = ~ round(CD_bit_1, 0),
    type = "scatter",
    mode = "lines",
    line = list(color = dashboard_colors[3]),
    name = "CD bit = 1",
    hovertemplate = paste0(
      "<b>", gettext("Date"), "</b>: %{x}<br><b>",
      "CD bit = 1", "</b>: %{y}<br><b><extra></extra>"
    )
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  layout(
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 2,
            label = gettext("2 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 4,
            label = gettext("4 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Queries per second"),
      tickformat = ",d"
    )
  )
