top_n <- 1000

data <- fromJSONwithToken(
  api_endpoint("/domain_ranking_odvr_ipv_latest",
    order = "sources_magnitude.desc",
    select = "domain,sources,sources_rank,sources_magnitude,ipv"
  )
)

details(
  sprintf(
    gettext("Top 1000 domains by client cardinality magnitude on %s"), format(Sys.Date() - 1, locale_date_format())
  ), # nolint long string
  paste0(
    "<p>",
    gettext("DNS magnitude is a number in the range 0–10 expressing “popularity” of a domain based on client cardinality (number of unique client IP addresses). For details see"), # nolint long string
    " <a href='https://www.nic.at/media/files/pdf/dns-magnitude-paper-20200601.pdf' target='_blank'>Mayrhofer et al. (2000)</a>.</p>" # nolint long string
  )
)

data %>%
  spread(ipv, sources) %>%
  group_by(domain) %>%
  summarise(
    IPV4 = sum(`4`, na.rm = TRUE), IPV6 = sum(`6`, na.rm = TRUE),
    sources_magnitude = mean(sources_magnitude)
  ) %>%
  arrange(desc(sources_magnitude), desc(IPV6)) %>%
  mutate_if(is.numeric, round, digits = 2) %>%
  slice(1:top_n) %>%
  mutate(order = seq(1:top_n), IPV4_IPV6 = IPV4 + IPV6) %>%
  select(order, domain, IPV4_IPV6, IPV6, sources_magnitude) %>%
  kable(
    "html",
    table.attr = "data-search-cols='2'",
    escape = FALSE,
    format.args = list(big.mark = " "),
    align = c("r", "l", "r", "r", "r"),
    col.names = c(
      gettext("Rank"),
      gettext("Domain"),
      gettext("All clients"),
      gettext("IPv6 clients"),
      gettext("Magnitude")
    )
  ) %>%
  column_spec(2, width = "100%") %>%
  column_spec(3, width = "6em") %>%
  column_spec(4, width = "6em") %>%
  column_spec(5, width = "6em") %>%
  kable_styling(
    full_width = TRUE,
    htmltable_class = paste(
      "adam-table-search",
      "adam-table-scroll",
      "adam-table-nowrap",
      "dtable",
      "table-condensed"
    )
  )
