holder <- fromJSON(api_endpoint("/fred_holders_by_cc",
  zone = "eq.cz"
))

country_codes <- load_country_codes() %>%
  rename(
    cc = "country_code"
  )

country_flags <- load_country_flags() |>
  rename(
    cc = "country_code"
  )

df_holders <-
  holder |>
  filter(cc != "CZ") |>
  select(-zone) |>
  mutate(
    cc    = as.factor(cc),
    ts    = as.Date(ts),
    year  = year(ts),
    month = month(ts),
    day   = day(ts)
  ) |>
  group_by(cc, year, month) |>
  filter(day == max(day)) |>
  ungroup() |>
  group_by(cc, year) |>
  filter(month == max(month)) |>
  ungroup()

df_holders <- df_holders |>
  mutate(
    cc =
      fct_lump(cc,
        n           = 11,
        w           = holders,
        other_level = gettext("Other")
      )
  )

df_holders <- df_holders |>
  group_by(year, cc) |>
  reframe(
    holders = sum(holders),
    cc,
    year
  ) |>
  distinct() |>
  ungroup()

df_holders <- df_holders |>
  left_join(country_codes, by = "cc") |>
  left_join(country_flags, by = "cc") |>
  mutate(
    Country = if_else(is.na(Country), gettext("Other"), Country),
    country_flag = if_else(is.na(country_flag), "", country_flag)
  )

final_order <- df_holders |>
  group_by(Country) |>
  filter(year == max(year)) |>
  ungroup() |>
  arrange(holders)
final_order <- as.vector(final_order$Country)

df_holders <- df_holders |>
  arrange(year, factor(Country)) |>
  mutate(Country = fct_relevel(Country, final_order))

plot_ly(
  df_holders,
  type = "bar",
  x = ~holders,
  y = ~Country,
  frame = ~year,
  showlegend = FALSE,
  marker = list(color = "#003893"),
  hoverinfo = "text",
  text = paste0(
    format(df_holders$holders, big.mark = " ")
  ),
  textposition = "inside",
  hovertemplate = paste0(
    df_holders$cc, " ",
    df_holders$country_flag, "<br>",
    gettext("Holders"), ": ", format(df_holders$holders, big.mark = " "), " ",
    "(", df_holders$year, ")",
    "<extra>", "</extra>"
  )
) |>
  layout(
    xaxis =
      list(
        title = gettext("Holders")
      ),
    yaxis =
      list(
        title = FALSE
      )
  ) |>
  animation_opts(
    frame  = 1000,
    easing = "linear",
    redraw = FALSE
  ) |>
  animation_slider(
    label = gettext("Play"),
    currentvalue =
      list(
        prefix = paste0(
          gettext("Year"), ": "
        )
      )
  ) |>
  htmlwidgets::onRender(anim_skip_to_last_frame())
