number_fct_lump <- 14

holder_latest <- fromJSON(api_endpoint(
  "/fred_holders_by_cc_latest",
  zone = "eq.cz"
))

holder_wc_latest <- fromJSONwithToken(api_endpoint(
  "/fred_wc_holders_by_cc_latest",
  predicted = "eq.parked",
  select = "ts,cc,holders"
)) %>%
  rename(parked_holders = holders)

holder_table <- holder_latest %>%
  left_join(holder_wc_latest, by = c("cc")) %>%
  mutate(
    cc = fct_lump_n(cc,
      n = number_fct_lump, w = holders,
      other_level = gettext("Other")
    ),
    parked_holders = ifelse(is.na(parked_holders), 0, parked_holders)
  ) %>%
  group_by(cc) %>%
  summarise(
    holders = sum(holders),
    parked_holders = sum(parked_holders)
  ) %>%
  mutate(
    percent_parked = parked_holders * 100 / holders,
    holders_tile = adam_color_tile(
      holders,
      "white", dashboard_colors[1]
    ),
    percent_parked_tile = adam_color_tile(
      percent_parked,
      "white", dashboard_colors[3]
    )
  )

holder_table %>%
  left_join(country_codes, by = c("cc")) %>%
  mutate(Country = ifelse(is.na(Country),
    gettext("Other"), Country
  )) %>%
  arrange(desc(holders)) %>%
  select(
    Country,
    holders_tile,
    percent_parked_tile
  ) %>%
  kable(
    "html",
    table.attr = "class='dtable'",
    escape = FALSE,
    align = c("r", "c", "c", "c"),
    format.args = list(big.mark = " "),
    col.names = c(
      gettext("Country"), gettext("Holders"),
      gettext("Parked (%)")
    )
  ) %>%
  column_spec(1, bold = TRUE, width = "3cm") %>%
  column_spec(2, width = "3cm") %>%
  column_spec(3, width = "3cm") %>%
  kable_styling(
    bootstrap_options = c("striped", "hover", "condensed", "responsive"),
    full_width = FALSE,
    position = "float_left"
  )
