domains_cc_wc <- fromJSONwithToken(api_endpoint("/fred_wc_domains_by_cc"))

domains_cc_latest <- fromJSON(api_endpoint("/fred_domains_by_cc_latest",
  zone = "eq.cz"
))

country_codes <- load_country_codes() |>
  rename(cc = country_code)

df_domains_country <- domains_cc_latest |>
  inner_join(country_codes, by = c("cc")) |>
  mutate(
    ts = as.Date(ts),
    Country = as.factor(Country),
    Country = fct_lump_n(Country,
      n = 14,
      w = domains,
      other_level = gettext("Other")
    ),
    cc = fct_lump_n(cc,
      n = 14,
      w = domains,
      other_level = gettext("Other")
    )
  ) |>
  group_by(ts, Country, cc) |>
  summarise(count = round(sum(domains), 0)) |>
  ungroup() |>
  select(-ts)

top_cc <- unique(levels(df_domains_country$cc))

df_domains_country_wc <- domains_cc_wc |>
  mutate(ts = as.Date(ts)) |>
  filter(ts == max(ts)) |>
  pivot_wider(
    names_from = predicted,
    values_from = domains,
    values_fill = 0
  ) |>
  mutate(
    parked_perc =
      round(parked * 100 / (http_error + no_content + normal + parked), 2)
  ) |>
  left_join(country_codes, by = "cc")

df_domains_country_wc_other <- domains_cc_wc |>
  mutate(ts = as.Date(ts)) |>
  left_join(country_codes, by = "cc") |>
  filter(ts == max(ts)) |>
  filter(!(cc %in% top_cc)) |>
  group_by(predicted) |>
  summarize(
    ts = unique(ts),
    domains = sum(domains),
    Country = gettext("Other")
  ) |>
  ungroup() |>
  pivot_wider(
    names_from = predicted,
    values_from = domains
  ) |>
  mutate(
    parked_perc =
      round(parked * 100 / (http_error + no_content + normal + parked), 2)
  )

df_domains_top_cc <- df_domains_country_wc |>
  filter(cc %in% top_cc) |>
  bind_rows(df_domains_country_wc_other) |>
  select(-cc) |>
  left_join(df_domains_country, by = "Country") |>
  rename(domains_total = count) |>
  mutate(
    domains_adjusted_unparked = domains_total * (100 - parked_perc) / 100,
    domains_adjusted_parked = domains_total * parked_perc / 100
  )

df_domains_top_cc <- df_domains_top_cc |>
  filter(cc != "CZ")

barchart_order <- df_domains_top_cc |>
  arrange(desc(domains_total)) |>
  filter(Country != gettext("Other")) |>
  select(Country) |>
  add_row(Country = gettext("Other"))
barchart_order <- rev(barchart_order$Country)

df_domains_top_cc |>
  plot_ly(
    x = ~domains_adjusted_unparked,
    y = ~Country,
    type = "bar",
    name = gettext("Non-parked domains"),
    marker = list(color = dashboard_colors[1]),
    hoverinfo = "text",
    textposition = "none",
    text = ~ paste0(
      "<b>", round(df_domains_top_cc$domains_adjusted_unparked, 0), "</b>",
      " ", "non-parked domains",
      " (", 100 - df_domains_top_cc$parked_perc, "%)"
    )
  ) |>
  add_trace(
    x = ~domains_adjusted_parked,
    y = ~Country,
    type = "bar",
    name = gettext("Parked domains"),
    marker = list(color = dashboard_colors[3]),
    hoverinfo = "text",
    textposition = "none",
    text = ~ paste0(
      "<b>", round(df_domains_top_cc$domains_adjusted_parked, 0), "</b>",
      " ", gettext("parked domains"),
      " (", df_domains_top_cc$parked_perc, "%)"
    )
  ) |>
  add_trace(
    name = "additional info",
    showlegend = FALSE,
    marker = list(color = "white"),
    x = 0,
    y = ~Country,
    hoverinfo = "text",
    text = ~ paste0(
      "<b>", df_domains_top_cc$domains_total, "</b>",
      " ", gettext("total domains"), "<br>",
      gettext("Parked ratio estimated on"), " ", df_domains_top_cc$ts
    )
  ) |>
  layout(
    hovermode = "y unified",
    barmode = "stack",
    yaxis =
      list(
        title         = "",
        categoryorder = "array",
        categoryarray = barchart_order
      ),
    xaxis =
      list(
        title = gettext("Domains")
      ),
    legend =
      list(
        orientation = "h",
        xanchor     = "center",
        yanchor     = "bottom",
        x           = 0.5,
        y           = 1
      )
  ) |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local())
