df_transfers <- fromJSON(api_endpoint("/fred_domain_transfers_1day_latest"))

day <- unique(as.Date(df_transfers$ts))
day <- format(day, locale_date_format())

df_transfers <- df_transfers %>%
  mutate(
    registrar_id_from = str_remove_all(registrar_id_from, "REG-"),
    registrar_id_to = str_remove_all(registrar_id_to, "REG-"),
    registrar_id_from = fct_lump_n(registrar_id_from,
      n = 5, ties.method = "first",
      other_level = gettext("Other")
    ),
    registrar_id_to = fct_lump_n(registrar_id_to,
      n = 5, ties.method = "first",
      other_level = gettext("Other")
    )
  ) %>%
  group_by(registrar_id_from, registrar_id_to) %>%
  summarise(domains = sum(domains))

df_transfers_remove <- df_transfers %>%
  filter(registrar_id_from == gettext("Other") &
           registrar_id_to == gettext("Other"))

df_transfers <- setdiff(df_transfers, df_transfers_remove)

f_levels <- unique(c(
  as.character(df_transfers$registrar_id_from),
  as.character(df_transfers$registrar_id_to)
))

df_transfers <- df_transfers %>%
  mutate(registrar_id_from = factor(registrar_id_from,
    levels = f_levels
  )) %>%
  mutate(registrar_id_to = factor(registrar_id_to,
    levels = f_levels
  ))

m_transfers <- unclass(xtabs(domains ~ ., df_transfers))

details(
  sprintf(
    gettext("Chord diagram of domain transfers between registrars on %s"), day
  ), # nolint long string
  gettext(
    "A chord diagram represents flows between several entities, each represented by a segment on the outer part of the circular layout. Chords (arcs) are drawn between each pair of entities, representing bi-directional transfers between them. The size of a chord is proportional to the magnitude of the flow." # nolint long string
  )
)

chorddiag(m_transfers,
  groupColors = dashboard_pal(length(f_levels)),
  showTicks = FALSE,
  groupnameFontsize = 12,
  groupnamePadding = 10,
  height = 650
)
