df_transfers_month <-
  fromJSON(api_endpoint("/fred_domain_transfers",
    ts = get_ts(months, 1),
    window = "eq.1 mon"
  )) %>%
  mutate(ts = as.Date(ts)) %>%
  filter(ts == max(ts)) %>%
  mutate(
    registrar_id_from = fct_lump_n(registrar_id_from,
      n = 10, w = domains,
      other_level = gettext("Other")
    ),
    registrar_id_to = fct_lump_n(registrar_id_to,
      n = 10, w = domains,
      other_level = gettext("Other")
    ),
    registrar_id_from = str_remove_all(registrar_id_from, "REG-"),
    registrar_id_to = str_remove_all(registrar_id_to, "REG-")
  ) %>%
  group_by(registrar_id_from, registrar_id_to) %>%
  summarise(domains = sum(domains)) %>%
  mutate(Total = sum(domains))

heatmap <- ggplot(
  df_transfers_month,
  aes(registrar_id_from, registrar_id_to,
    fill = domains
  )
) +
  geom_tile() +
  geom_text(aes(label = domains),
    colour = "white",
    size = 3.5
  ) +
  labs(
    x = gettext("Outgoing domains"),
    y = gettext("Incoming domains"),
    fill = gettext("Domains")
  ) +
  theme_classic() +
  scale_fill_gradient(low = dashboard_colors[1], high = dashboard_colors[3]) +
  theme(
    axis.text.x = element_text(angle = 45),
    axis.text = element_text(size = 8)
  )

ggplotly(heatmap, height = 650) %>%
  config(displayModeBar = FALSE) %>%
  layout(
    margin = list(t = 50),
    xaxis = list(fixedrange = TRUE),
    hovermode = FALSE
  ) %>%
  layout(yaxis = list(fixedrange = TRUE))
