num_fct_lump <- 11

registrar_latest <- fromJSON(api_endpoint(
  "/fred_domains_by_registrar_latest",
  zone = "eq.cz"
)) %>%
  mutate(
    registrar_id = str_remove_all(registrar_id, "REG-"),
    ts = as.Date(ts)
  )


dnssec_registrars <- fromJSONwithToken(
  api_endpoint("/fred_dnssec_domains_by_registrar_latest")
) %>%
  filter(zone == "cz") %>%
  mutate(
    registrar_id = str_remove_all(registrar_id, "REG-"),
    ts = as.Date(ts)
  ) %>%
  rename(dnssec_domains = domains)

parked_registrars <- fromJSONwithToken(
  api_endpoint("/fred_wc_domains_by_registrar_latest")
) %>%
  filter(predicted == "parked") %>%
  mutate(
    registrar_id = str_remove_all(registrar_id, "REG-"),
    ts = as.Date(ts)
  ) %>%
  rename(parked_domains = domains)

registrar_table <- registrar_latest %>%
  left_join(dnssec_registrars) %>%
  inner_join(parked_registrars, by = c("registrar_id")) %>%
  mutate(
    registrar_id = fct_lump_n(registrar_id,
      n = num_fct_lump, w = domains,
      other_level = gettext("other")
    ),
    dnssec_domains = ifelse(is.na(dnssec_domains), 0, dnssec_domains)
  ) %>%
  group_by(registrar_id) %>%
  summarise(
    domains = sum(domains),
    dnssec_domains = sum(dnssec_domains),
    parked_domains = sum(parked_domains)
  ) %>%
  mutate(
    percent_dnssec = dnssec_domains * 100 / domains,
    percent_parked = parked_domains * 100 / domains,
    domains_tile = adam_color_tile(
      domains,
      "white", dashboard_colors[1]
    ),
    percent_dnssec_tile = adam_color_tile(
      percent_dnssec,
      "white", dashboard_colors[3]
    ),
    percent_parked_tile = adam_color_tile(
      percent_parked,
      "white", dashboard_colors[3]
    )
  )


registrar_table %>%
  arrange(desc(domains)) %>%
  select(
    registrar_id,
    domains_tile,
    percent_dnssec_tile,
    percent_parked_tile
  ) %>%
  kable(
    "html",
    table.attr = "class='dtable'",
    escape = FALSE,
    align = c("r", "c", "c", "c", "c"),
    format.args = list(big.mark = " "),
    col.names = c(
      gettext("Registrar"), gettext("Domains"),
      gettext("DNSSEC (%)"),
      gettext("Parked (%)")
    )
  ) %>%
  column_spec(1, bold = TRUE, width = "3cm") %>%
  column_spec(2, width = "3cm") %>%
  column_spec(3, width = "3cm") %>%
  column_spec(4, width = "3cm") %>%
  kable_styling(
    bootstrap_options = c("striped", "hover", "condensed", "responsive"),
    full_width = FALSE,
    position = "float_left"
  )
