current_year <- as.integer(format(Sys.Date(), "%Y"))
n <- 10

country_codes <- load_country_codes() %>%
  rename(
    cc = "country_code"
  )

# colorblind palette
report_colors_slope <- c(
  "#999999", "#E69F00", "#56B4E9", "#009E73",
  "#F0E442", "#0072B2", "#D55E00", "#CC79A7", "#000000"
)
report_pal_slope <- colorRampPalette(report_colors_slope)
# It is only needed to add the new year to the line 62

holder <- fromJSON(api_endpoint("/fred_holders_by_cc",
  zone = "eq.cz"
))

holder_cc_2022 <-
  holder %>%
  inner_join(country_codes, by = c("cc")) %>%
  mutate(
    ts = as.Date(ts),
    Year = year(ts),
    Day = days_in_month(ts),
    day_logins = day(ts)
  ) %>%
  filter(Year >= current_year) %>%
  filter(cc != "CZ") %>%
  filter(ts == max(ts)) %>%
  mutate(
    Country = as.factor(Country),
    Country = fct_lump_n(Country,
      n = n, w = holders,
      other_level = gettext("Other")
    )
  ) %>%
  group_by(ts, Country, Year) %>%
  summarise(holders = sum(holders)) %>%
  mutate(Year = paste0(ts)) %>%
  ungroup()

df_cc <- as.data.frame(holder_cc_2022$Country) %>%
  rename(Country = `holder_cc_2022$Country`) %>%
  filter(Country != gettext("Other")) %>%
  mutate(value = Country)



holder_cc_old <-
  holder %>%
  filter(cc != "CZ") %>%
  inner_join(country_codes, by = c("cc")) %>%
  left_join(df_cc, by = c("Country")) %>%
  mutate(
    ts = as.Date(ts),
    Year = year(ts),
    value = coalesce(value, gettext("Other"))
  ) %>%
  select(-Country) %>%
  rename(Country = value) %>%
  mutate(
    Day = days_in_month(ts),
    day_logins = day(ts),
    month = month(ts)
  ) %>%
  filter(
    Year < current_year,
    Day == day_logins,
    month == 12
  ) %>%
  group_by(ts, Country, Year) %>%
  summarise(holders = sum(holders)) %>%
  ungroup()




holder_cc_2020 <-
  holder %>%
  inner_join(country_codes, by = c("cc")) %>%
  left_join(df_cc, by = c("Country")) %>%
  mutate(
    ts = as.Date(ts),
    Year = year(ts),
    value = coalesce(value, gettext("Other"))
  ) %>%
  select(-Country) %>%
  rename(Country = value) %>%
  filter(cc != "CZ", Year == 2020) %>%
  filter(ts >= max(ts)) %>%
  group_by(ts, Country, Year) %>%
  summarise(holders = sum(holders)) %>%
  ungroup()



holder_total <- rbind(
  holder_cc_old,
  holder_cc_2020,
  holder_cc_2022
) %>%
  filter(Year >= current_year - 4) %>%
  mutate(
    Country = as.character(Country),
    Country = ifelse(Country == gettext("United Kingdom"),
      gettext("UK"),
      ifelse(Country == gettext("United States"),
        gettext("USA"), Country
      )
    ),
    Year = as.factor(Year)
  ) %>%
  ungroup() %>%
  arrange(ts)



fig <- holder_total %>%
  ggplot(aes(Year, holders,
    group = Country,
    color = Country,
    text = paste0(
      Year, "\n", Country, "\n",
      gettext("Holders"), ": ", format(holders, big.mark = " ")
    )
  )) +
  geom_path() +
  geom_point(size = 0.8) +
  theme(
    plot.title = element_text(size = 10),
    text.legend = element_text(size = 8)
  ) +
  theme_minimal() +
  labs(x = gettext("Year"), y = gettext("Holders")) +
  scale_color_manual(
    name = gettext("Country"),
    values = report_pal_slope(n_distinct(holder_total$Country))
  ) +
  scale_y_continuous(
    labels = function(x) format(x, scientific = FALSE, big.mark = " ")
  )


ggplotly(fig, tooltip = "text") %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(xaxis = list(fixedrange = TRUE)) %>%
  layout(yaxis = list(fixedrange = TRUE))
