current_year <- as.integer(format(Sys.Date(), "%Y"))
n <- 11

# colorblind palette
report_colors_slope <- c(
  "#999999", "#E69F00", "#56B4E9", "#009E73",
  "#F0E442", "#0072B2", "#D55E00", "#CC79A7", "#000000"
)
report_pal_slope <- colorRampPalette(report_colors_slope)

domain <- fromJSON(api_endpoint("/fred_domains_by_registrar",
  zone = "eq.cz"
))

domain_reg_2022 <-
  domain %>%
  mutate(
    ts = as.Date(ts),
    Year = year(ts),
    Day = days_in_month(ts),
    day_logins = day(ts)
  ) %>%
  filter(Year >= current_year) %>%
  filter(ts == max(ts)) %>%
  mutate(
    registrar_id = as.factor(registrar_id),
    registrar_id = fct_lump_n(registrar_id,
      n = n, w = domains,
      other_level = gettext("Other")
    )
  ) %>%
  group_by(ts, registrar_id, Year) %>%
  summarise(domains = sum(domains)) %>%
  mutate(Year = paste0(ts)) %>%
  ungroup()

df_reg <- as.data.frame(domain_reg_2022$registrar_id) %>%
  rename(registrar_id = `domain_reg_2022$registrar_id`) %>%
  filter(registrar_id != gettext("Other")) %>%
  mutate(value = registrar_id)



domain_reg_old <-
  domain %>%
  left_join(df_reg, by = c("registrar_id")) %>%
  mutate(
    ts = as.Date(ts),
    Year = year(ts),
    value = coalesce(value, gettext("Other"))
  ) %>%
  select(-registrar_id) %>%
  rename(registrar_id = value) %>%
  mutate(
    Day = days_in_month(ts),
    day_logins = day(ts),
    month = month(ts)
  ) %>%
  filter(
    Year < current_year,
    Day == day_logins,
    month == 12
  ) %>%
  group_by(ts, registrar_id, Year) %>%
  summarise(domains = sum(domains)) %>%
  ungroup()




domain_reg_2020 <-
  domain %>%
  left_join(df_reg, by = c("registrar_id")) %>%
  mutate(
    ts = as.Date(ts),
    Year = year(ts),
    value = coalesce(value, gettext("Other"))
  ) %>%
  select(-registrar_id) %>%
  rename(registrar_id = value) %>%
  filter(Year == 2020) %>%
  filter(ts >= max(ts)) %>%
  group_by(ts, registrar_id, Year) %>%
  summarise(domains = sum(domains)) %>%
  ungroup()



domain_total <- rbind(
  domain_reg_old,
  domain_reg_2020,
  domain_reg_2022
) %>%
  filter(Year >= current_year - 4) %>%
  mutate(
    registrar_id = as.character(registrar_id),
    registrar_id = str_remove_all(registrar_id, "REG-"),
    Year = as.factor(Year)
  ) %>%
  ungroup() %>%
  arrange(ts)



fig <- domain_total %>%
  ggplot(aes(Year, domains,
    group = registrar_id,
    color = registrar_id,
    text = paste0(
      Year, "\n", registrar_id, "\n",
      gettext("Domains"), ": ", format(domains, big.mark = " ")
    )
  )) +
  geom_path() +
  geom_point(size = 0.8) +
  theme(
    plot.title = element_text(size = 10),
    text.legend = element_text(size = 8)
  ) +
  theme_minimal() +
  labs(x = gettext("Year"), y = gettext("Domains")) +
  scale_color_manual(
    name = gettext("Registrar"),
    values = report_pal_slope(n_distinct(domain_total$registrar_id))
  ) +
  scale_y_continuous(
    labels = function(x) format(x, scientific = FALSE, big.mark = " ")
  )


ggplotly(fig, tooltip = "text") %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(xaxis = list(fixedrange = TRUE)) %>%
  layout(yaxis = list(fixedrange = TRUE))
