total_dnssec <- fromJSON(api_endpoint("/fred_dnssec_domains",
  zone = "eq.cz"
)) %>%
  group_by(ts) %>%
  summarise(dnssec_domains = sum(domains)) %>%
  mutate(ts = as.Date(ts))

endpoint <- api_endpoint("/fred_domains", zone = "eq.cz")

total_dom <- fromJSON(api_endpoint("/fred_domains", zone = "eq.cz")) %>%
  mutate(
    ts = as.Date(ts),
    year = year(ts)
  ) %>%
  group_by(year) %>%
  filter(ts == max(ts)) %>%
  select(year, ts, domains) %>%
  ungroup() %>%
  mutate(year = as.numeric(year)) %>%
  arrange(desc(year))

details(
  gettext("Number of second-level domains registered in .CZ"),
  gettext("The domain counts correspond to the end of each year, and the present day for the current year.") # nolint long string
)

plot_ly(total_dom,
  x = ~year,
  y = ~domains,
  type = "bar",
  name = gettext("Domains"),
  marker = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    "<extra></extra>",
    "<b>", gettext("Count"), "</b>: ", formatC(total_dom$domains,
      big.mark = " "
    )
  )
) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  onRender(add_csv_button(endpoint)) %>%
  layout(
    hovermode = "x unified",
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 3,
            label = gettext("3 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(title = gettext("Number of domains"))
  )
