mojeid_nia_1d <- fromJSON(api_endpoint("/mojeid_nia_logins_1d",
  order = "ts.asc", ts = get_ts(days, 30)
)) %>%
  mutate(ts = as.Date(ts)) %>%
  rename(nia_logins = logins)

df_mojeid_logins_1d <- fromJSON(api_endpoint("/mojeid_logins",
  order = "ts.asc", ts = get_ts(days, 30)
)) %>%
  mutate(
    ts = as.Date(ts),
    weekday = weekdays(ts)
  ) %>%
  left_join(mojeid_nia_1d, by = c("ts")) %>%
  mutate(ratio = nia_logins / logins) %>%
  rowwise() %>%
  mutate(other_logins = sum(logins, -nia_logins, na.rm = TRUE)) %>%
  ungroup()

plot_summary <- plot_ly(df_mojeid_logins_1d,
  x = ~ts,
  y = ~logins,
  text = ~weekday,
  name = gettext("Total logins"),
  line = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    "<b>", gettext("Date"), "</b>: %{x} (%{text})<br>",
    "<b>", gettext("Total logins"),
    "</b>: %{y}<br><extra></extra>"
  )
) %>%
  add_lines() %>%
  add_trace(
    y = ~nia_logins,
    name = gettext("NIA logins"),
    mode = "lines",
    hovertemplate = paste0(
      "<b>", gettext("Date"), "</b>: %{x} (%{text})<br>",
      "<b>", gettext("NIA logins"), "</b>: %{y}<br><extra></extra>"
    ),
    line = list(color = dashboard_colors[3])
  ) %>%
  config(displayModeBar = FALSE, locale = locale_lang_code()) %>%
  htmlwidgets::onRender(add_csv_button(
    api_endpoint("/mojeid_combined_logins_1d", order = "ts.asc")
  )) %>%
  layout(
    separators = ".\u202F",
    yaxis = list(
      title = gettext("Number of logins"),
      tickformat = ",d"
    ),
    xaxis = list(title = gettext("Date"))
  )

plot_summary
