df_qps_cc_city <- fromJSONwithToken(api_endpoint("/tmobile_qps_cc_city_1h", ts = get_ts(days, 7)))


country_codes <- load_country_codes() |>
  rename(
    client_country_code = "country_code",
    client_country = "Country"
  )

df_data <- df_qps_cc_city %>%
  left_join(country_codes, by = c("client_country_code")) %>%
  rename(ISO2 = client_country_code) %>%
  group_by(ISO2, server_location, client_country) %>%
  summarise(qps = mean(qps)) %>%
  group_by(ISO2, client_country) %>%
  filter(qps == max(qps)) %>%
  mutate(
    server_location = ifelse(is.na(server_location),
                             "Undisclosed", server_location)
  )



legend <- df_data %>%
  group_by(server_location) %>%
  summarise(n = n())

legend$color <- colorRampPalette(brewer.pal(12, "Paired"))(length(legend$server_location))

df_data <- inner_join(df_data, legend)

data(wrld_simpl)

map_by_country <- sp::merge(
  wrld_simpl,
  df_data,
  by = c("ISO2"),
  all.x = TRUE,
  duplicateGeoms = TRUE,
  no.dups = FALSE
)


map_by_country@data$country <- countrycode(
  map_by_country@data$ISO2,
  "iso2c", "country.name"
)


m <- leaflet(
  map_by_country,
  width = "100%",
  options = tileOptions(minZoom = 1, maxZoom = 5)
) %>%
  setView(lng = 15, lat = 35, zoom = 1.2) %>%
  addPolygons(
    label = ~ lapply(sprintf(
      "<center>%s<BR><B>%s</B></center>",
      country,
      server_location
    ), HTML),
    weight = 1,
    color = "gray",
    fillColor = ~color,
    fillOpacity = 0.7,
    labelOptions = labelOptions(direction = "auto"),
    smoothFactor = 0.5
  ) %>%
  addPolylines(
    data = map_by_country,
    weight = 0.2,
    color = "gray",
    fillOpacity = 0.1,
    opacity = 1
  ) %>%
  setMapWidgetStyle(
    list(background = "white")
  ) %>%
  addLegend(
    data = legend,
    title = gettext("Main server location by country"),
    colors = ~color, labels = ~server_location, opacity = 0.7,
    position = "bottomright"
  ) %>%
  suspendScroll(sleepOpacity = 1, sleepNote = FALSE)

m$x$options <- append(m$x$options, list(
  "zoomControl" = FALSE,
  "dragging" = TRUE, "attributionControl" = FALSE
))

m
