server_cc <- fromJSONwithToken(api_endpoint("/all_dns_server_locations"))

df <- fromJSONwithToken(api_endpoint("/tmobile_qps_server_1h",
  ts = get_ts(days, 30)
))

n_round <- 5

qps_server_1h <- df %>%
  left_join(server_cc, by = c("server" = "server_name")) %>%
  mutate(city = ifelse(is.na(city), gettext("undisclosed"), city))

df_qps_server_traffic <- qps_server_1h %>%
  mutate(city = as.factor(city), ts = as.Date(ts)) %>%
  group_by(ts, city) %>%
  summarise(qps = sum(qps)) %>%
  mutate(queries = qps * 3600, queries_24h = queries / 86400)


df_qps_server_traffic_table <- df_qps_server_traffic %>%
  group_by(city) %>%
  summarise(
    qps_max = round(max(queries_24h), 0),
    qps_min = round(min(queries_24h), 0)
  ) %>%
  ungroup() %>%
  mutate(
    qps_max_tile = adam_color_tile2(qps_max, "white", dashboard_colors[1], decimals = n_round),
    qps_min_tile = adam_color_tile2(qps_min, "white", dashboard_colors[1], decimals = n_round)
  ) %>%
  inner_join(
    df_qps_server_traffic %>%
      group_by(city) %>%
      summarise(
        qps_current = mean(queries_24h)
      ) %>%
      ungroup() %>%
      mutate(
        qps_current_tile = adam_color_tile2(
          qps_current,
          "white", dashboard_colors[3],
          decimals = n_round
        )
      ),
    by = c("city")
  )

df_qps_server_traffic_spark <- df_qps_server_traffic %>%
  arrange(ts) %>%
  group_by(city) %>%
  summarise(
    queries_bar = spk_chr(
      queries_24h,
      type = "line",
      lineColor = sparkline_colors[1],
      fillColor = sparkline_colors[2],
      spotColor = TRUE,
      width = 80
    )
  )


htmltools::attachDependencies(
  htmltools::div(),
  html_dependency_sparkline()
)


df_qps_server_traffic_table %>%
  left_join(df_qps_server_traffic_spark, by = "city") %>%
  arrange(desc(qps_current)) %>%
  select(
    city,
    qps_max_tile,
    qps_min_tile,
    queries_bar,
    qps_current_tile
  ) %>%
  kable(
    "html",
    table.attr = "class='dtable'",
    escape = FALSE,
    align = c("r", "c", "c", "c", "c"),
    format.args = list(big.mark = " "),
    col.names = c(
      gettext("City"), "Max QPS", "Min QPS",
      "Trend", gettext("Average")
    )
  ) %>%
  column_spec(1, bold = TRUE, width = "3cm") %>%
  column_spec(2, width = "3cm") %>%
  column_spec(3, width = "3cm") %>%
  column_spec(4, width = "3cm") %>%
  column_spec(5, width = "3cm") %>%
  kable_styling(
    bootstrap_options = c("striped", "hover", "condensed", "responsive"),
    full_width = TRUE,
    position = "left"
  )
