crawler_ns_location_cc <- fromJSON(api_endpoint("/crawler_ns_location_cc_latest"
)
)

country_codes <- load_country_codes() %>%
  rename(cc = country_code)

crawler_location <- crawler_ns_location_cc %>%
  inner_join(country_codes, by = c("cc")) %>%
  mutate(ts = as.Date(ts)) %>%
  filter(ts == max(ts)) %>%
  mutate(Country = as.factor(Country)) %>%
  ungroup() %>%
  mutate(Country = fct_lump_n(Country, n = 7, w = domains,
                              other_level = gettext("other"))) %>%
  group_by(ts, Country, ipv) %>%
  summarise(domains = sum(domains), servers = sum(servers))

crawler_location_ipv4 <- crawler_location %>%
  filter(ipv == 4) %>%
  ungroup() %>%
  mutate(
    domains_IPV4_tile = adam_color_tile(domains, "white", dashboard_colors[1]),
    servers_IPV4_tile = adam_color_tile(servers, "white", dashboard_colors[1])
  )

crawler_location_ipv6 <- crawler_location %>%
  filter(ipv == 6) %>%
  ungroup() %>%
  mutate(
    domains_IPV6_tile = adam_color_tile(domains, "white", dashboard_colors[3]),
    servers_IPV6_tile = adam_color_tile(servers, "white", dashboard_colors[3])
  )

crawler_location_ipv4 %>%
  inner_join(crawler_location_ipv6, by = c("ts", "Country")) %>%
  ungroup() %>%
  arrange(desc(domains.x)) %>%
  select(
    Country,
    domains_IPV4_tile,
    servers_IPV4_tile,
    domains_IPV6_tile,
    servers_IPV6_tile
  ) %>%
  kable(
    "html",
    escape = FALSE,
    align = c("r", "c", "c", "c", "c", "c"),
    format.args = list(big.mark = " "),
    col.names =
      c(gettext("Country"),
        gettext("Domains"),
        gettext("Servers"),
        gettext("Domains"),
        gettext("Servers")
      )
  ) %>%
  column_spec(1, bold = TRUE, width = "7cm") %>%
  column_spec(2, width = "6cm") %>%
  column_spec(3, width = "6cm") %>%
  column_spec(4, width = "6cm") %>%
  column_spec(5, width = "6cm") %>%
  add_header_above(c(" ", "IPv4" = 2, "IPv6" = 2)) %>%
  kable_styling(
    bootstrap_options = c("striped", "hover", "condensed", "responsive"),
    full_width = FALSE,
    position = "left"
  )
