crawler_ns_location_as <- fromJSON(api_endpoint("/crawler_ns_location_as_latest"
)
)

crawler_location_as <- crawler_ns_location_as %>%
  mutate(ts = as.Date(ts)) %>%
  filter(ts == max(ts)) %>%
  mutate(as = as.factor(as)) %>%
  mutate(as = fct_lump_n(as, n = 7, w = domains,
                         other_level = gettext("other")),
         as = as.character(as),
         as = ifelse(is.na(as), gettext("other"), as)) %>%
  group_by(ts, as, ipv) %>%
  summarise(domains = sum(domains), servers = sum(servers)) %>%
  ungroup()

crawler_location_as <- crawler_location_as  %>%
  mutate(as = stringr::str_remove_all(as, ",? a\\.s\\."),
    as = stringr::str_remove_all(as, " B\\.V\\."),
    as = stringr::str_remove_all(as, " GmbH"),
    as = stringr::str_remove_all(as, ",? s\\.r\\.o\\."),
    as = stringr::str_remove_all(as, " S\\.p\\.A\\.")
  )

crawler_location_as_sep <- separate(crawler_location_as, as,
                                    into = c("AS", "Provider"),
                                    sep = "[[:space:]]+", extra = "merge")


crawler_location_as_sep[is.na(crawler_location_as_sep)] <- gettext("other")


crawler_location_as_ipv4 <- crawler_location_as_sep %>%
  filter(ipv == 4) %>%
  ungroup() %>%
  mutate(
    domains_IPV4_tile = adam_color_tile(domains, "white", dashboard_colors[1]),
    servers_IPV4_tile = adam_color_tile(servers, "white", dashboard_colors[1])
  )

crawler_location_as_ipv6 <- crawler_location_as_sep %>%
  filter(ipv == 6) %>%
  ungroup() %>%
  mutate(
    domains_IPV6_tile = adam_color_tile(domains, "white", dashboard_colors[3]),
    servers_IPV6_tile = adam_color_tile(servers, "white", dashboard_colors[3])
  )

crawler_location_as_ipv4 %>%
  inner_join(crawler_location_as_ipv6, by = c("ts", "AS")) %>%
  ungroup() %>%
  select(
    AS,
    Provider.x,
    domains_IPV4_tile,
    servers_IPV4_tile,
    domains_IPV6_tile,
    servers_IPV6_tile
  ) %>%
  kable(
    "html",
    escape = FALSE,
    align = c("r", "l", "c", "c", "c", "c", "c"),
    format.args = list(big.mark = " "),
    col.names = c(
                  "AS",
                  gettext("Providers"),
                  gettext("Domains"),
                  gettext("Servers"),
                  gettext("Domains"),
                  gettext("Servers"))
  ) %>%
  column_spec(1, bold = TRUE, width = "5cm") %>%
  column_spec(2, bold = TRUE, width = "5cm") %>%
  column_spec(3, width = "4cm") %>%
  column_spec(4, width = "4cm") %>%
  column_spec(5, width = "4cm") %>%
  column_spec(6, width = "4cm") %>%
  add_header_above(c(" ", " ", "IPv4" = 2, "IPv6" = 2)) %>%
  kable_styling(
    bootstrap_options = c("striped", "hover", "condensed", "responsive"),
    full_width = FALSE,
    position = "float_left"
  )
