df_auctioned_domains <-
  fromJSONwithToken(api_endpoint("/auctions_auctions_summary"))

df_auctioned_domains <- df_auctioned_domains |>
  select(date, auctioned) |>
  mutate(date = as.Date(date)) |>
  filter(date >= Sys.Date() - 30) |>
  arrange(date)

export_locale <- Sys.getlocale(category = "LC_COLLATE") |>
  stri_sub(
    from = 1L,
    to = 2L
  )

fig_auctioned_domains <- plot_ly(
  name = gettext("Auctioned domains"),
  type = "bar",
  x = ~date,
  y = ~auctioned,
  data = df_auctioned_domains,
  marker = list(color = dashboard_colors[1]),
  text = ~auctioned,
  textposition = "outside"
) |>
  config(locale = export_locale) |>
  layout(
    hovermode = "x unified",
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Date"),
      tickformat = locale_date_format(),
      ticks = "outside"
    ),
    yaxis = list(
      title = gettext("Count of auctioned domains"),
      tickformat = ",d"
    )
  )

save_image(fig_auctioned_domains,
  file =
    paste0(
      "../images/auctions_auctioned_domains_",
      export_locale,
      ".svg"
    )
)
