df_amounts_day <- fromJSONwithToken(api_endpoint("/auctions_auctions_summary")) |>
  select(date, tot_sum, paid) |>
  mutate(
    ts = as.Date(date),
    paid = replace_na(paid, 0),
    tot_sum = replace_na(tot_sum, 0),
    perc = round(paid * 100 / tot_sum, 2)
  ) |>
  arrange(ts)


plot1 <- plot_ly(
  df_amounts_day,
  x = ~ts,
  y = ~tot_sum,
  type = "scatter",
  mode = "lines",
  hovertemplate = ~ paste0(
    "<b>", gettext("Auctioned sum"),
    "</b>: ", formatC(tot_sum, big.mark = " "),
    " ", gettext("CZK"), "<extra></extra>"
  ),
  name = gettext("Auctioned sum"),
  line = list(color = dashboard_colors[1]),
  hoverinfo = "text"
) |>
  add_trace(
    y = ~paid,
    name = gettext("Paid sum"),
    mode = "lines",
    hovertemplate = ~ paste0(
      "<b>", gettext("Paid sum"),
      "</b>: ", formatC(paid, big.mark = " "),
      " ", gettext("CZK"), "<extra></extra>"
    ),
    line = list(color = dashboard_colors[3])
  ) |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local()) |>
  layout(
    hovermode = "x unified",
    margin = list(t = 75),
    title = gettext("Daily auctioned and paid sum"),
    legend = list(
      orientation = "h",
      xanchor = "center",
      x = 0.5,
      y = 1.08
    ),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 7,
            label = gettext("7 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 15,
            label = gettext("15 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title      = gettext("Sum (CZK)"),
      tickformat = ",d"
    )
  )


ratio <- plot_ly(df_amounts_day,
  x = ~ts,
  y = ~perc,
  type = "scatter",
  name = paste0(
    gettext("Ratio of paid sum"), " (%)"
  ),
  mode = "lines",
  line = list(color = dashboard_colors[2]),
  hovertemplate = paste0(
    "<b>",
    gettext("Auctioned sum"), "</b>: ",
    formatC(df_amounts_day$tot_sum, big.mark = " "),
    " ", gettext("CZK"), "<br><b>",
    gettext("Paid sum"), "</b>: ",
    formatC(df_amounts_day$paid,
      big.mark = " "
    ),
    " ", gettext("CZK"), "<br><b>",
    gettext("Ratio (%)"), "</b>: %{y}<br><b><extra></extra>"
  )
) %>%
  layout(
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 7,
            label = gettext("7 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 15,
            label = gettext("15 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date"),
        x = 0.8
      )
    ),
    yaxis = list(
      title = paste0(
        gettext("Ratio of paid sum"), " (%)"
      ),
      ticksuffix = "%"
    )
  )



subplot(plot1, ratio,
  margin = 0.06, titleX = TRUE, titleY = TRUE, nrows = 1, shareX = TRUE
) %>%
  layout(
    hovermode = "x unified",
    autosize = TRUE,
    xaxis = list(showgrid = TRUE, zeroline = FALSE),
    yaxis = list(showgrid = TRUE, zeroline = FALSE)
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local())
