df_amounts_month <- fromJSONwithToken(api_endpoint("/auctions_auctions_summary")) |>
  select(date, tot_sum, paid) |>
  mutate(
    ts = as.Date(date),
    paid = replace_na(paid, 0),
    tot_sum = replace_na(tot_sum, 0)
  )



df_amounts_month <- df_amounts_month |>
  mutate(ts = as.Date(ts), month = month(ts), year = year(ts)) |>
  group_by(month, year) |>
  mutate(
    month_start = min(ts),
    month_end = max(ts)
  ) |>
  group_by(month, year, month_start, month_end) |>
  summarise(
    tot_sum = sum(tot_sum), paid = sum(paid),
    perc = round(paid * 100 / tot_sum, 2)
  ) |>
  ungroup()  |>
  arrange(month_end)

plot2 <- plot_ly(df_amounts_month,
  x = ~month_end,
  y = ~tot_sum,
  name = gettext("Auctioned sum"),
  line = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    "<b>", gettext("Auctioned sum"),
    "</b>: %{y} ", gettext("CZK"), "<extra></extra>"
  )
) |>
  add_lines() |>
  add_trace(
    y = ~paid, name = gettext("Paid sum"),
    mode = "lines",
    hovertemplate = paste0(
      "<b>", gettext("Paid sum"), "</b>: %{y} ",
      gettext("CZK"), "<extra></extra>"
    ),
    line = list(color = dashboard_colors[3])
  ) |>
  layout(
    hovermode = "x unified",
    margin = list(t = 75),
    title = gettext("Monthly auctioned and paid sum"),
    legend = list(
      orientation = "h",
      xanchor = "center",
      x = 0.5,
      y = 1.08
    ),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Month"),
      rangeselector = list(
        buttons = list(
          list(
            count = 3,
            label = gettext("3 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 3,
            label = gettext("3 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Sum (CZK)"),
      tickformat = ",d"
    )
  )

ratio <- plot_ly(df_amounts_month,
  x = ~month_end,
  y = ~perc,
  type = "scatter",
  name = paste0(
    gettext("Ratio of paid sum"), " (%)"
  ),
  mode = "lines",
  line = list(color = dashboard_colors[2]),
  hovertemplate = paste0(
    "<b>",
    gettext("Auctioned sum"), "</b>: ",
    formatC(df_amounts_month$tot_sum, big.mark = " "),
    " ", gettext("CZK"), "<br><b>",
    gettext("Paid sum"), "</b>: ",
    formatC(df_amounts_month$paid,
      big.mark = " "
    ), " ", gettext("CZK"), "<br><b>",
    gettext("Ratio (%)"), "</b>: %{y}<br><b><extra></extra>"
  )
) %>%
  layout(
    xaxis = list(
      title = gettext("Month"),
      rangeselector = list(
        buttons = list(
          list(
            count = 3,
            label = gettext("3 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 3,
            label = gettext("3 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date"),
        x = 0.8
      )
    ),
    yaxis = list(
      title = paste0(
        gettext("Ratio of paid sum"), " (%)"
      ),
      ticksuffix = "%"
    )
  )



subplot(plot2, ratio,
  margin = 0.06, titleX = TRUE, titleY = TRUE, nrows = 1, shareX = TRUE
) %>%
  layout(
    hovermode = "x unified",
    autosize = TRUE,
    xaxis = list(showgrid = TRUE, zeroline = FALSE),
    yaxis = list(showgrid = TRUE, zeroline = FALSE)
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local())
