df_auctioned_total_sum <-
  fromJSONwithToken(api_endpoint("/auctions_auctions_summary"))

df_auctioned_total_sum <- df_auctioned_total_sum |>
  select(date, tot_sum, paid) |>
  mutate(
    date = as.Date(date),
    paid = replace_na(paid, 0),
    tot_sum = replace_na(tot_sum, 0)
  ) |>
  filter(date >= Sys.Date() - 30) |>
  arrange(date)

plot_ly(
  type = "bar",
  name = gettext("Auctioned sum"),
  x = ~date,
  y = ~tot_sum,
  data = df_auctioned_total_sum,
  marker = list(color = dashboard_colors[1]),
  showlegend = TRUE,
  hovertemplate = paste0(
    "<b>", gettext("Auctioned sum"), "</b>: ",
    formatC(df_auctioned_total_sum$tot_sum, big.mark = " "),
    " ", gettext("CZK"),
    "<extra></extra>"
  )
) |>
  add_trace(
    name = gettext("Paid sum"),
    y = ~paid,
    marker = list(color = dashboard_colors[3]),
    showlegend = TRUE,
    hovertemplate = paste0(
      "<b>", gettext("Paid sum"), "</b>: ",
      formatC(df_auctioned_total_sum$paid, big.mark = " "),
      " ", gettext("CZK"),
      "<extra></extra>"
    ),
    showlegend = TRUE
  ) |>
  layout(
    hovermode = "x unified",
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Date"),
      ticks = "outside"
    ),
    yaxis = list(
      title = gettext("Sum (CZK)"),
      tickformat = ",d"
    ),
    legend = list(
      orientation = "h",
      y = 1.1,
      x = 0.5,
      xanchor = "center"
    )
  ) |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  )
