df_auctioned_total_sum <-
  fromJSONwithToken(api_endpoint("/auctions_auctions_summary"))

df_auctioned_total_sum <- df_auctioned_total_sum |>
  select(date, tot_sum, paid) |>
  mutate(
    date = as.Date(date),
    paid = replace_na(paid, 0),
    tot_sum = replace_na(tot_sum, 0)
  ) |>
  filter(date >= Sys.Date() - 30) |>
  arrange(date)

export_locale <- Sys.getlocale(category = "LC_COLLATE") |>
  stri_sub(
    from = 1L,
    to = 2L
  )

fig_auctioned_paid <- plot_ly(
  type       = "bar",
  name       = gettext("Auctioned sum"),
  x          = ~date,
  y          = ~tot_sum,
  data       = df_auctioned_total_sum,
  marker     = list(color = dashboard_colors[1]),
  text       = "",
  showlegend = TRUE
) |>
  add_trace(
    name       = gettext("Paid sum"),
    y          = ~paid,
    marker     = list(color = dashboard_colors[3]),
    text       = "",
    showlegend = TRUE
  ) |>
  config(locale = export_locale) |>
  layout(
    hovermode = "x unified",
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Date"),
      tickformat = locale_date_format(),
      ticks = "outside"
    ),
    yaxis = list(
      title = gettext("Total auctioned and paid sum (CZK)"),
      tickformat = ",d"
    ),
    legend = list(
      orientation = "h",
      y = 1.1,
      x = 0.5,
      xanchor = "center"
    )
  )

save_image(fig_auctioned_paid,
  file =
    paste0(
      "../images/auctions_auctioned_paid_",
      export_locale,
      ".svg"
    )
)
