df_amounts_year <- fromJSONwithToken(api_endpoint("/auctions_auctions_summary")) |>
  select(date, tot_sum, paid) |>
  mutate(
    ts = as.Date(date),
    year = year(ts),
    paid = replace_na(paid, 0),
    tot_sum = replace_na(tot_sum, 0)
  ) |>
  group_by(year) %>%
  summarise(
    tot_sum = sum(tot_sum),
    paid = sum(paid),
    paid_perc = paid * 100 / tot_sum,
    tot_sum_perc = 100
  )


fig <- plot_ly(df_amounts_year,
  x = ~year,
  y = ~tot_sum,
  type = "bar",
  marker = list(color = dashboard_colors[1]),
  name = gettext("Auctioned sum"),
  hovertemplate = paste0(
    "<b>", gettext("Auctioned sum"), "</b>: ",
    formatC(df_amounts_year$tot_sum,
      format = "d",
      big.mark = "\u202F"
    ),
    " ", gettext("CZK"),
    "<extra></extra>"
  )
)
fig <- fig %>%
  add_trace(
    y = ~paid,
    name = gettext("Paid sum"),
    marker = list(color = dashboard_colors[3]),
    hovertemplate = paste0(
      "<b>", gettext("Paid sum"), "</b>: ",
      formatC(df_amounts_year$paid,
        format = "d",
        big.mark = "\u202F"
      ), " ", gettext("CZK"),
      " (", round(df_amounts_year$paid_perc, 2), "%)",
      "<extra></extra>"
    )
  )

fig <- fig %>%
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    hovermode = "x unified",
    title = gettext("Yearly auctioned and paid sum"),
    legend = list(
      orientation = "h",
      xanchor = "center",
      yanchor = "bottom",
      x = 0.5,
      y = 0.99
    ),
    separators = ".\u202F",
    margin = list(t = 50),
    xaxis = list(
      fixedrange = TRUE,
      dtick = 1,
      title = gettext("Year")
    )
  ) %>%
  layout(
    yaxis =
      list(
        fixedrange = TRUE,
        title = gettext("Sum (CZK)"),
        tickformat = ",d"
      )
  )


fig
