df_s1_day <- fromJSONwithToken(api_endpoint("/auctions_auctions_summary")) |>
  select(date, total, auctioned) |>
  mutate(ts = as.Date(date), perc = round(auctioned * 100 / total, 2)) |>
  arrange(ts)


plot1 <- plot_ly(
  df_s1_day,
  x = ~ts,
  y = ~total,
  type = "scatter",
  mode = "lines",
  hovertemplate = ~ paste0(
    "<b>", gettext("Domains available for auction"),
    "</b>: ", total, "<extra></extra>"
  ),
  name = gettext("Domains available for auction"),
  line = list(color = dashboard_colors[1])
) |>
  add_trace(
    y = ~auctioned,
    name = gettext("Auctioned domains"),
    mode = "lines",
    hovertemplate = ~ paste0(
      "<b>", gettext("Auctioned domains"),
      "</b>: ", auctioned, "<extra></extra>"
    ),
    line = list(color = dashboard_colors[3])
  ) |>
  layout(
    hovermode = "x unified",
    margin = list(t = 75),
    legend = list(
      orientation = "h",
      xanchor = "center",
      x = 0.5,
      y = 1.08
    ),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 7,
            label = gettext("7 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 15,
            label = gettext("15 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Number of domains"),
      tickformat = ",d"
    )
  )


ratio <- plot_ly(
  df_s1_day,
  x = ~ts,
  y = ~perc,
  type = "scatter",
  name = paste0(
    gettext("Ratio of auctioned domains"), " (%)"
  ),
  mode = "lines",
  line = list(color = dashboard_colors[2]),
  hovertemplate = paste0(
    "<b>",
    gettext("Domains available for auction"), "</b>: ",
    formatC(df_s1_day$total, big.mark = " "), "<br><b>",
    gettext("Auctioned domains"), "</b>: ",
    formatC(
      df_s1_day$auctioned,
      big.mark = " "
    ), "<br><b>",
    gettext("Ratio (%)"), "</b>: %{y}<br><b><extra></extra>"
  )
) %>%
  layout(
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 7,
            label = gettext("7 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 15,
            label = gettext("15 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date"),
        x = 0.8
      )
    ),
    yaxis = list(
      title = paste0(
        gettext("Ratio of auctioned domains"), " (%)"
      ),
      ticksuffix = "%"
    )
  )


subplot(
  plot1, ratio,
  margin = 0.06, titleX = TRUE, titleY = TRUE, nrows = 1
) %>%
  layout(
    hovermode = "x unified",
    autosize = TRUE,
    xaxis = list(showgrid = TRUE, zeroline = FALSE),
    yaxis = list(showgrid = TRUE, zeroline = FALSE)
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local())
