df_s1_year <- fromJSONwithToken(api_endpoint("/auctions_auctions_summary")) |>
  select(date, total, auctioned) |>
  mutate(ts = as.Date(date), year = year(ts)) |>
  group_by(year) %>%
  summarise(
    total = sum(total),
    auctioned = sum(auctioned),
    auctioned_perc = round(auctioned * 100 / total, 2),
    total_perc = 100
  )


fig <- plot_ly(df_s1_year,
  x = ~year,
  y = ~total,
  type = "bar",
  marker = list(color = dashboard_colors[1]),
  name = gettext("Domains available for auction"),
  hovertemplate = paste0(
    "<b>", gettext("Domains available for auction"), "</b>: ",
    formatC(df_s1_year$total,
      format = "d",
      big.mark = "\u202F"
    ),
    "<extra></extra>"
  )
)
fig <- fig %>%
  add_trace(
    y = ~auctioned,
    name = gettext("Auctioned domains"),
    marker = list(color = dashboard_colors[3]),
    hovertemplate = paste0(
      "<b>", gettext("Auctioned domains"), "</b>: ",
      formatC(df_s1_year$auctioned,
        format = "d",
        big.mark = "\u202F"
      ), " (", round(df_s1_year$auctioned_perc, 2), "%)",
      "<extra></extra>"
    )
  )

fig <- fig %>%
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    hovermode = "x unified",
    title = gettext("Yearly available and auctioned domains"),
    legend = list(
      orientation = "h",
      xanchor = "center",
      yanchor = "bottom",
      x = 0.5,
      y = 0.99
    ),
    separators = ".\u202F",
    margin = list(t = 50),
    xaxis = list(
      fixedrange = TRUE,
      dtick = 1,
      title = gettext("Year")
    )
  ) %>%
  layout(yaxis = list(
    fixedrange = TRUE,
    title = gettext("Number of domains"),
    tickformat = ",d"
  ))


fig
