df_auctioned_price <-
  fromJSONwithToken(api_endpoint("/auctions_auctions_summary"))

df_auctioned_price <- df_auctioned_price |>
  select(date, tot_sum, auctioned) |>
  mutate(
    date = as.Date(date),
    av_price = tot_sum / auctioned
  ) |>
  filter(date >= Sys.Date() - 30) |>
  arrange(date)

plot_ly(
  name = gettext("Average price in auction"),
  type = "bar",
  x = ~date,
  y = ~av_price,
  data = df_auctioned_price,
  marker = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    "<b>", gettext("Average price"), "</b>", ": ",
    formatC(df_auctioned_price$av_price,
      big.mark = " ",
      digits = 0,
      format = "d"
    ),
    " CZK<extra></extra>"
  )
) |>
  layout(
    hovermode = "x unified",
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Date"),
      ticks = "outside"
    ),
    yaxis = list(
      title =
        paste0(
          gettext("Average price in auction"),
          " (", gettext("CZK"), ")"
        ),
      tickformat = ",d"
    )
  ) |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  )
