df_auctioned_price <-
  fromJSONwithToken(api_endpoint("/auctions_auctions_summary"))

df_auctioned_price <- df_auctioned_price |>
  select(date, auctioned, tot_sum) |>
  mutate(
    date = as.Date(date),
    av_price = tot_sum / auctioned
  ) |>
  filter(date >= Sys.Date() - 30) |>
  arrange(date)

export_locale <- Sys.getlocale(category = "LC_COLLATE") |>
  stri_sub(
    from = 1L,
    to = 2L
  )

fig_price <- plot_ly(
  name = "Average price in auction",
  type = "bar",
  x = ~date,
  y = ~av_price,
  data = df_auctioned_price,
  marker = list(color = dashboard_colors[1]),
  textposition = "none"
) |>
  config(locale = export_locale) |>
  layout(
    hovermode = "x unified",
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Date"),
      tickformat = locale_date_format(),
      ticks = "outside"
    ),
    yaxis = list(
      title = paste0(
        gettext("Average price in auction"), " (",
        gettext("CZK"), ")"
      ),
      tickformat = ",d"
    )
  )

save_image(fig_price,
  file =
    paste0(
      "../images/auctions_average_price_",
      export_locale,
      ".svg"
    )
)
