df_strategy_month <- fromJSONwithToken(api_endpoint("/auctions_bid_strategy_types")) |>
  mutate(
    ts = as.Date(date),
    bid_strategy_type = replace_na(bid_strategy_type, 0),
    count = replace_na(count, 0)
  ) |>
  spread(bid_strategy_type, count) |>
  arrange(ts)


df_strategy_month  <- df_strategy_month  |>
  mutate(ts = as.Date(ts), month = month(ts), year = year(ts)) |>
  group_by(month, year) |>
  mutate(
    month_start = min(ts),
    month_end = max(ts)
  ) |>
  group_by(month, year, month_start, month_end) |>
  summarise(
    MAX = sum(MAX),
    SPOT = sum(SPOT),
  ) |>
  ungroup() |>
  arrange(month_end)

plot_ly(
  df_strategy_month,
  x = ~month_end,
  y = ~MAX,
  name = gettext("MAX"),
  line = list(color = dashboard_colors[1]),
  hovertemplate =
    paste0(
      "<b>", gettext("MAX"),
      "</b>: %{y} ", "<extra></extra>"
    )
) |>
  add_lines() |>
  add_trace(
    y = ~SPOT, name = gettext("SPOT"),
    mode = "lines",
    hovertemplate = paste0(
      "<b>", gettext("SPOT"), "</b>: %{y} <extra></extra>"
    ),
    line = list(color = dashboard_colors[3])
  ) |>
  layout(
    hovermode = "x unified",
    margin = list(t = 75),
    legend = list(
      orientation = "h",
      xanchor = "center",
      x = 0.5,
      y = 1.08
    ),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Month"),
      rangeselector = list(
        buttons = list(
          list(
            count = 3,
            label = gettext("3 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 3,
            label = gettext("3 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Count"),
      tickformat = ",d"
    )
  ) %>%
  layout(
    hovermode = "x unified",
    autosize = TRUE,
    xaxis = list(showgrid = TRUE, zeroline = FALSE),
    yaxis = list(showgrid = TRUE, zeroline = FALSE)
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local())
