df_strategy_week <- fromJSONwithToken(api_endpoint("/auctions_bid_strategy_types")) |>
  mutate(
    ts = as.Date(date),
    bid_strategy_type = replace_na(bid_strategy_type, 0),
    count = replace_na(count, 0)
  ) |>
  spread(bid_strategy_type, count) |>
  arrange(ts)



df_strategy_week <- df_strategy_week |>
  mutate(
    week = week(date),
    year = year(date)
  ) |>
  group_by(year, week) |>
  mutate(
    week_start = floor_date(ts, unit = "week", week_start = 1),
    week_end   = ceiling_date(ts, unit = "week", week_start = 1)
  ) |>
  select(
    ts,
    week_start,
    week_end,
    MAX,
    SPOT
  ) |>
  group_by(week_start, week_end) |>
  summarise(MAX = sum(MAX), SPOT = sum(SPOT)) |>
  ungroup() |>
  arrange(week_end)


plot_ly(
  df_strategy_week,
  x = ~ as.Date(week_end),
  type = "scatter",
  mode = "lines",
  y = ~MAX,
  name = gettext("MAX"),
  line = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    "<b>", gettext("MAX"), "</b>: %{y} <extra></extra>"
  )
) |>
  add_trace(
    y = ~SPOT,
    name = gettext("SPOT"),
    mode = "lines",
    line = list(color = dashboard_colors[3]),
    hovertemplate = paste0(
      "<b>", gettext("SPOT"), "</b>: %{y} <extra></extra>"
    )
  ) |>
  add_trace(
    y = 0,
    name = gettext("Date"),
    line = list(color = "rgba(255, 0, 0, 0)"),
    customdata = paste0(
      gettext("from"),
      " <b>",
      format(df_strategy_week$week_start),
      "</b> ",
      gettext("to"),
      " <b>",
      format(df_strategy_week$week_end),
      "</b>"
    ),
    hovertemplate = paste0(
      gettext("Week"), " %{customdata}", "<extra></extra>"
    ),
    visible = TRUE,
    legendrank = 1,
    showlegend = FALSE
  ) |>
  layout(
    hovermode = "x unified",
    margin = list(t = 75),
    legend = list(
      orientation = "h",
      xanchor = "center",
      x = 0.5,
      y = 1.08
    ),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Week"),
      rangeselector = list(
        buttons = list(
          list(
            count = 15,
            label = gettext("15 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Count"),
      tickformat = ",d"
    )
  )  %>%
  layout(
    hovermode = "x unified",
    autosize = TRUE,
    xaxis = list(showgrid = TRUE, zeroline = FALSE),
    yaxis = list(showgrid = TRUE, zeroline = FALSE)
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local())
