df_bidders_country <-
  fromJSONwithToken(api_endpoint("/auctions_bidders_by_country"))

country_codes <- load_country_codes() %>%
  rename("cc" = country_code)

df_bidders_country <- df_bidders_country |>
  mutate(date = as.Date(date)) |>
  rename("cc" = country) |>
  left_join(country_codes, by = c("cc")) |>
  mutate(
    Country = as.factor(Country),
    Country = fct_lump_n(Country,
      n = 10,
      w = total,
      other_level = gettext("Other")
    )
  ) |>
  select(-cc) |>
  complete(Country, date,
    fill = list(total = 0)
  ) |>
  group_by(Country, date) |>
  reframe(total = sum(total)) |>
  ungroup() |>
  arrange(date)


df_bidders_country$Country <- factor(df_bidders_country$Country,
  levels = unique(df_bidders_country$Country)[order(df_bidders_country$total, decreasing = TRUE)]
)





n_countries <- df_bidders_country |>
  select(Country) |>
  unique() |>
  nrow()

plot_ly(
  type = "scatter",
  mode = "lines",
  data = df_bidders_country,
  x = ~date,
  y = ~total,
  color = ~Country,
  colors = dashboard_pal(n = n_countries),
  hovertemplate = paste0(
    "<b>", df_bidders_country$Country, "</b>: ",
    df_bidders_country$total, "<extra></extra>"
  )
) |>
  layout(
    hovermode = "x unified",
    legend = list(
      orientation = "h",
      xanchor     = "center",
      x           = 0.5,
      y           = 1.08
    ),
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons =
          list(
            list(
              count    = 7,
              label    = gettext("7 d"),
              step     = "day",
              stepmode = "backward"
            ),
            list(
              count    = 1,
              label    = gettext("1 m"),
              step     = "month",
              stepmode = "backward"
            ),
            list(
              count    = 6,
              label    = gettext("6 m"),
              step     = "month",
              stepmode = "backward"
            ),
            list(
              count    = 1,
              label    = gettext("1 y"),
              step     = "year",
              stepmode = "backward"
            ),
            list(
              count    = 2,
              label    = gettext("2 y"),
              step     = "year",
              stepmode = "backward"
            ),
            list(
              count    = 4,
              label    = gettext("4 y"),
              step     = "year",
              stepmode = "backward"
            ),
            list(
              step = "all",
              label = gettext("all")
            )
          ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(title = gettext("Number of bidders"))
  ) |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) |>
  htmlwidgets::onRender(add_csv_button_local())
