df_bidders_country <-
  fromJSONwithToken(api_endpoint("/auctions_bidders_by_country_1m"))

country_codes <- load_country_codes() %>%
  rename("cc" = country_code)

df_bidders_country <- df_bidders_country |>
  mutate(date = as.Date(date)) |>
  rename("cc" = country) |>
  left_join(country_codes, by = c("cc")) |>
  mutate(
    year = year(date),
    month = month(date)
  ) |>
  mutate(
    Country = as.factor(Country),
    Country = fct_lump_n(Country,
      n = 10,
      w = total,
      other_level = gettext("Other")
    )
  ) |>
  group_by(Country, year, month) |>
  reframe(
    total = sum(total),
    date = max(date)
  ) |>
  ungroup() |>
  complete(Country, year, month,
    fill = list(total = 0)
  ) |>
  arrange(Country, year, month)

df_cz <- df_bidders_country |>
  left_join(country_codes, by = c("Country")) |>
  filter(cc == "CZ") |>
  select(year, month, date)

df_bidders_country <- df_bidders_country |>
  select(-date) |>
  left_join(df_cz,
    by = c("year", "month"),
    relationship = "many-to-many"
  ) |>
  arrange(year, month, total, Country)

n_countries <- df_bidders_country |>
  select(Country) |>
  unique() |>
  nrow()

df_bidders_country$Country <- factor(df_bidders_country$Country,
  levels = unique(df_bidders_country$Country)[order(df_bidders_country$total, decreasing = TRUE)]
)


plot_ly(
  type = "scatter",
  mode = "lines",
  data = df_bidders_country,
  x = ~date,
  y = ~total,
  color = ~Country,
  colors = dashboard_pal(n = n_countries),
  hovertemplate = paste0(
    "<b>", df_bidders_country$Country, "</b>: ", df_bidders_country$total, "<extra></extra>"
  )
) |>
  layout(
    hovermode = "x unified",
    legend = list(
      orientation = "h",
      xanchor     = "center",
      x           = 0.5,
      y           = 1.08
    ),
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 3,
            label = gettext("3 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 3,
            label = gettext("3 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(title = gettext("Number of bidders"))
  ) |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) |>
  htmlwidgets::onRender(add_csv_button_local())
