df_bidders_country <-
  fromJSONwithToken(api_endpoint("/auctions_bidders_by_country_1y"))

country_codes <- load_country_codes() %>%
  rename("cc" = country_code)

df_bidders_country <- df_bidders_country |>
  mutate(date = as.Date(date)) |>
  rename("cc" = country) |>
  left_join(country_codes, by = c("cc")) |>
  mutate(
    Country = as.factor(Country),
    Country = fct_lump_n(Country,
      n = 10,
      w = total,
      other_level = gettext("Other")
    ),
    year = year(date)
  ) |>
  group_by(Country, year) |>
  summarise(total = sum(total)) |>
  ungroup() |>
  mutate(total_cc = sum(total)) |>
  group_by(year, Country) |>
  mutate(perc = round(total * 100 / total_cc, 2)) |>
  arrange(Country, year)

df_bidders_country$Country <- factor(df_bidders_country$Country,
  levels = unique(df_bidders_country$Country)[order(df_bidders_country$total, decreasing = TRUE)]
)

n_countries <- df_bidders_country |>
  select(Country) |>
  unique() |>
  nrow()

plot_ly(
  type = "bar",
  mode = "stacked",
  data = df_bidders_country,
  x = ~year,
  y = ~total,
  color = ~Country,
  colors = dashboard_pal(n = n_countries),
  hovertemplate = paste0(
    "<b>", df_bidders_country$Country, "</b>: ",
    df_bidders_country$total, " (",
    df_bidders_country$perc, "%)<extra></extra>"
  )
) |>
  layout(
    hovermode = "x unified",
    legend = list(
      orientation = "h",
      xanchor     = "center",
      x           = 0.5,
      y           = 1.08
    ),
    xaxis = list(
      title = gettext("Year"),
      fixedrange = TRUE,
      dtick = 1
    ),
    yaxis = list(title = gettext("Number of bidders"))
  ) |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) |>
  htmlwidgets::onRender(add_csv_button_local())
