df_bidders <-
  fromJSONwithToken(api_endpoint("/auctions_bidders"))

df_bidders <- df_bidders |>
  select(date, total) |>
  mutate(date = as.Date(date)) |>
  filter(date >= Sys.Date() - 30) |>
  arrange(date)

export_locale <- Sys.getlocale(category = "LC_COLLATE") |>
  stri_sub(
    from = 1L,
    to = 2L
  )

fig_bidders <- plot_ly(
  name = "Bidders",
  type = "bar",
  x = ~date,
  y = ~total,
  data = df_bidders,
  marker = list(color = dashboard_colors[1]),
  text = ~total,
  textposition = "outside"
) |>
  layout(
    hovermode = "x unified",
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Date"),
      tickformat = locale_date_format(),
      ticks = "outside"
    ),
    yaxis = list(
      title = gettext("Count of active bidders"),
      tickformat = ",d"
    )
  ) |>
  config(
    displayModeBar = TRUE,
    locale = "en"
  )

save_image(fig_bidders,
  file =
    paste0(
      "../images/auctions_bidders_",
      export_locale,
      ".svg"
    )
)
