df_bidders_entity <-
  fromJSONwithToken(api_endpoint("/auctions_bidders")) |>
  select(date, natural, organization) |>
  mutate(date = as.Date(date)) |>
  arrange(date)

plot_ly(
  data = df_bidders_entity,
  name = gettext("Natural person"),
  type = "scatter",
  mode = "lines",
  x = ~date,
  y = ~natural,
  line = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    "<b>", gettext("Natural person"), "</b>: %{y}<extra></extra>"
  )
) |>
  add_trace(
    name = gettext("Legal person"),
    x = ~date,
    y = ~organization,
    line = list(color = dashboard_colors[3]),
    hovertemplate = paste0(
      "<b>", gettext("Legal person"), "</b>: %{y}<extra></extra>"
    )
  ) |>
  layout(
    hovermode = "x unified",
    legend = list(
      orientation = "h",
      xanchor     = "center",
      x           = 0.5,
      y           = 1.08
    ),
    xaxis =
      list(
        title = gettext("Date"),
        rangeselector =
        list(
          buttons =
          list(
            list(
              count    = 7,
              label    = gettext("7 d"),
              step     = "day",
              stepmode = "backward"
            ),
            list(
              count    = 1,
              label    = gettext("1 m"),
              step     = "month",
              stepmode = "backward"
            ),
            list(
              count    = 6,
              label    = gettext("6 m"),
              step     = "month",
              stepmode = "backward"
            ),
            list(
              count    = 1,
              label    = gettext("1 y"),
              step     = "year",
              stepmode = "backward"
            ),
            list(
              count    = 2,
              label    = gettext("2 y"),
              step     = "year",
              stepmode = "backward"
            ),
            list(
              count    = 4,
              label    = gettext("4 y"),
              step     = "year",
              stepmode = "backward"
            ),
            list(
              step = "all",
              label = gettext("all")
            )
          ),
          rangeslider = list(type = "date")
        )
      ),
    yaxis = list(title = gettext("Number of bidders"))
  ) |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) |>
  htmlwidgets::onRender(add_csv_button_local())
