df_bidders_entity <-
  fromJSONwithToken(api_endpoint("/auctions_bidders_1m")) |>
  select(date, natural, organization) |>
  mutate(date = as.Date(date)) |>
  arrange(date) |>
  mutate(
    month = month(date),
    year  = year(date)
  ) |>
  group_by(year, month) |>
  mutate(
    month_start = min(date),
    month_end   = max(date)
  ) |>
  reframe(
    natural      = sum(natural),
    organization = sum(organization),
    month_start  = month_start,
    month_end    = month_end
  ) |>
  ungroup() |>
  distinct()

plot_ly(
  name = gettext("Natural person"),
  type = "scatter",
  mode = "lines",
  x = ~month_end,
  y = ~natural,
  data = df_bidders_entity,
  line = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    "<b>", gettext("Natural person"), "</b>: %{y}<extra></extra>"
  )
) |>
  add_trace(
    name = gettext("Legal person"),
    x = ~month_end,
    y = ~organization,
    line = list(color = dashboard_colors[3]),
    hovertemplate = paste0(
      "<b>", gettext("Legal person"), "</b>: %{y}<extra></extra>"
    )
  ) |>
  layout(
    hovermode = "x unified",
    legend = list(
      orientation = "h",
      xanchor     = "center",
      x           = 0.5,
      y           = 1.08
    ),
    xaxis = list(
      title = gettext("Month"),
      rangeselector = list(
        buttons = list(
          list(
            count = 3,
            label = gettext("3 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 3,
            label = gettext("3 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(title = gettext("Number of bidders"))
  ) |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) |>
  htmlwidgets::onRender(add_csv_button_local())
