df_bidders_entity <-
  fromJSONwithToken(api_endpoint("/auctions_bidders_1w")) |>
  select(date, natural, organization) |>
  mutate(date = as.Date(date)) |>
  arrange(date) |>
  mutate(week_start = floor_date(date, unit = "week", week_start = 1),
         week_end = ceiling_date(date, unit = "week", week_start = 1))

plot_ly(
  data = df_bidders_entity,
  name = gettext("Natural person"),
  type = "scatter",
  mode = "lines",
  x = ~week_end,
  y = ~natural,
  line = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    "<b>", gettext("Natural person"), "</b>: %{y}<extra></extra>"
  )
) |>
  add_trace(
    name = gettext("Legal person"),
    x = ~week_end,
    y = ~organization,
    line = list(color = dashboard_colors[3]),
    hovertemplate = paste0(
      "<b>", gettext("Legal person"), "</b>: %{y}<extra></extra>"
    )
  ) |>
  add_trace(
    y = 0,
    name = gettext("Date"),
    line = list(color = "rgba(255, 0, 0, 0)"),
    customdata = paste0(
      gettext("from"),
      " <b>",
      format(df_bidders_entity$week_start, locale_date_format()),
      "</b> ",
      gettext("to"),
      " <b>",
      format(df_bidders_entity$week_end, locale_date_format()),
      "</b>"
    ),
    hovertemplate = paste0(
      gettext("Week"), " %{customdata}", "<extra></extra>"
    ),
    visible = TRUE,
    legendrank = 1,
    showlegend = FALSE
  ) |>
  layout(
    hovermode = "x unified",
    legend = list(
      orientation = "h",
      xanchor     = "center",
      x           = 0.5,
      y           = 1.08
    ),
    xaxis =
      list(
        title = gettext("Week"),
        rangeselector = list(
          buttons = list(
            list(
              count = 15,
              label = gettext("15 d"),
              step = "day",
              stepmode = "backward"
            ),
            list(
              count = 1,
              label = gettext("1 m"),
              step = "month",
              stepmode = "backward"
            ),
            list(
              count = 6,
              label = gettext("6 m"),
              step = "month",
              stepmode = "backward"
            ),
            list(
              count = 1,
              label = gettext("1 y"),
              step = "year",
              stepmode = "backward"
            ),
            list(
              count = 3,
              label = gettext("3 y"),
              step = "year",
              stepmode = "backward"
            ),
            list(
              count = 6,
              label = gettext("6 y"),
              step = "year",
              stepmode = "backward"
            ),
            list(
              step = "all",
              label = gettext("all")
            )
          ),
          rangeslider = list(type = "date")
        )
      ),
    yaxis = list(title = gettext("Number of bidders"))
  ) |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) |>
  htmlwidgets::onRender(add_csv_button_local())
