df_bidders_entity <-
  fromJSONwithToken(api_endpoint("/auctions_bidders_1y")) |>
  select(date, natural, organization) |>
  mutate(date = as.Date(date)) |>
  arrange(date) |>
  mutate(
    year = year(date)
  ) |>
  group_by(year) |>
  reframe(
    natural = sum(natural),
    organization = sum(organization),
    perc_natural = round(natural * 100 / (natural + organization), 2),
    perc_organization = round(organization * 100 / (natural + organization), 2)
  ) |>
  ungroup() |>
  distinct()

plot_ly(
  name = gettext("Natural person"),
  type = "bar",
  x = ~year,
  y = ~natural,
  data = df_bidders_entity,
  marker = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    "<b>", gettext("Natural person"), "</b>: %{y}", " (", df_bidders_entity$perc_natural, " %) <extra></extra>"
  )
) |>
  add_trace(
    name = gettext("Legal person"),
    x = ~year,
    y = ~organization,
    marker = list(color = dashboard_colors[3]),
    hovertemplate = paste0(
      "<b>", gettext("Legal person"), "</b>: %{y}", " (", df_bidders_entity$perc_organization, " %) <extra></extra>"
    )
  ) |>
  layout(
    hovermode = "x unified",
    legend = list(
      orientation = "h",
      xanchor     = "center",
      x           = 0.5,
      y           = 1.08
    ),
    xaxis = list(
      title = gettext("Year"),
      fixedrange = TRUE,
      dtick = 1
    ),
    yaxis = list(title = gettext("Number of bidders"))
  ) |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) |>
  htmlwidgets::onRender(add_csv_button_local())
