df_endtime <-
  fromJSONwithToken(api_endpoint("/auctions_auctions_summary"))

df_endtime <- df_endtime |>
  select(date, last_finished) |>
  mutate(
    date = as.Date(date),
    ts = ymd_hms(last_finished, tz = "UTC"),
    ts_cet_cest = with_tz(ts, tzone = "Europe/Prague"),
    baseline = ymd_hms(paste0(date, " 21:00:00")),
    time_hms = as.POSIXct(ts_cet_cest, format = "%H:%M:%S"),
    duration = difftime(time_hms, baseline, tz = "Europe/Prague"),
    time_hm = format(
      as.POSIXct(time_hms),
      format = "%H:%M"
    ),
    dst = dst(ts_cet_cest),
    duration = case_when(dst == FALSE ~ duration - 3600,
                         dst == TRUE ~ duration)
  ) |>
  arrange(date)

hline_min <- df_endtime |>
  select(duration, time_hm, time_hms) |>
  mutate(
    duration = as.numeric(duration)
  ) |>
  filter(
    duration == min(duration)
  )

hline_max <- df_endtime |>
  select(duration, time_hm, time_hms) |>
  mutate(
    duration = as.numeric(duration)
  ) |>
  filter(
    duration == max(duration)
  )

hlines <-
  bind_rows(
    hline_min,
    hline_max
  )

separation <- (abs(hline_min$duration) + abs(hline_max$duration)) / 4

hlines <- hlines |>
  add_row(
    duration =
      seq(from = hline_min$duration,
          to = hline_max$duration,
          by = separation)
  ) |>
  mutate(
    daytime_baseline = period_to_seconds(hms("23:00:00")),
    daytime_closing = daytime_baseline + duration,
    daytime_closing_period = seconds_to_period(daytime_closing),
    daytime_hour = hour(daytime_closing_period),
    daytime_minute = minute(daytime_closing_period),
    daytime_minute =
      ifelse(stri_length(daytime_minute) == 1,
             paste0("0", daytime_minute),
             daytime_minute),
    daytime_text = paste0(daytime_hour, ":", daytime_minute)
  )



plot_ly(
  name = gettext("Last auction"),
  type = "scatter",
  mode = "lines",
  x = ~date,
  y = ~duration,
  data = df_endtime,
  hovertemplate = ~ paste0(
    "<b>", gettext("Closing time"),
    "</b>: ", df_endtime$time_hm, "<extra></extra>"
  ),
  line = list(color = dashboard_colors[1])
) |>
  layout(
    hovermode = "x unified",
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons =
          list(
            list(
              count    = 7,
              label    = gettext("7 d"),
              step     = "day",
              stepmode = "backward"
            ),
            list(
              count    = 1,
              label    = gettext("1 m"),
              step     = "month",
              stepmode = "backward"
            ),
            list(
              count    = 6,
              label    = gettext("6 m"),
              step     = "month",
              stepmode = "backward"
            ),
            list(
              count    = 1,
              label    = gettext("1 y"),
              step     = "year",
              stepmode = "backward"
            ),
            list(
              count    = 2,
              label    = gettext("2 y"),
              step     = "year",
              stepmode = "backward"
            ),
            list(
              count    = 4,
              label    = gettext("4 y"),
              step     = "year",
              stepmode = "backward"
            ),
            list(
              step = "all",
              label = gettext("all")
            )
          ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Last auction's closing time"),
      tickvals = ~ hlines$duration,
      ticktext = ~ hlines$daytime_text,
      tickmode = "array",
      dtick = 10,
      zeroline = FALSE
    )
  ) |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button("/auctions_auctions_summary"))
