num_bids_time_day <- fromJSONwithToken(api_endpoint("/auctions_bid_times")) |>
  mutate(report_datetime_range = as.character(report_datetime_range)) |>
  separate(
    report_datetime_range,
    into = c("start_time", "end_time"),
    sep = ",",
    extra = "drop"
  ) %>%
  mutate(
    start_time = gsub("\\[|\"", "", start_time),
    end_time = gsub("\\)|\"", "", end_time),
    date = as.Date(date),
    start_time = ymd_hms(start_time, tz = "UTC"),
    cet_cest_start = with_tz(start_time, tzone = "Europe/Prague"),
    end_time = ymd_hms(end_time, tz = "UTC"),
    cet_cest_end = with_tz(end_time, tzone = "Europe/Prague"),
  ) |>
  select(date, cet_cest_start, count, hour_num) |>
  arrange(cet_cest_start) |>
  left_join(intervals) |>
  filter(date > "2024-05-15") |>
  drop_na()

y_max_week <- num_bids_time_day |>
  filter(date > Sys.Date() - 7) |>
  summarize(ymax = max(count))

plot_ly(
  num_bids_time_day,
  type = "bar",
  x = ~cet_cest_start,
  y = ~count,
  split = ~hour_num,
  color = ~hour_num,
  colors = dashboard_pal(24),
  hovertemplate = ~ paste0(
    num_bids_time_day$date,
    "<br>", num_bids_time_day$start_time_hour, " \U2013 ",
    num_bids_time_day$end_time_hour,
    "<br><b>", gettext("Number of bids"),
    "</b>: ", formatC(count, big.mark = " "), "<extra></extra>"
  )
) |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local()) |>
  layout(
    barmode = "relative",
    margin = list(t = 20),
    legend = list(
      title = list(text = gettext("Hour of Day")),
      orientation = "h",
      xanchor = "center",
      x = 0.5,
      y = 1
    ),
    separators = ".\u202F",
    xaxis = list(
      type = "date",
      dtick = "D1",
      title = gettext("Day"),
      range = c(Sys.Date() - 0.5, Sys.Date() + 0.5), # Default range
      rangeselector = list(
        buttons = list(
          list(
            count = 1,
            label = gettext("1 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 7,
            label = gettext("7 d"),
            step = "day",
            stepmode = "backward"
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Count"),
      tickformat = ",d",
      range = c(0, y_max_week$ymax)
    )
  ) |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local()) |>
  hide_colorbar()
