num_bids_time_day_total <- fromJSONwithToken(api_endpoint("/auctions_bid_times")) |>
  mutate(report_datetime_range = as.character(report_datetime_range)) |>
  separate(
    report_datetime_range,
    into = c("start_time", "end_time"),
    sep = ",",
    extra = "drop"
  ) %>%
  mutate(
    start_time = gsub("\\[|\"", "", start_time),
    end_time = gsub("\\)|\"", "", end_time),
    date = as.Date(date),
    start_time = ymd_hms(start_time, tz = "UTC"),
    cet_cest_start = with_tz(start_time, tzone = "Europe/Prague"),
    end_time = ymd_hms(end_time, tz = "UTC"),
    cet_cest_end = with_tz(end_time, tzone = "Europe/Prague"),
  ) |>
  select(date, cet_cest_start, count, hour_num) |>
  arrange(cet_cest_start) |>
  left_join(intervals) |>
  filter(date > "2024-05-15") |>
  drop_na() |>
  group_by(date) |>
  summarize(
    count = sum(count)
  )

plot_ly(
  num_bids_time_day_total,
  type = "bar",
  x = ~date,
  y = ~count,
  marker = list(color = dashboard_colors[1]),
  hovertemplate = ~ paste0(
    num_bids_time_day_total$date,
    "<br><b>", gettext("Number of bids"),
    "</b>: ", formatC(count, big.mark = " "), "<extra></extra>"
  )
) |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local()) |>
  layout(
    barmode = "relative",
    separators = ".\u202F",
    xaxis = list(
      type = "date",
      dtick = "D1",
      title = gettext("Day"),
      range = c(Sys.Date() - 31, Sys.Date()), # Default range
      rangeselector = list(
        buttons = list(
          list(
            count = 7,
            label = gettext("7 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 15,
            label = gettext("15 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Count"),
      tickformat = ",d"
    )
  ) |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local()) |>
  hide_colorbar()
