num_bids_total_month <- fromJSONwithToken(api_endpoint("/auctions_bid_times")) |>
  mutate(report_datetime_range = as.character(report_datetime_range)) |>
  separate(
    report_datetime_range,
    into = c("start_time", "end_time"),
    sep = ",",
    extra = "drop"
  ) %>%
  mutate(
    start_time = gsub("\\[|\"", "", start_time),
    end_time = gsub("\\)|\"", "", end_time),
    date = as.Date(date),
    start_time = ymd_hms(start_time, tz = "UTC"),
    cet_cest_start = with_tz(start_time, tzone = "Europe/Prague"),
    end_time = ymd_hms(end_time, tz = "UTC"),
    cet_cest_end = with_tz(end_time, tzone = "Europe/Prague"),
  ) |>
  select(cet_cest_start, count, hour_num) |>
  arrange(cet_cest_start)

df_bids_total_month <- num_bids_total_month |>
  mutate(month = month(cet_cest_start), year = year(cet_cest_start)) |>
  group_by(month, year, hour_num) |>
  mutate(
    month_start = min(cet_cest_start),
    month_end = max(cet_cest_start)
  ) |>
  group_by(month, year, month_start, month_end, hour_num) |>
  summarise(
    mean = mean(count),
    count = sum(count)
  ) |>
  ungroup() |>
  left_join(intervals) |>
  filter(hour_num < 25) |>
  mutate(
    ym = paste0(year, "-", month)
  ) |>
  arrange(year, month, hour_num) |>
  group_by(ym) |>
  summarize(
    count = sum(count),
    year = first(year),
    month = first(month)
  ) |>
  ungroup() |>
  arrange(year, month)

df_bids_total_month <- df_bids_total_month |>
  mutate(
    month_order = seq(from = 1, to = nrow(df_bids_total_month), by = 1)
  )

plot_ly(
  df_bids_total_month,
  type = "bar",
  x = ~month_order,
  y = ~count,
  marker = list(color = dashboard_colors[1]),
  hovertemplate =
    paste0(
      df_bids_total_month$ym, "<br>",
      "<b>", gettext("Number of bids"), "</b>: ",
      formatC(df_bids_total_month$count, big.mark = " "),
      "<extra></extra>"
    )
) |>
  layout(
    margin = list(t = 20),
    separators = ".\u202F",
    bargap = -0.5,
    xaxis = list(
      title = gettext("Month"),
      range = c(max(df_bids_total_month$month_order) - 11.5,
                max(df_bids_total_month$month_order) + 0.5),
      tickvals = ~df_bids_total_month$month_order,
      ticktext = ~df_bids_total_month$ym,
      tickmode = "array"
    ),
    yaxis = list(
      title = gettext("Count"),
      tickformat = ",d"
    ),
    updatemenus = list(
      list(
        bgcolor = "#ECECEC",
        borderwidth = 0,
        type = "buttons",
        x = 0.2,
        y = 1.1,
        direction = "right",
        buttons = list(
          list(label = gettext("6 m"),
               method = "relayout",
               args = list("xaxis.range",
                           c(max(df_bids_total_month$month_order) - 5.5,
                             max(df_bids_total_month$month_order) + 0.5))),
          list(label = gettext("1 y"),
               method = "relayout",
               args = list("xaxis.range",
                           c(max(df_bids_total_month$month_order) - 11.5,
                             max(df_bids_total_month$month_order) + 0.5))),
          list(label = gettext("All"),
               method = "relayout",
               args = list("xaxis.range",
                           c(min(df_bids_total_month$month_order) - 0.5,
                             max(df_bids_total_month$month_order) + 0.5)))
        ),
        active = 1
      )
    )
  ) |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local()) |>
  hide_colorbar()
