df_bids_week_total <- fromJSONwithToken(api_endpoint("/auctions_bid_times")) |>
  mutate(report_datetime_range = as.character(report_datetime_range)) |>
  separate(
    report_datetime_range,
    into = c("start_time", "end_time"),
    sep = ",",
    extra = "drop"
  ) %>%
  mutate(
    start_time = gsub("\\[|\"", "", start_time),
    end_time = gsub("\\)|\"", "", end_time),
    date = as.Date(date),
    start_time = ymd_hms(start_time, tz = "UTC"),
    cet_cest_start = with_tz(start_time, tzone = "Europe/Prague"),
    end_time = ymd_hms(end_time, tz = "UTC"),
    cet_cest_end = with_tz(end_time, tzone = "Europe/Prague"),
  ) |>
  select(cet_cest_start, count, hour_num) |>
  arrange(cet_cest_start)

df_bids_week_total <- df_bids_week_total |>
  mutate(
    week = week(cet_cest_start),
    year = year(cet_cest_start)
  ) |>
  mutate(
    week_start = floor_date(cet_cest_start, unit = "week", week_start = 1),
    week_end   = ceiling_date(cet_cest_start + 1, unit = "week", week_start = 1)
  ) |>
  select(
    cet_cest_start,
    week_start,
    week_end,
    hour_num,
    count
  ) |>
  group_by(week_end, week_start, hour_num) |>
  summarise(
    mean = mean(count),
    count = sum(count)
  ) |>
  ungroup() |>
  arrange(week_end)  |>
  left_join(intervals) |>
  filter(hour_num < 25) |>
  filter(difftime(week_end, week_start) > 0) |>
  mutate(week_start = as.character(week_start)) |>
  group_by(week_end, week_start) |>
  summarize(
    count = sum(count)
  ) |>
  ungroup()

df_bids_week_total <- df_bids_week_total |>
  mutate(
    week_order = seq(from = 1, to = nrow(df_bids_week_total), by = 1)
  )

plot_ly(
  df_bids_week_total,
  type = "bar",
  x = ~week_order,
  y = ~count,
  marker = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    gettext("Week"), " ", gettext("from"), " ", df_bids_week_total$week_start,
    gettext(" to "), df_bids_week_total$week_end,
    "<br><b>", gettext("Number of bids"), "</b>: ",
    formatC(df_bids_week_total$count, big.mark = " "),
    "<extra></extra>"
  )
) |>
  layout(
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Week"),
      range = c(max(df_bids_week_total$week_order) - 27.5,
                max(df_bids_week_total$week_order) + 1), # Default range
      tickvals = ~df_bids_week_total$week_order,
      ticktext = ~as.character(df_bids_week_total$week_end),
      tickmode = "array"
    ),
    yaxis = list(
      title = gettext("Count")
    ),
    updatemenus = list(
      list(bgcolor = "#ECECEC",
           borderwidth = 0,
           type = "buttons",
           x = 0.2,
           y = 1.1,
           direction = "right",
           buttons = list(
             list(label = gettext("1 m"),
                  method = "relayout",
                  args = list("xaxis.range",
                              c(max(df_bids_week_total$week_order) - 3.5,
                                max(df_bids_week_total$week_order) + 0.5))),
             list(label = gettext("3 m"),
                  method = "relayout",
                  args = list("xaxis.range",
                              c(max(df_bids_week_total$week_order) - 13.5,
                                max(df_bids_week_total$week_order) + 0.5))),
             list(label = gettext("6 m"),
                  method = "relayout",
                  args = list("xaxis.range",
                              c(max(df_bids_week_total$week_order) - 27.5,
                                max(df_bids_week_total$week_order) + 0.5))),
             list(label = gettext("1 y"),
                  method = "relayout",
                  args = list("xaxis.range",
                              c(max(df_bids_week_total$week_order) - 52.5,
                                max(df_bids_week_total$week_order) + 0.5))),
             list(label = gettext("All"),
                  method = "relayout",
                  args = list("xaxis.range",
                              c(min(df_bids_week_total$week_order) - 0.5,
                                max(df_bids_week_total$week_order) + 0.5)))
           ),
           active = 2)
    )
  ) |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local()) |>
  hide_colorbar()
