df_num_bids_total_year <- fromJSONwithToken(api_endpoint("/auctions_bid_times")) |>
  mutate(report_datetime_range = as.character(report_datetime_range)) |>
  separate(
    report_datetime_range,
    into = c("start_time", "end_time"),
    sep = ",",
    extra = "drop"
  ) %>%
  mutate(
    start_time = gsub("\\[|\"", "", start_time),
    end_time = gsub("\\)|\"", "", end_time),
    date = as.Date(date),
    start_time = ymd_hms(start_time, tz = "UTC"),
    cet_cest_start = with_tz(start_time, tzone = "Europe/Prague"),
    end_time = ymd_hms(end_time, tz = "UTC"),
    cet_cest_end = with_tz(end_time, tzone = "Europe/Prague"),
    year = year(cet_cest_start)
  ) |>
  select(year, count, hour_num) |>
  group_by(year, hour_num) %>%
  summarise(
    mean = mean(count),
    count = sum(count)
  ) |>
  left_join(intervals) |>
  ungroup() |>
  filter(hour_num < 25) |>
  group_by(year) |>
  summarize(
    count = sum(count)
  )

plot_ly(
  df_num_bids_total_year,
  x = ~year,
  y = ~count,
  type = "bar",
  marker = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    df_num_bids_total_year$year,
    "<br><b>", gettext("Number of bids"),
    "</b>: ", formatC(df_num_bids_total_year$count, big.mark = " "),
    "<extra></extra>"
  )
) |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    separators = ".\u202F",
    margin = list(t = 50),
    xaxis = list(
      fixedrange = TRUE,
      dtick = 1,
      title = gettext("Year")
    )
  ) %>%
  layout(yaxis = list(
    fixedrange = TRUE,
    title = gettext("Count"),
    tickformat = ",d"
  )) |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local())
