num_bids_time_year <- fromJSONwithToken(api_endpoint("/auctions_bid_times")) |>
  mutate(report_datetime_range = as.character(report_datetime_range)) |>
  separate(
    report_datetime_range,
    into = c("start_time", "end_time"),
    sep = ",",
    extra = "drop"
  ) %>%
  mutate(
    start_time = gsub("\\[|\"", "", start_time),
    end_time = gsub("\\)|\"", "", end_time),
    date = as.Date(date),
    start_time = ymd_hms(start_time, tz = "UTC"),
    cet_cest_start = with_tz(start_time, tzone = "Europe/Prague"),
    end_time = ymd_hms(end_time, tz = "UTC"),
    cet_cest_end = with_tz(end_time, tzone = "Europe/Prague"),
    year = year(cet_cest_start)
  ) |>
  select(year, count, hour_num) |>
  group_by(year, hour_num) %>%
  summarise(
    mean = mean(count),
    count = sum(count)
  ) |>
  left_join(intervals) |>
  ungroup() |>
  filter(hour_num < 25)

plot_ly(
  num_bids_time_year,
  x = ~year,
  y = ~mean,
  split = ~hour_num,
  type = "bar",
  color = ~hour_num,
  colors = dashboard_pal(24),
  hovertemplate = paste0(
    num_bids_time_year$year,
    "<br>", num_bids_time_year$start_time_hour,
    " \U2013 ", num_bids_time_year$end_time_hour,
    "<br><b>", gettext("Mean bids"), "</b>: ",
    round(num_bids_time_year$mean, 2),
    "<br><b>", gettext("Number of bids"),
    "</b>: ", formatC(num_bids_time_year$count, big.mark = " "),
    "<extra></extra>"
  )
) |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    legend = list(
      title = list(text = gettext("Hour of Day")),
      orientation = "h",
      xanchor = "center",
      yanchor = "bottom",
      x = 0.5,
      y = 1.1
    ),
    separators = ".\u202F",
    margin = list(t = 50),
    xaxis = list(
      fixedrange = TRUE,
      dtick = 1,
      title = gettext("Year")
    )
  ) %>%
  layout(yaxis = list(
    fixedrange = TRUE,
    title = gettext("Mean bids"),
    tickformat = ",d"
  )) |>
  hide_colorbar()
