df_pre_max_day <- fromJSONwithToken(api_endpoint("/auctions_pre_auction_strategies")) |>
  mutate(
    ts = as.Date(date),
    count_num_pre_auction_bid_strategies = replace_na(count_num_pre_auction_bid_strategies, 0),
    count_num_auctions = replace_na(count_num_auctions, 0),
    count_num_persons = replace_na(count_num_persons, 0)
  ) |>
  arrange(ts)

plot_ly(
  df_pre_max_day,
  x = ~ts,
  y = ~count_num_pre_auction_bid_strategies,
  type = "scatter",
  mode = "lines",
  hovertemplate = ~ paste0(
    "<b>", gettext("Number of set pre-auction strategies"),
    "</b>: ", formatC(count_num_pre_auction_bid_strategies, big.mark = " "),
    "<extra></extra>"
  ),
  name = gettext("Number of set pre-auction strategies"),
  line = list(color = dashboard_colors[1]),
  hoverinfo = "text"
) |>
  add_trace(
    y = ~count_num_auctions,
    name = gettext("Number of auctions with set pre-auction strategies"),
    mode = "lines",
    hovertemplate = ~ paste0(
      "<b>", gettext("Number of auctions with set pre-auction strategies"),
      "</b>: ", formatC(count_num_auctions, big.mark = " "), "<extra></extra>"
    ),
    line = list(color = dashboard_colors[3])
  ) |>
  add_trace(
    y = ~count_num_persons,
    name = gettext("Number of people who set pre-auction strategies"),
    mode = "lines",
    hovertemplate = ~ paste0(
      "<b>", gettext("Number of people who set pre-auction strategies"),
      "</b>: ", formatC(count_num_persons, big.mark = " "), "<extra></extra>"
    ),
    line = list(color = dashboard_colors[2])
  ) |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local()) |>
  layout(
    hovermode = "x unified",
    margin = list(t = 75),
    legend = list(
      orientation = "h",
      xanchor = "center",
      x = 0.5,
      y = 1.08
    ),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 7,
            label = gettext("7 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 15,
            label = gettext("15 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title      = gettext("Count"),
      tickformat = ",d"
    )
  ) %>%
  layout(
    hovermode = "x unified",
    autosize = TRUE,
    xaxis = list(showgrid = TRUE, zeroline = FALSE),
    yaxis = list(showgrid = TRUE, zeroline = FALSE)
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local())
