df_prestrategy_year <-
  fromJSONwithToken(api_endpoint("/auctions_pre_auction_strategies")) |>
  mutate(
    ts = as.Date(date),
    year = year(ts),
    count_num_pre_auction_bid_strategies = replace_na(count_num_pre_auction_bid_strategies, 0),
    count_num_auctions = replace_na(count_num_auctions, 0),
    count_num_persons = replace_na(count_num_persons, 0)
  ) |>
  group_by(year) %>%
  summarise(
    count_num_pre_auction_bid_strategies = sum(count_num_pre_auction_bid_strategies),
    count_num_auctions = sum(count_num_auctions),
    count_num_persons = sum(count_num_persons)
  )

plot_ly(df_prestrategy_year,
  x = ~year,
  y = ~count_num_pre_auction_bid_strategies,
  type = "bar",
  marker = list(color = dashboard_colors[1]),
  name = gettext("Number of set pre-auction strategies"),
  hovertemplate = paste0(
    "<b>", gettext("Number of set pre-auction strategies"), "</b>: ",
    df_prestrategy_year$count_num_pre_auction_bid_strategies,
    "<extra></extra>"
  )
) |>
  add_trace(
    y = ~count_num_auctions,
    name = gettext("Number of auctions with set pre-auction strategies"),
    marker = list(color = dashboard_colors[3]),
    hovertemplate = paste0(
      "<b>", gettext("Number of auctions with set pre-auction strategies"),
      "</b>: ",
      formatC(df_prestrategy_year$count_num_auctions,
        format = "d",
        big.mark = "\u202F"
      ), "<extra></extra>"
    )
  ) |>
  add_trace(
    y = ~count_num_persons,
    name = gettext("Number of people who set pre-auction strategies"),
    marker = list(color = dashboard_colors[2]),
    hovertemplate = paste0(
      "<b>", gettext("Number of people who set pre-auction strategies"),
      "</b>: ",
      formatC(df_prestrategy_year$count_num_persons,
        format = "d",
        big.mark = "\u202F"
      ), "<extra></extra>"
    )
  ) |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    hovermode = "x unified",
    legend = list(
      orientation = "h",
      xanchor = "center",
      yanchor = "bottom",
      x = 0.5,
      y = 0.99
    ),
    separators = ".\u202F",
    margin = list(t = 50),
    xaxis = list(
      fixedrange = TRUE,
      dtick = 1,
      title = gettext("Year")
    )
  ) %>%
  layout(yaxis = list(
    fixedrange = TRUE,
    title = gettext("Count"),
    tickformat = ",d"
  ))
