df_prolonged <-
  fromJSONwithToken(api_endpoint("/auctions_auctions_summary")) |>
  mutate(date = as.Date(date)) |>
  select(date, prolonged) |>
  arrange(date)

plot_ly(
  name = gettext("Number of auctions"),
  type = "scatter",
  mode = "lines",
  x = ~date,
  y = ~prolonged,
  data = df_prolonged,
  hovertemplate = ~ paste0(
    "<b>", gettext("Number of auctions"),
    "</b>: ", prolonged, "<extra></extra>"
  ),
  line = list(color = dashboard_colors[1])
) |>
  layout(
    hovermode = "x unified",
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons =
          list(
            list(
              count    = 7,
              label    = gettext("7 d"),
              step     = "day",
              stepmode = "backward"
            ),
            list(
              count    = 1,
              label    = gettext("1 m"),
              step     = "month",
              stepmode = "backward"
            ),
            list(
              count    = 6,
              label    = gettext("6 m"),
              step     = "month",
              stepmode = "backward"
            ),
            list(
              count    = 1,
              label    = gettext("1 y"),
              step     = "year",
              stepmode = "backward"
            ),
            list(
              count    = 2,
              label    = gettext("2 y"),
              step     = "year",
              stepmode = "backward"
            ),
            list(
              count    = 4,
              label    = gettext("4 y"),
              step     = "year",
              stepmode = "backward"
            ),
            list(
              step = "all",
              label = gettext("all")
            )
          ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(title = gettext("Number of auctions"))
  ) |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) |>
  htmlwidgets::onRender(add_csv_button_local())
