df_prolonged <-
  fromJSONwithToken(api_endpoint("/auctions_auctions_summary")) |>
  mutate(date = as.Date(date)) |>
  select(date, prolonged) |>
  arrange(date)

df_prolonged <- df_prolonged |>
  select(date, prolonged) |>
  mutate(date = as.Date(date)) |>
  arrange(date)

df_prolonged <- df_prolonged |>
  mutate(
    month = month(date),
    year  = year(date)
  ) |>
  group_by(year, month) |>
  mutate(
    month_start = min(date),
    month_end   = max(date)
  ) |>
  reframe(
    prolonged = sum(prolonged),
    month_start = month_start,
    month_end = month_end
  ) |>
  ungroup() |>
  distinct()

plot_ly(
  name = gettext("Number of auctions"),
  type = "scatter",
  mode = "lines",
  x = ~month_end,
  y = ~prolonged,
  data = df_prolonged,
  line = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    "<b>", gettext("Number of auctions"), "</b>: %{y}<extra></extra>"
  )
) |>
  layout(
    hovermode = "x unified",
    xaxis = list(
      title = gettext("Month"),
      rangeselector = list(
        buttons = list(
          list(
            count = 3,
            label = gettext("3 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 3,
            label = gettext("3 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(title = gettext("Number of auctions"))
  ) |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) |>
  htmlwidgets::onRender(add_csv_button_local())
