df_prolonged <-
  fromJSONwithToken(api_endpoint("/auctions_auctions_summary")) |>
  mutate(date = as.Date(date)) |>
  select(date, prolonged) |>
  arrange(date)

df_prolonged <- df_prolonged |>
  select(date, prolonged) |>
  mutate(date = as.Date(date)) |>
  arrange(date)

df_prolonged <- df_prolonged |>
  mutate(
    week = isoweek(date),   # ISO week number, takes into consideration the changing of year
    year = isoyear(date)    # ISO year
  ) |>
  group_by(year, week) |>
  mutate(
    week_start = floor_date(date, unit = "week", week_start = 1),
    week_end   = ceiling_date(date, unit = "week", week_start = 1)
  ) |>
  reframe(
    prolonged = sum(prolonged),
    week_start = week_start,
    week_end = week_end
  ) |>
  ungroup() |>
  distinct()

plot_ly(
  name = gettext("Number of auctions"),
  type = "scatter",
  mode = "lines",
  x = ~week_end,
  y = ~prolonged,
  data = df_prolonged,
  line = list(color = dashboard_colors[1]),
  hovertemplate = paste0(
    "<b>", gettext("Number of auctions"), "</b>: %{y}<extra></extra>"
  )
) |>
  add_trace(
    y = 0,
    name = gettext("Date"),
    line = list(color = "rgba(255, 0, 0, 0)"),
    customdata = paste0(
      gettext("from"),
      " <b>",
      format(df_prolonged$week_start, locale_date_format()),
      "</b> ",
      gettext("to"),
      " <b>",
      format(df_prolonged$week_end, locale_date_format()),
      "</b>"
    ),
    hovertemplate = paste0(
      gettext("Week"), " %{customdata}", "<extra></extra>"
    ),
    visible = TRUE,
    legendrank = 1,
    showlegend = FALSE
  ) |>
  layout(
    hovermode = "x unified",
    xaxis =
      list(
        title = gettext("Week"),
        rangeselector = list(
          buttons = list(
            list(
              count = 15,
              label = gettext("15 d"),
              step = "day",
              stepmode = "backward"
            ),
            list(
              count = 1,
              label = gettext("1 m"),
              step = "month",
              stepmode = "backward"
            ),
            list(
              count = 6,
              label = gettext("6 m"),
              step = "month",
              stepmode = "backward"
            ),
            list(
              count = 1,
              label = gettext("1 y"),
              step = "year",
              stepmode = "backward"
            ),
            list(
              count = 3,
              label = gettext("3 y"),
              step = "year",
              stepmode = "backward"
            ),
            list(
              count = 6,
              label = gettext("6 y"),
              step = "year",
              stepmode = "backward"
            ),
            list(
              step = "all",
              label = gettext("all")
            )
          ),
          rangeslider = list(type = "date")
        )
      ),
    yaxis = list(title = gettext("Number of auctions"))
  ) |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) |>
  htmlwidgets::onRender(add_csv_button_local())
