df_sk3_month <- fromJSONwithToken(api_endpoint("/auctions_auctions_summary")) |>
  select(date, registered, num_paid) |>
  mutate(ts = as.Date(date))


df_sk3_month <- df_sk3_month |>
  mutate(ts = as.Date(ts), month = month(ts), year = year(ts)) |>
  group_by(month, year) |>
  mutate(
    month_start = min(ts),
    month_end = max(ts)
  ) |>
  group_by(month, year, month_start, month_end) |>
  summarise(registered = sum(registered), num_paid = sum(num_paid)) |>
  ungroup() |>
  mutate(perc = round(registered * 100 / num_paid, 2)) |>
  arrange(month_end)


plot2 <- plot_ly(df_sk3_month,
  x = ~month_end,
  y = ~num_paid,
  name = gettext("Number of paid domains"),
  mode = "lines",
  hovertemplate = paste0(
    "<b>", gettext("Number of paid domains"), "</b>: %{y}<extra></extra>"
  ),
  line = list(color = dashboard_colors[1])
) |>
  add_lines() |>
  add_trace(
    y = ~registered,
    name = gettext("Registered domains"),
    line = list(color = dashboard_colors[3]),
    hovertemplate = paste0(
      "<b>", gettext("Registered domains"),
      "</b>: %{y}<extra></extra>"
    )
  ) |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local()) |>
  layout(
    hovermode = "x unified",
    margin = list(t = 75),
    title = gettext("Monthly registered domains"),
    legend = list(
      orientation = "h",
      xanchor = "center",
      x = 0.5,
      y = 1.08
    ),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Month"),
      rangeselector = list(
        buttons = list(
          list(
            count = 3,
            label = gettext("3 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 3,
            label = gettext("3 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Number of domains"),
      tickformat = ",d"
    )
  )

ratio <- plot_ly(df_sk3_month,
  x = ~month_end,
  y = ~perc,
  type = "scatter",
  name = paste0(
    gettext("Ratio of registered domains"), " (%)"
  ),
  mode = "lines",
  line = list(color = dashboard_colors[2]),
  hovertemplate = paste0(
    "<b>",
    gettext("Number of paid domains"), "</b>: ",
    formatC(df_sk3_month$num_paid, big.mark = " "), "<br><b>",
    gettext("Registered domains"), "</b>: ",
    formatC(df_sk3_month$registered,
      big.mark = " "
    ), "<br><b>",
    gettext("Ratio (%)"), "</b>: %{y}<br><b><extra></extra>"
  )
) %>%
  layout(
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 7,
            label = gettext("7 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 15,
            label = gettext("15 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date"),
        x = 0.8
      )
    ),
    yaxis = list(
      title = paste0(
        gettext("Ratio of registered domains"), " (%)"
      ),
      ticksuffix = "%"
    )
  )



subplot(plot2, ratio,
  margin = 0.06, titleX = TRUE, titleY = TRUE, nrows = 1
) %>%
  layout(
    hovermode = "x unified",
    autosize = TRUE,
    xaxis = list(showgrid = TRUE, zeroline = FALSE),
    yaxis = list(showgrid = TRUE, zeroline = FALSE)
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local())
