df_sk3_year <- fromJSONwithToken(api_endpoint("/auctions_auctions_summary")) |>
  select(date, registered, num_paid) |>
  mutate(
    ts = as.Date(date), year = year(ts),
    registered = replace_na(registered, 0),
    num_paid = replace_na(num_paid, 0)
  ) |>
  group_by(year) %>%
  summarise(
    registered = sum(registered),
    num_paid = sum(num_paid),
    perc = round(registered * 100 / num_paid, 2)
  )

fig <- plot_ly(df_sk3_year,
  x = ~year,
  y = ~num_paid,
  type = "bar",
  marker = list(color = dashboard_colors[1]),
  name = gettext("Number of paid domains"),
  hovertemplate = paste0(
    "<b>", gettext("Number of paid domains"), "</b>: ", df_sk3_year$num_paid,
    "<extra></extra>"
  )
) |>
  add_trace(
    y = ~registered,
    name = gettext("Registered domains"),
    marker = list(color = dashboard_colors[3]),
    hovertemplate = paste0(
      "<b>", gettext("Registered domains"), "</b>: ",
      formatC(df_sk3_year$registered,
        format = "d",
        big.mark = "\u202F"
      ), " (", round(df_sk3_year$perc, 2), "%)",
      "<extra></extra>"
    )
  )

fig <- fig %>%
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    hovermode = "x unified",
    title = gettext("Yearly registered domains"),
    legend = list(
      orientation = "h",
      xanchor = "center",
      yanchor = "bottom",
      x = 0.5,
      y = 0.99
    ),
    separators = ".\u202F",
    margin = list(t = 50),
    xaxis = list(
      fixedrange = TRUE,
      dtick = 1,
      title = gettext("Year")
    )
  ) %>%
  layout(yaxis = list(
    fixedrange = TRUE,
    title = gettext("Number of domains"),
    tickformat = ",d"
  ))


fig
