#30 days
df_auctioned_domains_30d <-
  fromJSONwithToken(api_endpoint("/auctions_auctions_summary")) |>
  mutate(date = as.Date(date)) |>
  filter(date >= Sys.Date() - 30) |>
  arrange(date) |>
  mutate(paid = replace_na(paid, 0))

df_bidders_30d <-
  fromJSONwithToken(api_endpoint("/auctions_bidders_30d")) |>
  select(total, date) |>
  mutate(date = as.Date(date)) |>
  rename("bidders" = total)

df_price_30d <-
  fromJSONwithToken(api_endpoint("/auctions_top_auctions")) |>
  mutate(date = as.Date(date)) |>
  rename("price_max" = price) |>
  filter(date >= Sys.Date() - 30) |>
  reframe(price_max = max(price_max))

df_auctions_summary_30d <-
  left_join(df_auctioned_domains_30d, df_bidders_30d, by = "date") |>
  bind_cols(df_price_30d)

df_auctions_summary_30d <- df_auctions_summary_30d |>
  reframe(
    price_max = price_max,
    domains   = sum(auctioned),
    bidders   = na.omit(bidders),
    price_avg = round(sum(tot_sum) / sum(auctioned), 0),
    auctioned = sum(tot_sum),
    paid      = sum(paid)
  ) |>
  distinct()

#2 years
df_auctioned_domains_2y <-
  fromJSONwithToken(api_endpoint("/auctions_auctions_summary")) |>
  mutate(date = as.Date(date)) |>
  filter(date >= Sys.Date() - 730) |>
  arrange(date) |>
  mutate(paid = replace_na(paid, 0))

df_bidders_2y <-
  fromJSONwithToken(api_endpoint("/auctions_bidders_730d")) |>
  select(total, date) |>
  mutate(date = as.Date(date)) |>
  rename("bidders" = total)

df_price_2y <-
  fromJSONwithToken(api_endpoint("/auctions_top_auctions")) |>
  mutate(date = as.Date(date)) |>
  rename("price_max" = price) |>
  filter(date >= Sys.Date() - 730) |>
  reframe(price_max = max(price_max))

df_auctions_summary_2y <-
  left_join(df_auctioned_domains_2y, df_bidders_2y, by = "date") |>
  bind_cols(df_price_2y)

df_auctions_summary_2y <- df_auctions_summary_2y |>
  reframe(
    price_max = price_max,
    domains   = sum(auctioned),
    bidders   = na.omit(bidders),
    price_avg = round(sum(tot_sum) / sum(auctioned), 0),
    auctioned = sum(tot_sum),
    paid      = sum(paid)
  ) |>
  distinct()

#Users 180 days
df_users <-
  fromJSONwithToken(api_endpoint("/mojeid_dombr_users_180d")) |>
  select(users) |>
  rename(
    "active_users" = users
  )

#Combine and export as JSON
auctions_summaries <- list(
  last30days = as.list(df_auctions_summary_30d),
  last180days = as.list(df_users),
  last730days = as.list(df_auctions_summary_2y)
)

#Export to JSON
auctions_summary_table <- toJSON(auctions_summaries,
                                 auto_unbox = TRUE,
                                 pretty = TRUE)
write(auctions_summary_table, "../images/auctions_summary_table.json")
