df <- fromJSONwithToken(api_endpoint("/auctions_winners")) |>
  filter(date == max(date)) |>
  select(date, account, auctions_won, num_auctions_paid, num_auctions_registered) |>
  mutate(account = fct_lump_n(account,
                              n = 10, w = auctions_won,
                              other_level = gettext("other"))) |>
  gather(type, count, auctions_won, num_auctions_paid, num_auctions_registered) %>%
  mutate(type = ifelse(type == "auctions_won",
                       gettext("auctions won"),
                       ifelse(type == "num_auctions_paid",
                              gettext("num auctions paid"),
                              gettext("num auctions registered"))),
         type = factor(type, levels = c(gettext("auctions won"),
                                        gettext("num auctions paid"),
                                        gettext("num auctions registered"))))

unique_accounts <- unique(df$account)
anon_dict <- setNames(paste0("User-", seq_along(unique_accounts)), unique_accounts)

df$short <- anon_dict[df$account]

#short = paste0(substr(account, 1, 14), "...."))

fig <- df |>
  ggplot(
    aes(
      reorder(short, count), count,
      fill = type,
      text =
        paste0(
          date,
          "<br><b>", type,
          "<br><b>", short,
          "<br>", gettext("Count"), "</b>: ",
          formatC(
            count,
            format = "d",
            big.mark = " "
          )
        )
    )
  ) +
  geom_bar(stat = "identity", fill = dashboard_pal(1)) +
  coord_flip() +
  facet_grid(. ~ type) +
  theme_bw() +
  labs(y = gettext("Count"), x = gettext("Anonymous accounts")) +
  scale_y_continuous(breaks = seq(0, max(df$count), by = 1)) +
  theme(
    strip.background = element_rect(fill = "white", color = "black"),
    strip.text = element_text(color = "black", face = "bold")
  ) +
  scale_y_continuous(labels = function(x) format(x, big.mark = " ", scientific = FALSE))

ggplotly(fig, tooltip = "text") %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    margin = list(t = 50),
    xaxis = list(fixedrange = TRUE)
  ) %>%
  layout(yaxis = list(fixedrange = TRUE))
