df <- fromJSONwithToken(api_endpoint("/auctions_winners")) |>
  filter(date >= Sys.Date() - 7) |>
  select(date, account, total_amount, total_amount_paid, total_amount_unpaid) |>
  mutate(
    account =
      fct_lump_n(
        account,
        n = 10,
        w = total_amount,
        other_level = gettext("other")
      )
  ) |>
  gather(type, count, total_amount, total_amount_paid, total_amount_unpaid) |>
  group_by(account, type) |>
  summarise(count = sum(count)) |>
  ungroup() %>%
  mutate(
    type =
      ifelse(
        type == "total_amount",
        gettext("total amount"),
        ifelse(
          type == "total_amount_paid",
          gettext("total amount paid"),
          gettext("total amount unpaid")
        )
      )
  )


unique_accounts <- unique(df$account)
anon_dict <- setNames(paste0("User-", seq_along(unique_accounts)), unique_accounts)

df$short <- anon_dict[df$account]

fig <- df |>
  ggplot(
    aes(
      reorder(short, count), count,
      fill = type,
      group = 1,
      text = paste0(
        "<br><b>", type,
        "<br><b>", short,
        "<br>", gettext("Sum (CZK)"), "</b>: ",
        formatC(
          count,
          format = "d",
          big.mark = " "
        )
      )
    )
  ) +
  geom_bar(stat = "identity", fill = dashboard_pal(1)) +
  coord_flip() +
  facet_grid(. ~ factor(type, levels = c(gettext("total amount"),
                                         gettext("total amount paid"),
                                         gettext("total amount unpaid")))) +
  theme_bw() +
  labs(y = gettext("Sum (CZK)"), x = gettext("Anonymous accounts")) +
  theme(
    strip.background = element_rect(fill = "white", color = "black"),
    strip.text = element_text(color = "black", face = "bold")
  ) +
  scale_y_continuous(labels = function(x) format(x, big.mark = " ", scientific = FALSE))


ggplotly(fig, tooltip = "text") %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    margin = list(t = 50),
    xaxis = list(fixedrange = TRUE)
  ) %>%
  layout(yaxis = list(fixedrange = TRUE))
