df_track_month <- fromJSONwithToken(api_endpoint("/auctions_watchers")) |>
  mutate(
    ts = as.Date(date),
    count_num_auctions = replace_na(count_num_auctions, 0),
    count_num_watchdogs = replace_na(count_num_watchdogs, 0),
    count_num_watched_auctions = replace_na(count_num_watched_auctions, 0),
    count_num_persons = replace_na(count_num_persons, 0)
  ) |>
  arrange(ts)


df_track_month  <- df_track_month  |>
  mutate(ts = as.Date(ts), month = month(ts), year = year(ts)) |>
  group_by(month, year) |>
  mutate(
    month_start = min(ts),
    month_end = max(ts)
  ) |>
  group_by(month, year, month_start, month_end) |>
  summarise(
    count_num_auctions = sum(count_num_auctions),
    count_num_watchdogs = sum(count_num_watchdogs),
    count_num_watched_auctions = sum(count_num_watched_auctions),
    count_num_persons = sum(count_num_persons)
  ) |>
  ungroup() |>
  arrange(month_end)




plot_ly(
  df_track_month,
  x = ~month_end,
  y = ~count_num_watchdogs,
  type = "scatter",
  mode = "lines",
  hovertemplate = ~ paste0(
    "<b>", gettext("Number of set watchdogs for auctions on given date"),
    "</b>: ", formatC(count_num_watchdogs, big.mark = " "), "<extra></extra>"
  ),
  name = gettext("Number of set watchdogs for auctions on given date"),
  line = list(color = dashboard_colors[3]),
  hoverinfo = "text"
) |>
  add_trace(
    y = ~count_num_auctions,
    name = gettext("Number of unique auctions starting on given date"),
    mode = "lines",
    hovertemplate = ~ paste0(
      "<b>", gettext("Number of unique auctions starting on given date"),
      "</b>: ", formatC(count_num_auctions, big.mark = " "), "<extra></extra>"
    ),
    line = list(color = dashboard_pal(4)[3])
  ) |>
  add_trace(
    y = ~count_num_watched_auctions,
    name = gettext("Number of unique auctions with watchers on given date"),
    mode = "lines",
    hovertemplate = ~ paste0(
      "<b>", gettext("Number of unique auctions with watchers on given date"),
      "</b>: ", formatC(count_num_watched_auctions, big.mark = " "), "<extra></extra>"
    ),
    line = list(color = dashboard_colors[1])
  ) |>
  add_trace(
    y = ~count_num_persons,
    name = gettext("Number of people watching upcoming auctions on given date"),
    mode = "lines",
    hovertemplate = ~ paste0(
      "<b>", gettext("Number of people watching upcoming auctions on given date"),
      "</b>: ", formatC(count_num_persons, big.mark = " "), "<extra></extra>"
    ),
    line = list(color = dashboard_colors[2])
  ) |>
  layout(
    hovermode = "x unified",
    margin = list(t = 75),
    legend = list(
      orientation = "h",
      xanchor = "center",
      x = 0.5,
      y = 1.08
    ),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Month"),
      rangeselector = list(
        buttons = list(
          list(
            count = 3,
            label = gettext("3 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            count = 3,
            label = gettext("3 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Count"),
      tickformat = ",d"
    )
  ) %>%
  layout(
    hovermode = "x unified",
    autosize = TRUE,
    xaxis = list(showgrid = TRUE, zeroline = FALSE),
    yaxis = list(showgrid = TRUE, zeroline = FALSE)
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local())
