df_track_week <- fromJSONwithToken(api_endpoint("/auctions_watchers")) |>
  mutate(
    ts = as.Date(date),
    count_num_auctions = replace_na(count_num_auctions, 0),
    count_num_watchdogs = replace_na(count_num_watchdogs, 0),
    count_num_watched_auctions = replace_na(count_num_watched_auctions, 0),
    count_num_persons = replace_na(count_num_persons, 0)
  ) |>
  arrange(ts)



df_track_week <- df_track_week |>
  mutate(
    week = week(date),
    year = year(date)
  ) |>
  group_by(year, week) |>
  mutate(
    week_start = floor_date(ts, unit = "week", week_start = 1),
    week_end   = ceiling_date(ts, unit = "week", week_start = 1)
  ) |>
  select(
    ts,
    week_start,
    week_end,
    count_num_auctions,
    count_num_watchdogs,
    count_num_watched_auctions,
    count_num_persons
  ) |>
  group_by(week_start, week_end) |>
  summarise(count_num_auctions = sum(count_num_auctions),
            count_num_watchdogs = sum(count_num_watchdogs),
            count_num_watched_auctions = sum(count_num_watched_auctions),
            count_num_persons = sum(count_num_persons)) |>
  ungroup() |>
  arrange(week_end)




plot_ly(
  df_track_week,
  x = ~as.Date(week_end),
  y = ~count_num_watchdogs,
  type = "scatter",
  mode = "lines",
  hovertemplate = ~ paste0(
    "<b>", gettext("Number of set watchdogs for auctions on given date"),
    "</b>: ", formatC(count_num_watchdogs, big.mark = " "), "<extra></extra>"
  ),
  name = gettext("Number of set watchdogs for auctions on given date"),
  line = list(color = dashboard_colors[3]),
  hoverinfo = "text"
) |>
  add_trace(
    y = ~count_num_auctions,
    name = gettext("Number of unique auctions starting on given date"),
    mode = "lines",
    hovertemplate = ~ paste0(
      "<b>", gettext("Number of unique auctions starting on given date"),
      "</b>: ", formatC(count_num_auctions, big.mark = " "), "<extra></extra>"
    ),
    line = list(color = dashboard_pal(4)[3])
  ) |>
  add_trace(
    y = ~count_num_watched_auctions,
    name = gettext("Number of unique auctions with watchers on given date"),
    mode = "lines",
    hovertemplate = ~ paste0(
      "<b>", gettext("Number of unique auctions with watchers on given date"),
      "</b>: ", formatC(count_num_watched_auctions, big.mark = " "), "<extra></extra>"
    ),
    line = list(color = dashboard_colors[1])
  ) |>
  add_trace(
    y = ~count_num_persons,
    name = gettext("Number of people watching upcoming auctions on given date"),
    mode = "lines",
    hovertemplate = ~ paste0(
      "<b>", gettext("Number of people watching upcoming auctions on given date"),
      "</b>: ", formatC(count_num_persons, big.mark = " "), "<extra></extra>"
    ),
    line = list(color = dashboard_colors[2])
  ) |>
  add_trace(
    y = 0,
    name = gettext("Date"),
    line = list(color = "rgba(255, 0, 0, 0)"),
    customdata = paste0(
      gettext("from"),
      " <b>",
      format(df_track_week$week_start),
      "</b> ",
      gettext("to"),
      " <b>",
      format(df_track_week$week_end),
      "</b>"
    ),
    hovertemplate = paste0(
      gettext("Week"), " %{customdata}", "<extra></extra>"
    ),
    visible = TRUE,
    legendrank = 1,
    showlegend = FALSE
  ) |>
  layout(
    hovermode = "x unified",
    margin = list(t = 75),
    legend = list(
      orientation = "h",
      xanchor = "center",
      x = 0.5,
      y = 1.08
    ),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Week"),
      rangeselector = list(
        buttons = list(
          list(
            count = 15,
            label = gettext("15 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Count"),
      tickformat = ",d"
    )
  )  %>%
  layout(
    hovermode = "x unified",
    autosize = TRUE,
    xaxis = list(showgrid = TRUE, zeroline = FALSE),
    yaxis = list(showgrid = TRUE, zeroline = FALSE)
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local())
