df_track_year <- fromJSONwithToken(api_endpoint("/auctions_watchers")) |>
  mutate(
    ts = as.Date(date),
    year = year(ts),
    count_num_auctions = replace_na(count_num_auctions, 0),
    count_num_watchdogs = replace_na(count_num_watchdogs, 0),
    count_num_watched_auctions = replace_na(count_num_watched_auctions, 0),
    count_num_persons = replace_na(count_num_persons, 0)
  ) |>
  group_by(year) |>
  summarise(
    count_num_auctions = sum(count_num_auctions),
    count_num_watchdogs = sum(count_num_watchdogs),
    count_num_watched_auctions = sum(count_num_watched_auctions),
    count_num_persons = sum(count_num_persons)
  ) |>
  ungroup()


plot_ly(
  df_track_year,
  x = ~year,
  y = ~count_num_auctions,
  type = "bar",
  hovertemplate = ~ paste0(
    "<b>", gettext("Number of unique auctions starting on given date"),
    "</b>: ", formatC(df_track_year$count_num_auctions, big.mark = " "), "<extra></extra>"
  ),
  name = gettext("Number of unique auctions starting on given date"),
  marker = list(color = dashboard_pal(4)[3]),
  hoverinfo = "text"
) |>
  add_trace(
    y = ~count_num_watchdogs,
    name = gettext("Number of set watchdogs for auctions on given date"),
    hovertemplate = ~ paste0(
      "<b>", gettext("Number of set watchdogs for auctions on given date"),
      "</b>: ", formatC(count_num_watchdogs, big.mark = " "), "<extra></extra>"
    ),
    marker = list(color = dashboard_colors[3])
  ) |>
  add_trace(
    y = ~count_num_watched_auctions,
    name = gettext("Number of unique auctions with watchers on given date"),
    hovertemplate = ~ paste0(
      "<b>", gettext("Number of unique auctions with watchers on given date"),
      "</b>: ", formatC(count_num_watched_auctions, big.mark = " "), "<extra></extra>"
    ),
    marker = list(color = dashboard_colors[1])
  ) |>
  add_trace(
    y = ~count_num_persons,
    name = gettext("Number of people watching upcoming auctions on given date"),
    hovertemplate = ~ paste0(
      "<b>", gettext("Number of people watching upcoming auctions on given date"),
      "</b>: ", formatC(count_num_persons, big.mark = " "), "<extra></extra>"
    ),
    marker = list(color = dashboard_colors[2])
  )  |>
  config(
    displayModeBar = TRUE,
    locale = locale_lang_code()
  ) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    hovermode = "x unified",
    legend = list(
      orientation = "h",
      xanchor = "center",
      yanchor = "bottom",
      x = 0.5,
      y = 0.99
    ),
    separators = ".\u202F",
    margin = list(t = 50),
    xaxis = list(
      fixedrange = TRUE,
      dtick = 1,
      title = gettext("Year")
    )
  ) %>%
  layout(yaxis = list(
    fixedrange = TRUE,
    title = gettext("Count"),
    tickformat = ",d"
  ))
