df_winstrategy_day <-
  fromJSONwithToken(api_endpoint("/auctions_winner_bid_strategy_types")) |>
  mutate(
    ts = as.Date(date),
    bid_strategy_type = replace_na(bid_strategy_type, 0),
    count = replace_na(count, 0)
  ) |>
  spread(bid_strategy_type, count) |>
  arrange(ts)

plot_ly(
  df_winstrategy_day,
  x = ~ts,
  y = ~MAX,
  type = "scatter",
  mode = "lines",
  hovertemplate = ~ paste0(
    "<b>", gettext("MAX"),
    "</b>: ", formatC(MAX, big.mark = " "), "<extra></extra>"
  ),
  name = gettext("MAX"),
  line = list(color = dashboard_colors[1]),
  hoverinfo = "text"
) |>
  add_trace(
    y = ~SPOT,
    name = gettext("SPOT"),
    mode = "lines",
    hovertemplate = ~ paste0(
      "<b>", gettext("SPOT"),
      "</b>: ", formatC(SPOT, big.mark = " "), "<extra></extra>"
    ),
    line = list(color = dashboard_colors[3])
  ) |>
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local()) |>
  layout(
    hovermode = "x unified",
    margin = list(t = 75),
    legend = list(
      orientation = "h",
      xanchor = "center",
      x = 0.5,
      y = 1.08
    ),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 7,
            label = gettext("7 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 15,
            label = gettext("15 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title      = gettext("Count"),
      tickformat = ",d"
    )
  ) %>%
  layout(
    hovermode = "x unified",
    autosize = TRUE,
    xaxis = list(showgrid = TRUE, zeroline = FALSE),
    yaxis = list(showgrid = TRUE, zeroline = FALSE)
  ) %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) |>
  htmlwidgets::onRender(add_csv_button_local())
