tz <- "Europe/Prague"
num_days <- 29

df_rtt <- fromJSONwithToken(api_endpoint("/dk_rtt_cc_server_ipv_1d",
  ts = get_ts(days, num_days + 1)
)) %>%
  mutate(ts = as.Date(ts))
df_qps <- fromJSONwithToken(api_endpoint("/dk_qps_cc_server_ipv_1d",
  ts = get_ts(days, num_days + 1)
)) %>%
  mutate(ts = as.Date(ts))
country_codes <- load_country_codes() %>%
  rename(country_name = Country)
country_flags <- load_country_flags()

df_rtt_qps <- left_join(df_qps, df_rtt)

df_rtt_country_ts <- df_rtt_qps %>%
  group_by(ts, country_code) %>%
  summarise(
    mean_rtt_ts = weighted.mean(mean_median_rtt, qps, na.rm = TRUE),
    qps_ts = mean(qps)
  ) %>%
  ungroup()

df_rtt_country <- df_rtt_country_ts %>%
  group_by(country_code) %>%
  na.omit() %>%
  summarise(
    min_rtt = min(mean_rtt_ts, na.rm = TRUE),
    mean_qps = mean(qps_ts),
    mean_rtt = mean(mean_rtt_ts, na.rm = TRUE),
    max_rtt = max(mean_rtt_ts, na.rm = TRUE),
    stdv_rtt = sd(mean_rtt_ts, na.rm = TRUE),
    spark_rtt = spk_chr(
      mean_rtt_ts,
      type = "line",
      lineColor = sparkline_colors[1],
      fillColor = sparkline_colors[2],
      spotColor = TRUE,
      width = 80
    )
  )

rtt_country_table <- df_rtt_country %>%
  inner_join(country_codes, by = c("country_code")) %>%
  inner_join(country_flags, by = c("country_code")) %>%
  mutate(
    country_flag = get_country_flag_html(country_code, country_flag),
    min_tile = adam_color_tile(
      min_rtt,
      "white", dashboard_colors[1]
    ),
    mean_tile = adam_color_tile(
      mean_rtt,
      "white", dashboard_colors[3]
    ),
    max_tile = adam_color_tile(
      max_rtt,
      "white", dashboard_colors[1]
    ),
    stdv_tile = adam_color_tile(
      stdv_rtt,
      "white", dashboard_colors[2]
    )
  ) %>%
  arrange(desc(mean_qps)) %>%
  select(
    country_flag,
    country_name,
    max_tile,
    mean_tile,
    min_tile,
    stdv_tile,
    spark_rtt
  ) %>%
  kable(
    "html",
    table.attr = "data-search-cols='1,2'",
    escape = FALSE,
    format.args = list(big.mark = " "),
    align = c("l", "l", "r", "r", "r", "r", "l"),
    col.names = c(
      "",
      gettext("Country"),
      "Max",
      gettext("Mean"),
      "Min",
      "σ",
      "Trend"
    )
  ) %>%
  column_spec(1, width = "2.5em", extra_css = "vertical-align:top;") %>%
  column_spec(2, width = "100%", bold = TRUE) %>%
  column_spec(3, width = "3em") %>%
  column_spec(4, width = "3em") %>%
  column_spec(5, width = "3em") %>%
  column_spec(6, width = "3em") %>%
  column_spec(7, width = "90px") %>%
  kable_styling(
    full_width = TRUE,
    htmltable_class = paste(
      "adam-table-search",
      "adam-table-scroll",
      "dtable",
      "table-condensed"
    )
  )

rtt_country_table
