#' Fetch JSON data using `curl` with token
#' authentication ('Authorization: Bearer …')
#'
#' @param url JSON url
#' @param token Token
#' @return JSON data
#' @examples
#' fromJSONwithToken("https://…", "123456")
#' fromJSONwithToken("https://…") – token will be read from 'API_TOKEN' env
#'                                  variable if not specified
fromJSONwithToken <- function(url, token = Sys.getenv("API_TOKEN")) { # nolint because lintr wants snake_case
  curl_handle <- curl::new_handle()
  if (token != "") {
    curl::handle_setheaders(curl_handle,
      "Authorization" = paste("Bearer", token)
    )
  }
  request <- curl::curl_fetch_memory(url, handle = curl_handle)
  return(jsonlite::fromJSON(rawToChar(request$content)))
}
