df_rtt <- fromJSONwithToken(api_endpoint("/gov_rtt_cc_server_ipv_1d",
  ts = get_ts(months, 6)
))

df_qps <- fromJSONwithToken(api_endpoint("/gov_qps_cc_server_ipv_1d",
  ts = get_ts(months, 6)
))




df_rtt_qps <- left_join(df_qps, df_rtt) %>%
  mutate(
    country_code = ifelse(is.na(country_code), "Missing", country_code),
    region = countrycode::countrycode(country_code, "iso2c", "region23",
      custom_match = c(
        XK = "Eastern Europe", TF = "Melanesia", IO = "Southern Asia",
        GS = "South America", CX = "Australia and New Zealand",
        CC = "South-Eastern Asia", BV = "Southern Africa",
        AQ = "Antarctica", HM = "South-Eastern Asia"
      )
    ),
    continent = countrycode::countrycode(country_code, "iso2c", "continent",
      custom_match = c(
        XK = "Europe", TF = "Oceania", IO = "Asia",
        GS = "Americas", CX = "Oceania",
        CC = "Asia", BV = "Africa",
        AQ = "Antarctica", HM = "Asia"
      )
    ),
    region = ifelse(region %in% c("Melanesia", "Micronesia", "Polynesia"),
      gettext("Pacific Islands"),
      ifelse(region %in% c("Eastern Africa", "Middle Africa", "Southern Africa"),
        gettext("South-East Africa"),
        ifelse(region %in% c("Eastern Asia", "South-Eastern Asia", "Southern Asia"),
          gettext("South-Eastern Asia"),
          ifelse(region %in% c("Western Asia", "Central Asia"),
            gettext("Western-Central Asia"),
            ifelse(region %in% c("Central America", "Caribbean"),
              gettext("Central America & Caribbean"),
              ifelse(region %in% c("Western Africa", "Northern Africa"),
                gettext("North-West Africa"), region
              )
            )
          )
        )
      )
    )
  ) %>%
  mutate(region = ifelse(region == "South America", gettext("South America"),
    ifelse(region == "Southern Europe", gettext("Southern Europe "),
      ifelse(region == "Northern Europe", gettext("Northern Europe"),
        ifelse(region == "Eastern Europe", gettext("Eastern Europe"),
          ifelse(region == "Western Europe", gettext("Western Europe"),
            region
          )
        )
      )
    )
  ))

df_rtt_qps_country <- df_rtt_qps %>%
  mutate(ts = as_datetime(ts, tz = "Europe/Prague")) %>%
  filter(!is.na(continent)) %>%
  group_by(ts, region, continent) %>%
  summarise(
    total_qps = sum(qps),
    rtt = weighted.mean(mean_median_rtt, qps, na.rm = TRUE)
  ) %>%
  mutate(
    month = month(ts), year = year(ts),
    Date = as.Date(paste(year, month, 1, sep = "-"))
  ) %>%
  group_by(Date, month, year, region, continent) %>%
  summarise(total_qps = round(mean(total_qps), 2), rtt = mean(rtt)) %>%
  mutate(
    continent = ifelse(continent == "Oceania", gettext("Oceania"),
      ifelse(continent == "Americas", gettext("Americas"),
        ifelse(continent == "Europe", gettext("Europe"),
          ifelse(continent == "Asia", gettext("Asia"),
            ifelse(continent == "Africa", gettext("Africa"), continent)
          )
        )
      )
    )
  ) %>%
  filter(!is.na(rtt)) %>%
  ungroup()

arrow <- df_rtt_qps_country %>%
  filter(Date == max(Date)) %>%
  mutate(month = as.factor(month))


rtt_lines <- df_rtt_qps_country %>%
  ggplot(aes(total_qps, rtt,
    color = continent,
    group = region,
    text = paste(
      region, "\n", Date,
      "<b>\nQPS:</b>", total_qps,
      "<b>\nRTT (ms):</b>", round(rtt, 2)
    )
  )) +
  geom_point(size = 0.5) +
  geom_path() +
  geom_point(arrow,
    mapping = aes(total_qps, rtt,
      color = continent,
      group = region, shape = month
    ),
    shape = 1, size = 3
  ) +
  theme_bw() +
  scale_y_continuous(
    labels = function(x) {
      format(x,
        big.mark = " ",
        scientific = FALSE
      )
    }
  ) +
  scale_x_log10() +
  labs(
    x = gettext("Queries per second"),
    y = gettext("Round-trip time [ms]")
  ) +
  scale_color_manual(
    values = dashboard_pal(length(unique(df_rtt_qps_country$continent))),
    labels = c(
      gettext("Africa"), gettext("Americas"),
      gettext("Asia"), gettext("Europe"),
      gettext("Oceania")
    )
  )

ggplotly(rtt_lines, tooltip = "text") %>%
  config(displayModeBar = FALSE) %>%
  layout(
    margin = list(b = 140, r = 200),
    autosize = FALSE,
    xaxis = list(fixedrange = TRUE)
  ) %>%
  layout(yaxis = list(fixedrange = TRUE))
