endpoint_web <- api_endpoint("/crawler_web_ipv")

df_web <- fromJSONwithToken(endpoint_web) %>%
  mutate(type = "web")

endpoint_mail <- api_endpoint("/crawler_mail_ipv")
df_mail <- fromJSONwithToken(endpoint_mail) %>%
  mutate(type = "mail")

fig_web_mail <- df_web %>%
  rbind(df_mail) %>%
  mutate(
    ts = as.Date(ts),
    ip_support = ifelse(ip_support == "ipv6 only", gettext("IPv6 only"),
      ifelse(ip_support == "ipv4 only", gettext("IPv4 only"),
        gettext("IPv4 and IPv6")
      )
    )
  ) %>%
  ggplot(aes(ts, domains,
    text = paste0(
      "<b>\n", ts, "</b>",
      "<b>\n", ip_support, "</b>",
      "<b>\n", gettext("Domains"), "</b>: ", formatC(domains,
        format = "d",
        big.mark = " "
      )
    ),
    group = type,
    color = type
  )) +
  geom_line(aes(color = type)) +
  facet_wrap(. ~ reorder(ip_support, -domains), scale = "free_y") +
  theme_bw() +
  labs(y = gettext("Domains"), x = gettext("Date"), color = gettext("Type")) +
  scale_color_manual(values = rev(dashboard_pal(2))) +
  scale_x_date(date_labels = "%d.%b.%y") +
  scale_y_continuous(labels = scales::format_format(
    big.mark = " ",
    decimal.mark = ",",
    scientific = FALSE
  )) +
  theme(
    panel.spacing.x = unit(-0.8, "lines"),
    panel.spacing.y = unit(0.5, "lines")
  )


ggplotly(fig_web_mail, tooltip = "text") %>%
  config(displayModeBar = TRUE, locale = locale_lang_code()) %>%
  htmlwidgets::onRender(add_csv_button_local()) %>%
  layout(
    margin = list(t = 50),
    xaxis = list(fixedrange = TRUE)
  ) %>%
  layout(yaxis = list(fixedrange = TRUE))
