endpoint <- api_endpoint("/crawler_web_ipv")

df_web <- fromJSONwithToken(endpoint)


df_web |>
  filter(domains > 0) |>
  spread(ip_support, domains) |>
  mutate(ts = as.Date(ts)) |>
  plot_ly(
    x = ~ts,
    y = ~`ipv4 and ipv6`,
    type = "scatter",
    mode = "lines",
    line = list(color = dashboard_colors[1]),
    name = gettext("IPv4 & IPv6"),
    hovertemplate = ~ paste0(
      "<b>", gettext("IPv4 & IPv6"),
      "</b>: ", formatC(`ipv4 and ipv6`, format = "d", big.mark = " "), "<extra></extra>"
    )
  ) |>
  add_trace(
    y = ~`ipv4 only`,
    name = gettext("Only IPv4"),
    mode = "lines",
    hovertemplate = ~ paste0(
      "<b>", gettext("IPv4"),
      "</b>: ", formatC(`ipv4 only`, format = "d", big.mark = " "), "<extra></extra>"
    ),
    line = list(color = dashboard_colors[3]),
    visible = "legendonly",
    legendgroup = ~`ipv4 only`
  ) |>
  add_trace(
    y = ~`ipv6 only`,
    name = gettext("Only IPv6"),
    mode = "lines",
    hovertemplate = ~ paste0(
      "<b>", gettext("IPv6"),
      "</b>: ", formatC(`ipv6 only`, format = "d", big.mark = " "), "<extra></extra>"
    ),
    line = list(color = dashboard_colors[2]),
    visible = "legendonly",
    legendgroup = ~`ipv6 only`
  ) |>
  layout(
    hovermode = "x unified",
    margin = list(t = 75),
    legend = list(
      orientation = "h",
      xanchor = "center",
      x = 0.5,
      y = 1.08
    ),
    separators = ".\u202F",
    xaxis = list(
      title = gettext("Date"),
      rangeselector = list(
        buttons = list(
          list(
            count = 7,
            label = gettext("7 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 15,
            label = gettext("15 d"),
            step = "day",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 6,
            label = gettext("6 m"),
            step = "month",
            stepmode = "backward"
          ),
          list(
            count = 1,
            label = gettext("1 y"),
            step = "year",
            stepmode = "backward"
          ),
          list(
            step = "all",
            label = gettext("all")
          )
        ),
        rangeslider = list(type = "date")
      )
    ),
    yaxis = list(
      title = gettext("Domains"),
      tickformat = ",d"
    )
  )
