df_rtt <- fromJSONwithToken(api_endpoint("/ua_rtt_cc_server_ipv_1d",
  ts = get_ts(days, 30)
))
df_qps <- fromJSONwithToken(api_endpoint("/ua_qps_cc_server_ipv_1d",
  ts = get_ts(days, 30)
))



df_rtt_qps <- left_join(df_qps, df_rtt) %>%
  mutate(
    country_code = ifelse(is.na(country_code), "Missing", country_code),
    ts = as_datetime(ts, tz = "Europe/Prague"),
    region = countrycode::countrycode(country_code, "iso2c", "region23",
      custom_match = c(
        XK = "Eastern Europe",
        TF = "Melanesia",
        IO = "Southern Asia",
        GS = "South America",
        CX = "Australia and New Zealand",
        CC = "South-Eastern Asia",
        BV = "Southern Africa",
        AQ = "Antarctica",
        HM = "South-Eastern Asia"
      )
    ),
    continent = countrycode::countrycode(country_code, "iso2c", "continent",
      custom_match = c(
        XK = "Europe",
        TF = "Oceania",
        IO = "Asia",
        GS = "Americas",
        CX = "Oceania",
        CC = "Asia",
        BV = "Africa",
        AQ = "Antarctica",
        HM = "Asia"
      )
    ),
    continent = ifelse(continent == "Oceania",
      gettext("Oceania"),
      ifelse(continent == "Americas",
        gettext("Americas"),
        ifelse(continent == "Europe",
          gettext("Europe"),
          ifelse(continent == "Asia",
            gettext("Asia"),
            ifelse(continent == "Africa",
              gettext("Africa"), continent
            )
          )
        )
      )
    )
  )



df_rtt_qps %>%
  group_by(continent) %>%
  summarise(
    min_rtt = quantile(mean_median_rtt, 0.10, na.rm = TRUE),
    first_q_rtt = quantile(mean_median_rtt, 0.25, na.rm = TRUE),
    mean_rtt = mean(mean_median_rtt, na.rm = TRUE),
    median_rtt = median(mean_median_rtt, na.rm = TRUE),
    wgt_mean_rtt = weighted.mean(mean_median_rtt, qps,
      na.rm = TRUE
    ),
    third_q_rtt = quantile(mean_median_rtt, 0.75, na.rm = TRUE),
    max_rtt = quantile(mean_median_rtt, 0.90, na.rm = TRUE),
    stdv_rtt = sd(mean_median_rtt, na.rm = TRUE)
  ) %>%
  mutate(
    min_tile = adam_color_tile(
      min_rtt,
      "white", dashboard_colors[1]
    ),
    mean_tile = adam_color_tile(
      wgt_mean_rtt,
      "white", dashboard_colors[3]
    ),
    max_tile = adam_color_tile(
      max_rtt,
      "white", dashboard_colors[1]
    ),
    stdv_tile = adam_color_tile(
      stdv_rtt,
      "white", dashboard_colors[2]
    )
  ) %>%
  filter(!is.na(continent), !is.na(median_rtt)) %>%
  arrange(desc(mean_rtt)) %>%
  select(
    continent,
    max_tile,
    mean_tile,
    min_tile,
    stdv_tile
  ) %>%
  kable(
    "html",
    table.attr = "class='dtable'",
    escape = FALSE,
    caption = details(
      sprintf(
        gettext("Statistics for the last 30 days before %s"),
        format(Sys.Date(), locale_date_format())
      ),
      paste0(
        "<p>",
        gettext("Meaning of symbols:"),
        "</p><dl><dt>D<sub>1</sub></b></dt><dd>",
        gettext("first decile (10% values are smaller)"),
        "</dd><dt>D<sub>9</sub></dt><dd>",
        gettext("ninth decile (10% values are higher)"),
        "</dd><dt>σ</dt><dd>",
        gettext("standard error"),
        "</dd></dl>"
      )
    ),
    align = c("r", "c", "c", "c", "c"),
    format.args = list(big.mark = " "),
    col.names = c(
      gettext("Continent"),
      "D~9~",
      gettext("Mean"),
      "D~1~",
      "σ"
    )
  ) %>%
  kable_styling(
    font_size = 13,
    bootstrap_options = c("striped", "hover", "condensed", "responsive"),
    full_width = FALSE,
    position = "float_right"
  )
